@@ -97,14 +97,22 @@ void BookMarkManager::addBookMarkPrivate(const QString &uri)
     qDebug() << "add bookmarket: " << uri;
     //desktop uri is fixed in favorite item
     QString desktopPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
-    QString videoPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
-    QString picturePath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
-    QString downloadPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
-    QString musicPath = QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
-    QString docPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
-    if (url.path() == desktopPath || url.path() == videoPath
+//    QString videoPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
+//    QString picturePath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+//    QString downloadPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
+//    QString musicPath = QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+//    QString docPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    QString trashPath = QString("favorite:///?schema=trash");
+    QString usersharePath = QString("favorite:///data/usershare?schema=file");
+    QString kmrePath = QString("favorite:///?schema=kmre");
+    QString recentPath = QString("favorite:///?schema=recent");
+    qDebug() << "url.path():"<<url.path();
+    //fix bug#163066, drag trash from desktop, uri not processed
+    if (url.path() == desktopPath /*|| url.path() == videoPath
         || url.path() == picturePath || url.path() == downloadPath
-        || url.path() == musicPath || url.path() == docPath)
+        || url.path() == musicPath || url.path() == docPath*/
+        || uri == trashPath || uri == usersharePath
+        || uri == kmrePath || uri == recentPath || uri == "trash:///")
         return;
 
 
@@ -225,3 +233,9 @@ void BookMarkManager::removeBookMark(const QStringList &uris)
     });
 }
 
+bool BookMarkManager::existsInBookMarks(const QString &uri)
+{
+    QUrl url = FileUtils::urlDecode(uri);
+    QString originPath = "favorite://" + url.path() + "?schema=" + url.scheme();
+    return (m_uris.contains(originPath) || m_uris.contains(uri));
+}
