@@ -30,10 +30,18 @@
 #include <QSizePolicy>
 #include <QSpacerItem>
 #include <QButtonGroup>
+#include <QRegExp>
+#include <QMessageBox>
+#include "file-enumerator.h"
+#include "file-utils.h"
+#include "file-info-job.h"
+#include "file-info.h"
 
 #include <openssl/aes.h>
 #include <glib.h>
 
+#include <QApplication>
+
 using namespace Peony;
 static const QString ftpTypeStr="ftp";
 static const QString sftpTypeStr="sftp";
@@ -45,8 +53,91 @@ static const QString sambaDefaultPortStr="445";
 static QString passwdEncode (QString p);
 static QString passwdDecode (QString p);
 
+static ButtonStyle *global_instance = nullptr;
+
+ButtonStyle *ButtonStyle::getStyle()
+{
+    if (!global_instance) {
+        global_instance = new ButtonStyle;
+    }
+    return global_instance;
+}
+
+void ButtonStyle::drawControl(QStyle::ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
+{
+    switch (element) {
+    case CE_PushButton:
+    {
+        if (const QStyleOptionButton *button = qstyleoption_cast<const QStyleOptionButton *>(option)) {
+            proxy()->drawControl(CE_PushButtonBevel, option, painter, widget);
+            QStyleOptionButton subopt = *button;
+            subopt.rect = proxy()->subElementRect(SE_PushButtonContents, option, widget);
+            proxy()->drawControl(CE_PushButtonLabel, &subopt, painter, widget);
+            return;
+        }
+        break;
+    }
+
+    default:
+        break;
+    }
+    qApp->style()->drawControl(element, option, painter, widget);
+}
+
+int ButtonStyle::pixelMetric(QStyle::PixelMetric metric, const QStyleOption *option, const QWidget *widget) const
+{
+    switch (metric) {
+    case PM_ButtonMargin:
+    {
+        return 0;
+    }
+
+    default:
+        return QProxyStyle::pixelMetric(metric, option, widget);
+    }
+}
+
+QRect ButtonStyle::subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const
+{
+    switch (element) {
+    case SE_PushButtonContents:
+    {
+        if (const QStyleOptionButton *button = qstyleoption_cast<const QStyleOptionButton *>(option)) {
+            const bool icon = !button->icon.isNull();
+            const bool text = !button->text.isEmpty();
+            QRect rect = option->rect;
+            int Margin_Height = 2;
+            int ToolButton_MarginWidth = 10;
+            int Button_MarginWidth = proxy()->pixelMetric(PM_ButtonMargin, option, widget);
+            if (text && !icon && !(button->features & QStyleOptionButton::HasMenu)) {
+                rect.adjust(Button_MarginWidth, 0, -Button_MarginWidth, 0);
+            } else if (!text && icon && !(button->features & QStyleOptionButton::HasMenu)) {
+
+            } else {
+                rect.adjust(ToolButton_MarginWidth, Margin_Height, -ToolButton_MarginWidth, -Margin_Height);
+            }
+            if (button->features & (QStyleOptionButton::AutoDefaultButton | QStyleOptionButton::DefaultButton)) {
+                int dbw = proxy()->pixelMetric(PM_ButtonDefaultIndicator, option, widget);
+                rect.adjust(dbw, dbw, -dbw, -dbw);
+            }
+            return rect;
+        }
+        break;
+    }
+
+    default:
+        break;
+    }
+
+    return QProxyStyle::subElementRect(element, option, widget);
+}
+
+
 ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
 {
+    if("bo_CN" == QLocale::system().name()){
+        m_widget_size.setWidth(m_widget_size.width() + 57);
+    }
     setFixedSize(m_widget_size);
     setWindowIcon(QIcon::fromTheme("network-server"));
     setWindowTitle(tr("connect to server"));
@@ -82,7 +173,6 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
     m_remote_type_edit->setAutoCompletion(true);
     m_ip_label->setFixedHeight(36);
     m_ip_edit->setFixedHeight(36);
-    m_ip_edit->setFixedWidth(194);
     m_port_label->setFixedHeight(36);
     m_port_editor->setFixedHeight(36);
     m_port_editor->setFixedWidth(65);
@@ -96,9 +186,11 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
     m_remote_layout->addWidget(m_remote_type_edit,  0, 1, 1, 5);
     m_remote_layout->setVerticalSpacing(20);
     m_remote_layout->addWidget(m_ip_label,          1, 0, 1, 1);
-    m_remote_layout->addWidget(m_ip_edit,           1, 1, 1, 1);
-    m_remote_layout->addWidget(m_port_label,        1, 2, 1, 1);
-    m_remote_layout->addWidget(m_port_editor,       1, 3, 1, 3);
+    m_remote_layout->addWidget(m_ip_edit,           1, 1, 1, 3);
+    m_remote_layout->addWidget(m_port_label,        1, 4, 1, 1);
+    m_remote_layout->addWidget(m_port_editor,       1, 5, 1, 1);
+    m_remote_layout->setColumnStretch(0, 1);
+    m_remote_layout->setColumnStretch(1, 5);
 
     m_main_layout->addLayout(m_remote_layout);
     m_main_layout->addSpacing(28);
@@ -130,6 +222,7 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
     m_btn_conn->setAutoDefault(true);
     m_btn_add->setAutoDefault(false);
     m_btn_del->setAutoDefault(false);
+    //m_btn_conn->setStyle(ButtonStyle::getStyle());
     m_main_layout->addLayout(m_btn_layout);
 
     setLayout(m_main_layout);
@@ -140,6 +233,9 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
         for (auto uri = uriList.constBegin(); uri != uriList.constEnd(); ++uri) {
             QUrl url(uri.key ());
             if ("" != uri.key ()) {
+                if("smb"==url.scheme().toLower() && !url.path().isEmpty()){/* samba的子项不添加到个人收藏服务器中 */
+                    continue;
+                }
                 QString urit = uri.key () == url.toDisplayString() ? uri.key() : url.toDisplayString();
                 QListWidgetItem* item = new QListWidgetItem;
                 item->setText(urit);
@@ -170,7 +266,11 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
     Q_EMIT m_remote_type_edit->currentTextChanged(ftpTypeStr);
 
     connect(m_btn_del, &QPushButton::clicked, this, [=] (bool checked) {
-        removeUri(uri());
+        QString delUri = uri();
+        if (!m_favorite_list && !m_favorite_list->currentItem() && delUri != m_favorite_list->currentItem()->text()) {
+            delUri = m_favorite_list->currentItem()->text();
+        }
+        removeUri(delUri);
         if (m_favorite_uri.count() <= 0) {
             m_favorite_list->clear();
         } else {
@@ -187,9 +287,24 @@ ConnectServerDialog::ConnectServerDialog(QWidget *parent) : QDialog(parent)
 
     connect(m_btn_conn, &QPushButton::clicked, this, [=] (bool checked) {
         if ("" != uri()) {
+            checkConnectIpAndPort(uri());
+
+            if (m_checkIp) {
+                m_checkIp = false;
+                QMessageBox::warning(nullptr, tr("Warning"), tr("ip input error, please re-enter!"), QMessageBox::Ok);
+                return;
+            } else if (m_checkPort) {
+                m_checkPort = false;
+                QMessageBox::warning(nullptr, tr("Warning"), tr("port input error, please re-enter!"), QMessageBox::Ok);
+                return;
+            }
             accept();
         }
-
+        /* 连接smb时，最外层连接时不会弹出登录框，如需添加到个人收藏服务器和侧边栏则需如下代码 */
+        QUrl url(uri());
+        if("smb"==url.scheme().toLower() && url.path().isEmpty()){/* smb最外层uri，无挂载卸载能力，例如：smb://127.0.0.1:445 */
+            addUri(uri());
+        }
         Q_UNUSED(checked);
     });
 }
@@ -244,6 +359,18 @@ void ConnectServerDialog::setUri(QString uri)
 
 void ConnectServerDialog::addUri(QString uri)
 {
+    checkConnectIpAndPort(uri);
+
+    if (m_checkIp) {
+        m_checkIp = false;
+        QMessageBox::warning(nullptr, tr("Warning"), tr("ip input error, please re-enter!"), QMessageBox::Ok);
+        return;
+    } else if (m_checkPort) {
+        m_checkPort = false;
+        QMessageBox::warning(nullptr, tr("Warning"), tr("port input error, please re-enter!"), QMessageBox::Ok);
+        return;
+    }
+
     bool canInsert = false;
     QUrl url(uri);
 
@@ -291,16 +418,54 @@ void ConnectServerDialog::removeUri(QString uri)
     }
 }
 
+void ConnectServerDialog::checkConnectIpAndPort(QString uri)
+{
+    QString tmpUri = uri + "/";
+    bool isExistNetwork = false;
+    FileEnumerator e;
+    e.setEnumerateDirectory("network:///");
+    e.enumerateSync();
+    for (auto fileInfo : e.getChildren()) {
+        FileInfoJob infoJob(fileInfo);
+        infoJob.querySync();
+
+        /* 由远程服务器的targeturi获取uri来调用属性窗口, */
+        QUrl targetUrl(fileInfo.get()->targetUri());
+        if (tmpUri == targetUrl.toString() && tmpUri != "smb:///") {
+            isExistNetwork = true;
+            break;
+        }
+    }
+
+    if (!isExistNetwork) {
+        //filter ip and port
+        QRegExp regExpIp("((2[0-4]\\d|25[0-5]|[01]?\\d\\d?)\\.){3}(2[0-4]\\d|25[0-5]|[01]?\\d\\d?)");
+        if (!regExpIp.exactMatch(m_ip_edit->text())) {
+            m_checkIp = true;
+        }
+
+        QRegExp regExpPort("([0-9]|[1-9]\\d{1,3}|[1-5]\\d{4}|6[0-4]\\d{4}|65[0-4]\\d{2}|655[0-2]\\d|6553[0-5])");
+        if (!regExpPort.exactMatch(m_port_editor->currentText())) {
+            m_checkPort = true;
+        }
+    }
+}
+
 ConnectServerLogin::ConnectServerLogin(QString uri, QWidget *parent)
     : QDialog(parent),m_remoteIP(uri)
 {
+    if("bo_CN" == QLocale::system().name()){
+        m_widget_size.setHeight(m_widget_size.height() + 61);
+    }
     setFixedSize(m_widget_size);
+    if("bo_CN" == QLocale::system().name()){
+        setFixedSize(QSize(424,455));
+    }
     setWindowIcon(QIcon::fromTheme("network-server"));
     setWindowTitle(tr("The login user"));
     setBackgroundRole(QPalette::Base);
     setAutoFillBackground(true);
     m_main_layout = new QVBoxLayout(this);
-    m_main_layout->addSpacing(12);
     m_main_layout->setMargin(m_widget_margin);
 
     QUrl url(uri);
@@ -308,22 +473,18 @@ ConnectServerLogin::ConnectServerLogin(QString uri, QWidget *parent)
     m_tip->setWordWrap(true);
     m_tip->setText(QString(tr("Please enter the %1's user name and password of the server.")).arg(url.host ()));
     m_main_layout->addWidget(m_tip);
-
+    m_usr_layout            = new QGridLayout;
     m_usr_label             = new QLabel;
-    m_usr_btn_group         = new QVBoxLayout;
     m_usr_btn_guest         = new QRadioButton;
     m_usr_btn_usr           = new QRadioButton;
-    m_usr_layout            = new QHBoxLayout;
 
     m_usr_label->setText(tr("User's identity"));
     m_usr_btn_guest->setText(tr("guest"));
     m_usr_btn_usr->setText(tr("Registered users"));
-    m_usr_btn_group->addWidget(m_usr_btn_guest);
-    m_usr_btn_group->addWidget(m_usr_btn_usr);
-    m_usr_layout->addWidget(m_usr_label);
-    m_usr_layout->addLayout(m_usr_btn_group);
-    m_usr_label->setAlignment (Qt::AlignTop | Qt::AlignLeft);
-    m_usr_layout->setAlignment(Qt::AlignTop | Qt::AlignLeft);
+    m_usr_layout->addWidget(m_usr_label,         0, 0);
+    m_usr_layout->addWidget(m_usr_btn_guest,     0, 1);
+    m_usr_layout->addWidget(m_usr_btn_usr,       1, 1);
+    m_usr_layout->setColumnStretch(2, 1);
     m_main_layout->addLayout(m_usr_layout);
 
     m_reg_usr_name_label    = new QLabel;
@@ -360,7 +521,7 @@ ConnectServerLogin::ConnectServerLogin(QString uri, QWidget *parent)
     m_btn_ok->setText(tr("ok"));
     m_btn_layout->addWidget(m_btn_cancel);
     m_btn_layout->addWidget(m_btn_ok);
-    m_main_layout->addSpacing(20);
+    m_main_layout->addStretch();
     m_btn_ok->setAutoDefault(true);
     m_btn_cancel->setAutoDefault(false);
     m_main_layout->addLayout(m_btn_layout);
@@ -439,8 +600,9 @@ ConnectServerLogin::ConnectServerLogin(QString uri, QWidget *parent)
 
     connect(m_btn_ok, &QPushButton::clicked, [=] () {
         accept();
-        QUrl url(m_remoteIP);
-        syncRemoteServer(url);
+        //QUrl url(m_remoteIP);
+        //syncRemoteServer(url);
+        m_reg_usr_passwd_editor->setProperty("password", m_reg_usr_passwd_editor->text());
     });
 }
 
@@ -495,21 +657,24 @@ void ConnectServerLogin::syncRemoteServer(const QUrl& url)
         QString remoteUri= type.append("://").append(url.host()).append(":").append(portStr);
         QMap<QString, QVariant> userInfo;
         if (!uriList.contains (remoteUri)) {
-            if (savePassword () && !m_reg_usr_passwd_editor->text().isEmpty ()) {
-                userInfo.insert (m_reg_usr_name_editor->currentText (), passwdEncode (m_reg_usr_passwd_editor->text().toUtf8 ()));
+            if (savePassword () && !getPassWordProperty().isEmpty ()) {
+                userInfo.insert (user(), passwdEncode (getPassWordProperty().toUtf8 ()));
             }
 
             uriList.insert (remoteUri, userInfo);
             GlobalSettings::getInstance()->slot_updateRemoteServer(remoteUri, true);
         } else {
             userInfo = uriList[remoteUri].toMap ();
-            if (savePassword ()  && !m_reg_usr_passwd_editor->text().isEmpty ()) {
-                userInfo[m_reg_usr_name_editor->currentText ()] = passwdEncode (m_reg_usr_passwd_editor->text().toUtf8 ());
-            } /*else {
-                if (userInfo.contains (m_reg_usr_name_editor->currentText ())) {
-                    userInfo.remove (m_reg_usr_name_editor->currentText ());
+            if (savePassword()){
+                if (!getPassWordProperty().isEmpty ()) {
+                    userInfo[user()] = passwdEncode (getPassWordProperty().toUtf8 ());
                 }
-            }*/
+            }else {
+                if (userInfo.contains(m_reg_usr_name_editor->currentText ())) {
+                    userInfo.remove(m_reg_usr_name_editor->currentText ());
+                }
+            }
+
             uriList[remoteUri] = userInfo;
         }
 
@@ -518,6 +683,11 @@ void ConnectServerLogin::syncRemoteServer(const QUrl& url)
     }
 }
 
+QString ConnectServerLogin::getPassWordProperty()
+{
+    return m_reg_usr_passwd_editor->property("password").toString();
+}
+
 
 static const unsigned char PEONY_AES_KEY[] = "peony key";
 
