@@ -27,6 +27,10 @@
 #include "peony-core_global.h"
 #include <QWidget>
 #include <QStack>
+#include <QGSettings>
+#include <QTimer>
+#include <QDir>
+#include <QAbstractItemView>
 
 #include "file-item-model.h"
 
@@ -63,6 +67,7 @@ public:
 
     const QString getCurrentUri();
     const QStringList getCurrentSelections();
+    const int getCurrentRowcount();
 
     const QStringList getAllFileUris();
 
@@ -87,6 +92,7 @@ Q_SIGNALS:
     void selectionChanged();
     void viewDoubleClicked(const QString &uri);
     void updateWindowLocationRequest(const QString &uri, bool addHistory, bool forceUpdate = false);
+    void signal_responseUnmounted(const QString &destUri, const QString &sourceUri);
 
     void updateWindowSelectionRequest(const QStringList &uris);
 
@@ -95,6 +101,9 @@ Q_SIGNALS:
     void zoomRequest(bool zoomIn);
     void setZoomLevelRequest(int zoomLevel);
     void updateStatusBarSliderStateRequest();
+    void signal_itemAdded(const QString& uri);/* 新增文件（夹），item创建完成 */
+    void updatePreviewPageRequest();
+    void statusBarChanged();
 
 public Q_SLOTS:
     void goToUri(const QString &uri, bool addHistory, bool forceUpdate = false);
@@ -118,6 +127,7 @@ public Q_SLOTS:
 
     void setSortFilter(int FileTypeIndex=0, int FileMTimeIndex=0, int FileSizeIndex=0);
     void setShowHidden(bool showHidden = false);
+    void setShowFileExtensions(bool show = true);
     void setUseDefaultNameSortOrder(bool use);
     void setSortFolderFirst(bool folderFirst);
     void setFilterLabelConditions(QString name);
@@ -131,6 +141,9 @@ public Q_SLOTS:
 
     void onViewDoubleClicked(const QString &uri);
 
+    void addFileDialogFiltersCondition(const QStringList &mimeTypeFilters, const QStringList &nameFilters, QDir::Filters dirFilters, Qt::CaseSensitivity caseSensitivity);
+    void setSelectionMode(QAbstractItemView::SelectionMode mode);
+
 protected:
     /*!
      * \brief bindNewProxy
@@ -153,6 +166,7 @@ private:
 
     FileItemModel *m_model;
     FileItemProxyFilterSortModel *m_proxy_model;
+    QGSettings* m_control_center_plugin = nullptr;
 };
 
 }
