@@ -31,6 +31,8 @@
 #include "file-utils.h"
 
 #include "global-settings.h"
+#include "search-vfs-uri-parser.h"
+#include "directoryviewhelper.h"
 
 #include <QMouseEvent>
 
@@ -55,22 +57,34 @@
 
 #include <QStringList>
 #include <QStyleHints>
+#include <QPoint>
 
 #include <QDebug>
 #include <QToolTip>
 
+#include <QStandardPaths>
+
+#include <QDrag>
+#include <QWindow>
+#include <QMessageBox>
+
 using namespace Peony;
 using namespace Peony::DirectoryView;
 
 IconView::IconView(QWidget *parent) : QListView(parent)
-{
+{   
+    m_touch_active_timer = new QTimer(this);
+    m_touch_active_timer->setSingleShot(true);
+
+    setFrameShape(QFrame::NoFrame);
+
     setAttribute(Qt::WA_TranslucentBackground);
     viewport()->setAttribute(Qt::WA_TranslucentBackground);
 
     setAutoScroll(true);
     setAutoScrollMargin(100);
 
-    setStyle(IconViewStyle::getStyle());
+    //setStyle(IconViewStyle::getStyle());
     //FIXME: do not create proxy in view itself.
     IconViewDelegate *delegate = new IconViewDelegate(this);
     setItemDelegate(delegate);
@@ -101,8 +115,8 @@ IconView::IconView(QWidget *parent) : QListView(parent)
 
     setContextMenuPolicy(Qt::CustomContextMenu);
 
-    setGridSize(QSize(115, 135));
-    setIconSize(QSize(64, 64));
+    setIconSize(QSize(86, 86));
+    setGridSize(itemDelegate()->sizeHint(QStyleOptionViewItem(), QModelIndex()) + QSize(20, 20));
 
     m_renameTimer = new QTimer(this);
     m_renameTimer->setInterval(3000);
@@ -176,6 +190,12 @@ void IconView::setCutFiles(const QStringList &uris)
 void IconView::setDirectoryUri(const QString &uri)
 {
     m_current_uri = uri;
+    if (m_current_uri.startsWith("search://")) {
+        QString nameRegexp = SearchVFSUriParser::getSearchUriNameRegexp(uri);
+        setSearchKey(nameRegexp);
+    } else {
+        setSearchKey("");
+    }
 }
 
 const QString IconView::getDirectoryUri()
@@ -216,6 +236,13 @@ void IconView::dragEnterEvent(QDragEnterEvent *e)
     auto action = m_ctrl_key_pressed ? Qt::CopyAction : Qt::MoveAction;
     qDebug()<<"dragEnterEvent()" <<action <<m_ctrl_key_pressed;
     if (e->mimeData()->hasUrls()) {
+        if (FileUtils::containsStandardPath(e->mimeData()->urls())) {
+            e->ignore();
+            if (this == e->source()) {
+                clearSelection();
+            }
+            return;
+        }
         e->setDropAction(action);
         e->accept();
     }
@@ -270,9 +297,26 @@ void IconView::dropEvent(QDropEvent *e)
     if (e->keyboardModifiers() & Qt::ShiftModifier) {
         action = Qt::TargetMoveAction;
     }
+
+    //Do not allow dragging files to file manager when searching
+    //related to bug#107063,118004
+    if (m_current_uri.startsWith("search://") || m_current_uri.startsWith("favorite://")) {
+        QMessageBox::warning(this, tr("warn"), tr("This operation is not supported."));
+        return;
+    }
+
     auto proxy_index = indexAt(e->pos());
     auto index = m_sort_filter_proxy_model->mapToSource(proxy_index);
     qDebug()<<"dropEvent" <<action <<m_ctrl_key_pressed <<indexAt(e->pos()).isValid();
+
+    QString username = QStandardPaths::writableLocation(QStandardPaths::HomeLocation).split("/").last();
+    QString boxpath = "file://"+QStandardPaths::writableLocation(QStandardPaths::HomeLocation)+"/.box";
+    QString oldboxpath = "file://box/"+username;
+
+    if(m_current_uri == boxpath || m_current_uri == oldboxpath || m_current_uri == "filesafe:///"){
+        return;
+    }
+
     //move in current path, do nothing
     if (e->source() == this)
     {
@@ -305,20 +349,64 @@ void IconView::mouseMoveEvent(QMouseEvent *e)
         return;
     }
     QListView::mouseMoveEvent(e);
+
+    // fix #115124, drag selection can not trigger auto scroll in view.
+    if (e->buttons() & Qt::LeftButton && !this->viewport()->rect().adjusted(0, autoScrollMargin(), 0, -autoScrollMargin()).contains(e->pos())) {
+        doAutoScroll();
+    }
+
+    if(getSelections().count()>1)
+        multiSelect();
+    viewport()->update(viewport()->rect());
 }
 
 void IconView::mousePressEvent(QMouseEvent *e)
 {
+    bool singleClicked = qApp->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick);
+    if (singleClicked) {
+        if (!m_touch_active_timer->isActive()) {
+            m_touch_active_timer->start(1100);
+        }
+    }
+
     m_allow_set_index_widget = true;
 
-    qDebug()<<"moursePressEvent";
-    m_editValid = true;
+    QModelIndex itemIndex = indexAt(e->pos());
+    if (itemIndex.isValid() && m_multi_select) {
+        m_mouse_release_unselect = selectedIndexes().contains(itemIndex);
+    } else {
+        m_mouse_release_unselect = false;
+    }
+
     QListView::mousePressEvent(e);
 
     if (e->button() != Qt::LeftButton) {
         return;
     }
 
+    if (true == m_mouse_release_unselect) {
+        selectionModel()->setCurrentIndex(itemIndex, QItemSelectionModel::Select|QItemSelectionModel::Rows);
+    }
+
+    if(getSelections().count()>1)
+        multiSelect();
+
+    viewport()->update(viewport()->rect());
+
+    if (!itemIndex.isValid()) {
+        disableMultiSelect();
+    }
+    //FIXME: Modify the icon style, only click on the text to respond, click on the icon to not respond
+    QRect rect = visualRect(indexAt(e->pos()));
+    QSize iconExpectedSize = iconSize();
+
+    QRect testRect(rect.x(), rect.y()+ iconExpectedSize.height(),rect.width(),rect.height()-iconExpectedSize.height());
+    if(!testRect.contains(e->pos()))
+    {
+        m_editValid = false;
+        m_renameTimer->start();
+        return;
+    }
     //m_renameTimer
     if(!m_renameTimer->isActive())
     {
@@ -327,8 +415,10 @@ void IconView::mousePressEvent(QMouseEvent *e)
     }
     else
     {
-        //if remain time is between[0.75, 3000],then trigger rename event;
-        if(m_renameTimer->remainingTime()>=0 && m_renameTimer->remainingTime() <= 3000 - qApp->styleHints()->mouseDoubleClickInterval()
+        //优化文件点击策略，提升用户体验，关联bug#125368
+        //在双击时间间隔内，如果未触发双击事件，但是点击的是同一个有效图标，触发双击事件
+        //系统默认双击间隔为400ms, 策略为[0,400]，触发双击，(400,3000)触发重命名
+        if(m_renameTimer->remainingTime() >0 && m_renameTimer->remainingTime() < 3000 - qApp->styleHints()->mouseDoubleClickInterval()
                 && indexAt(e->pos()) == m_last_index && m_last_index.isValid() && m_editValid == true)
         {
             slotRename();
@@ -346,6 +436,13 @@ void IconView::mouseReleaseEvent(QMouseEvent *e)
     if (e->button() != Qt::LeftButton) {
         return;
     }
+
+    if (true == m_mouse_release_unselect) {
+        QModelIndex itemIndex = indexAt(e->pos());
+        if (itemIndex.isValid()) {
+            selectionModel()->setCurrentIndex(itemIndex, QItemSelectionModel::Deselect|QItemSelectionModel::Rows);
+        }
+    }
 }
 
 void IconView::mouseDoubleClickEvent(QMouseEvent *event)
@@ -354,6 +451,20 @@ void IconView::mouseDoubleClickEvent(QMouseEvent *event)
     QListView::mouseDoubleClickEvent(event);
 }
 
+void IconView::keyPressEvent(QKeyEvent *e)
+{
+    QListView::keyPressEvent(e);
+    if (e->key() == Qt::Key_Control)
+        m_ctrl_key_pressed = true;
+}
+
+void IconView::keyReleaseEvent(QKeyEvent *e)
+{
+    QListView::keyReleaseEvent(e);
+    if (e->key() == Qt::Key_Control)
+        m_ctrl_key_pressed = false;
+}
+
 void IconView::paintEvent(QPaintEvent *e)
 {
     QPainter p(this->viewport());
@@ -369,10 +480,9 @@ void IconView::paintEvent(QPaintEvent *e)
 
 void IconView::resizeEvent(QResizeEvent *e)
 {
-    //FIXME: first resize is disfluency.
-    //but I have to reset the index widget in view's resize.
     QListView::resizeEvent(e);
-    setIndexWidget(m_last_index, nullptr);
+    // fix 85058
+    updateEditorGeometries();
 }
 
 void IconView::wheelEvent(QWheelEvent *e)
@@ -403,6 +513,9 @@ void IconView::updateGeometries()
         return;
     }
 
+    if (model()->columnCount() == 0 || model()->rowCount() == 0)
+        return;
+    //bug#120710 文件未占满一屏时，不需要展示滑动条
     int itemCount = model()->rowCount();
     QRegion itemRegion;
     for (int row = 0; row < itemCount; row++) {
@@ -413,7 +526,8 @@ void IconView::updateGeometries()
         verticalScrollBar()->setRange(0, 0);
     } else {
         int vertiacalMax = verticalScrollBar()->maximum();
-        verticalScrollBar()->setMaximum(vertiacalMax + gridSize().height());
+        verticalScrollBar()->setMaximum(vertiacalMax + BOTTOM_STATUS_MARGIN);
+        int verticalValue = verticalOffset();
         verticalScrollBar()->setValue(verticalValue);
     }
 #else
@@ -452,26 +566,77 @@ void IconView::focusInEvent(QFocusEvent *e)
             selectionModel()->select(model()->index(0, 0), QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows);
         } else {
             scrollTo(selectedIndexes().first(), QListView::PositionAtCenter);
-            //auto selections = selectedIndexes();
+            auto selections = getSelections();
             clearSelection();
             //added for tab key to focus button issue
-            //comment to fix crash bug#68788
-//            QTimer::singleShot(100, this, [=](){
-//                for (auto index : selections) {
-//                    selectionModel()->select(index, QItemSelectionModel::Select);
-//                }
-//            });
+            //use uri rather than index, to fix crash bug#68788, 96145
+            QTimer::singleShot(100, this, [=](){
+               setSelections(selections);
+            });
         }
     }
 }
 
+void IconView::startDrag(Qt::DropActions supportedActions)
+{
+    auto indexes = selectedIndexes();
+    if (indexes.count() > 0) {
+        auto pos = mapFromGlobal(QCursor::pos());
+        qreal scale = 1.0;
+        QWidget *window = this->window();
+        if (window) {
+            auto windowHandle = window->windowHandle();
+            if (windowHandle) {
+                scale = windowHandle->devicePixelRatio();
+            }
+        }
+
+        auto drag = new QDrag(this);
+        drag->setMimeData(model()->mimeData(indexes));
+
+        QRegion rect;
+        QHash<QModelIndex, QRect> indexRectHash;
+        for (auto index : indexes) {
+            rect += (visualRect(index));
+            indexRectHash.insert(index, visualRect(index));
+        }
+
+        QRect realRect = rect.boundingRect();
+        QPixmap pixmap(realRect.size() * scale);
+        pixmap.fill(Qt::transparent);
+        pixmap.setDevicePixelRatio(scale);
+        QPainter painter(&pixmap);
+        for (auto index : indexes) {
+            painter.save();
+            QStyleOptionViewItem opt = viewOptions();
+            auto viewItemDelegate = static_cast<IconViewDelegate *>(itemDelegate());
+            viewItemDelegate->initIndexOption(&opt, index);
+
+            opt.state |= QStyle::State_Selected;
+            opt.rect.setSize(visualRect(index).size());
+            painter.translate(indexRectHash.value(index).topLeft() - rect.boundingRect().topLeft());
+
+            viewItemDelegate->setStartDrag(true);
+            itemDelegate()->paint(&painter, opt, index);
+            viewItemDelegate->setStartDrag(false);
+            painter.restore();
+        }
+
+        drag->setPixmap(pixmap);
+        drag->setHotSpot(pos - rect.boundingRect().topLeft() );
+        drag->setDragCursor(QPixmap(), m_ctrl_key_pressed? Qt::CopyAction: Qt::MoveAction);
+        drag->exec(m_ctrl_key_pressed? Qt::CopyAction: Qt::MoveAction);
+    }
+}
+
 void IconView::slotRename()
 {
     //special path like trash path not allow rename
     if (getDirectoryUri().startsWith("trash://")
         || getDirectoryUri().startsWith("recent://")
         || getDirectoryUri().startsWith("favorite://")
-        || getDirectoryUri().startsWith("search://"))
+        || getDirectoryUri().startsWith("search://")
+        || getDirectoryUri().startsWith("network://"))
         return;
 
     //standardPaths not allow rename
@@ -484,7 +649,8 @@ void IconView::slotRename()
     qDebug()<<"slotRename"<<m_editValid;
     QTimer::singleShot(300, m_renameTimer, [&]() {
         qDebug()<<"singleshot"<<m_editValid;
-        if(m_editValid) {
+        //fix bug#98951, click edit box boarder will reenter edit issue
+        if(m_editValid && ! m_delegate_editing) {
             m_renameTimer->stop();
             setIndexWidget(m_last_index, nullptr);
             edit(m_last_index);
@@ -509,11 +675,23 @@ void IconView::bindModel(FileItemModel *sourceModel, FileItemProxyFilterSortMode
     m_model = sourceModel;
     m_sort_filter_proxy_model = proxyModel;
 
+    auto proxyModelSelectionModelHint = proxyModel->getSelectionModeHint();
+    if (proxyModelSelectionModelHint != NoSelection) {
+        setSelectionMode(proxyModelSelectionModelHint);
+    }
+
+    connect(proxyModel, &FileItemProxyFilterSortModel::setSelectionModeChanged, this, [=]{
+        auto proxyModelSelectionModelHint = proxyModel->getSelectionModeHint();
+        if (proxyModelSelectionModelHint != NoSelection) {
+            setSelectionMode(proxyModelSelectionModelHint);
+        }
+    });
+
     setModel(m_sort_filter_proxy_model);
 
     //edit trigger
     connect(this->selectionModel(), &QItemSelectionModel::selectionChanged, [=](const QItemSelection &selection, const QItemSelection &deselection) {
-        qDebug()<<"selection changed";
+        //qDebug()<<"selection changed";
         auto currentSelections = selection.indexes();
 
         for (auto index : deselection.indexes()) {
@@ -539,7 +717,7 @@ void IconView::bindModel(FileItemModel *sourceModel, FileItemProxyFilterSortMode
         }
 
 
-        qDebug()<<"selection changed2"<<m_editValid;
+        //qDebug()<<"selection changed2"<<m_editValid;
     });
 }
 
@@ -565,7 +743,12 @@ void IconView::setProxy(DirectoryViewProxyIface *proxy)
         if (getSelections().count() != 1)
             return;
         auto uri = getSelections().first();
-        Q_EMIT m_proxy->viewDoubleClicked(uri);
+        //process open symbolic link lllll
+        //auto info = FileInfo::fromUri(uri);
+        //if (info->isSymbolLink() && uri.startsWith("file://") && info->isValid())
+          //  uri = "file://" + FileUtils::getSymbolicTarget(uri);
+        if(!m_multi_select)
+            Q_EMIT m_proxy->viewDoubleClicked(uri);
     });
 
 
@@ -621,7 +804,7 @@ bool IconView::getDelegateEditFlag()
 
 int IconView::getSortType()
 {
-    int type = m_sort_filter_proxy_model->sortColumn();
+    int type = m_sort_filter_proxy_model->expectedSortType();
     return type<0? 0: type;
 }
 
@@ -632,7 +815,7 @@ void IconView::setSortType(int sortType)
 
 int IconView::getSortOrder()
 {
-    return m_sort_filter_proxy_model->sortOrder();
+    return m_sort_filter_proxy_model->expectedSortOrder();
 }
 
 void IconView::setSortOrder(int sortOrder)
@@ -649,10 +832,13 @@ void IconView::editUri(const QString &uri)
 {
     setState(QListView::NoState);
     auto origin = FileUtils::getOriginalUri(uri);
-    setIndexWidget(m_sort_filter_proxy_model->indexFromUri(origin), nullptr);
+    if(uri.startsWith("mtp://"))/* Fixbug#82649:在手机内部存储里新建文件/文件夹时，名称不是可编辑状态,都是默认文件名/文件夹名 */
+        origin = uri;
+    QModelIndex index = m_sort_filter_proxy_model->indexFromUri(origin);
+    setIndexWidget(index, nullptr);
     qDebug() <<"editUri:" <<uri <<origin;
-    QListView::scrollTo(m_sort_filter_proxy_model->indexFromUri(origin));
-    edit(m_sort_filter_proxy_model->indexFromUri(origin));
+    QListView::scrollTo(index);
+    edit(index);
 //    if (! m_delegate_editing)
 //        edit(m_sort_filter_proxy_model->indexFromUri(origin));
 }
@@ -683,14 +869,73 @@ void IconView::clearIndexWidget()
     }
 }
 
+void IconView::multiSelect()
+{
+    if (selectionMode() == MultiSelection) {
+        return;
+    }
+    if (GlobalSettings::getInstance()->getValue(MULTI_SELECT).toBool()) {
+        m_multi_select = true;
+    }
+    setSelectionMode(MultiSelection);
+    viewport()->update(viewport()->rect());
+    Q_EMIT updateSelectStatus(m_multi_select);
+}
+
+void IconView::disableMultiSelect()
+{
+    if (selectionMode() == ExtendedSelection) {
+        return;
+    }
+    m_multi_select = false;
+    setSelectionMode(ExtendedSelection);
+    viewport()->update(viewport()->rect());
+    Q_EMIT updateSelectStatus(m_multi_select);
+}
+
+void IconView::setSearchKey(const QString &key)
+{
+    auto viewItemDelegate = static_cast<IconViewDelegate *>(itemDelegate());
+    viewItemDelegate->setSearchKeyword(key);
+}
+
+void IconView::doMultiSelect(bool isMultiSlelect)
+{
+    if (isMultiSlelect) {
+        multiSelect();
+    } else {
+        disableMultiSelect();
+    }
+}
+
+void IconView::setItemsVisible(bool visible)
+{
+    viewport()->setVisible(visible);
+}
+
+bool IconView::isEnableMultiSelect()
+{
+    return m_multi_select;
+}
+
+void IconView::releaseUnselect(bool select)
+{
+    m_mouse_release_unselect = select;
+}
+
 //Icon View 2
 IconView2::IconView2(QWidget *parent) : DirectoryViewWidget(parent)
 {
     auto layout = new QVBoxLayout(this);
+    layout->setObjectName("_iconview2_layout");
     layout->setMargin(0);
     layout->setSpacing(0);
     m_view = new IconView(this);
 
+    DirectoryViewHelper * viewHelper = DirectoryViewHelper::globalInstance();
+    viewHelper->addIconViewWithDirectoryViewWidget(m_view, this);
+    connect(m_view, &IconView::updateSelectStatus, viewHelper, &DirectoryViewHelper::updateSelectStatus);
+
     int defaultZoomLevel = GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ZOOM_LEVEL).toInt();
     if (defaultZoomLevel >= minimumZoomLevel() && defaultZoomLevel <= maximumZoomLevel())
         m_zoom_level = defaultZoomLevel;
@@ -709,6 +954,15 @@ IconView2::~IconView2()
 
 void IconView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *proxyModel)
 {
+    auto layout = findChild<QVBoxLayout *>("_iconview2_layout");
+    bool ok = false;
+    if (parentWidget()) {
+        int statusBarHeight = parentWidget()->property("statusBarHeight").toInt(&ok);
+        if (ok) {
+            layout->setContentsMargins(0, 0, 0, statusBarHeight);
+        }
+    }
+
     disconnect(m_model);
     disconnect(m_proxy_model);
     m_model = model;
@@ -716,20 +970,40 @@ void IconView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
 
     m_view->bindModel(model, proxyModel);
     connect(m_model, &FileItemModel::selectRequest, this, &DirectoryViewWidget::updateWindowSelectionRequest);
-
+    connect(m_model,&FileItemModel::signal_itemAdded, this, [=](const QString& uri){
+        Q_EMIT this->signal_itemAdded(uri);
+    });
     connect(model, &FileItemModel::findChildrenFinished, this, &DirectoryViewWidget::viewDirectoryChanged);
     //connect(m_model, &FileItemModel::dataChanged, m_view, &IconView::clearIndexWidget);
     //connect(m_model, &FileItemModel::updated, m_view, &IconView::resort);
+    connect(m_model, &FileItemModel::updated, m_view->viewport(), QOverload<>::of(&QWidget::update));
 
-    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged,
-            this, &DirectoryViewWidget::viewSelectionChanged);
+    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged, this, [=]() {
+        Q_EMIT viewSelectionChanged();
+    });
 
     connect(m_view, &IconView::activated, this, [=](const QModelIndex &index) {
+        //平板模式下，长按打开文件处理
+        if (m_view->m_touch_active_timer->isActive()) {
+            auto costTime = m_view->m_touch_active_timer->interval() - m_view->m_touch_active_timer->remainingTime();
+            if (costTime > qApp->doubleClickInterval()) {
+                m_view->m_touch_active_timer->stop();
+                return;
+            }
+        }
+
         //when selections is more than 1, let mainwindow to process
         if (getSelections().count() != 1)
             return;
         auto uri = getSelections().first();
-        Q_EMIT this->viewDoubleClicked(uri);
+        //process open symbolic link
+       // auto info = FileInfo::fromUri(uri);
+       // if (info->isSymbolLink() && uri.startsWith("file://") && info->isValid())
+        //    uri = "file://" +  FileUtils::getSymbolicTarget(uri);
+        if(!m_view->isEnableMultiSelect())
+            Q_EMIT this->viewDoubleClicked(uri);
+
+        m_view->m_touch_active_timer->stop();
     });
 
     connect(m_view, &IconView::customContextMenuRequested, this, [=](const QPoint &pos) {
@@ -745,14 +1019,20 @@ void IconView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
             m_view->viewport()->repaint();
         }
 
-        if (!m_view->indexAt(pos).isValid())
+        bool indexWidgetContainsPos = false;
+        auto indexWidget = m_view->indexWidget(m_view->currentIndex());
+        if (indexWidget) {
+            indexWidgetContainsPos = indexWidget->geometry().contains(pos);
+        }
+        if (!m_view->indexAt(pos).isValid() && !indexWidgetContainsPos)
             m_view->clearSelection();
 
         //NOTE: we have to ensure that we have cleared the
         //selection if menu request at blank pos.
         QTimer::singleShot(isDragSelecting? 300: 1, this, [=]() {
             m_view->setIgnore_mouse_move_event(false);
-            Q_EMIT this->menuRequest(QCursor::pos());
+            m_view->m_touch_active_timer->stop();
+            Q_EMIT this->menuRequest(mapToGlobal(pos));
         });
     });
 
@@ -775,7 +1055,7 @@ void IconView2::setCurrentZoomLevel(int zoomLevel)
     if (zoomLevel <= maximumZoomLevel() && zoomLevel >= minimumZoomLevel()) {
         m_zoom_level = zoomLevel;
         //FIXME: implement zoom
-        int base = 64 - 25; //50
+        int base = 16; //50
         int adjusted = base + zoomLevel;
         m_view->setIconSize(QSize(adjusted, adjusted));
         m_view->setGridSize(m_view->itemDelegate()->sizeHint(QStyleOptionViewItem(), QModelIndex()) + QSize(20, 20));
