@@ -29,6 +29,8 @@
 #include "file-item-proxy-filter-sort-model.h"
 
 #include "directory-view-widget.h"
+#include "global-settings.h"
+#include "directoryviewhelper.h"
 
 #include <QListView>
 #include <QTimer>
@@ -39,7 +41,7 @@ namespace DirectoryView {
 
 class IconViewDelegate;
 
-class PEONYCORESHARED_EXPORT IconView : public QListView, public DirectoryViewIface
+class PEONYCORESHARED_EXPORT IconView : public QListView, public DirectoryViewIface, public DirectoryViewIface2
 {
     friend class IconViewDelegate;
     friend class IconViewIndexWidget;
@@ -97,9 +99,11 @@ public:
     QRect visualRect(const QModelIndex &index) const override;
 
     bool getDelegateEditFlag();
+    bool isEnableMultiSelect();
 
 Q_SIGNALS:
     void zoomLevelChangedRequest(bool zoomIn);
+    void updateSelectStatus(bool status);
 
 public Q_SLOTS:
     //location
@@ -131,6 +135,12 @@ public Q_SLOTS:
     void resort();
     void reportViewDirectoryChanged();
     void clearIndexWidget();
+    void multiSelect();
+    void disableMultiSelect();
+    void setSearchKey(const QString &key);
+    void doMultiSelect(bool isMultiSlelect);
+
+    void setItemsVisible(bool visible) override;
 
 protected:
     /*!
@@ -149,6 +159,9 @@ protected:
 
     void mouseDoubleClickEvent(QMouseEvent *event) override;
 
+    void keyPressEvent(QKeyEvent *e) override;
+    void keyReleaseEvent(QKeyEvent *e) override;
+
     void paintEvent(QPaintEvent *e) override;
     void resizeEvent(QResizeEvent *e) override;
 
@@ -158,8 +171,11 @@ protected:
 
     void focusInEvent(QFocusEvent *e) override;
 
+    void startDrag(Qt::DropActions supportedActions) override;
+
     bool getIgnore_mouse_move_event() const;
     void setIgnore_mouse_move_event(bool ignore_mouse_move_event);
+    void releaseUnselect(bool select);
 
 private Q_SLOTS:
     void slotRename();
@@ -171,6 +187,8 @@ private:
     bool  m_ctrl_key_pressed;
     QTimer* m_renameTimer;
 
+    QTimer *m_touch_active_timer = nullptr;
+
     QModelIndex m_last_index;
 
     DirectoryViewProxyIface *m_proxy = nullptr;
@@ -192,9 +210,11 @@ private:
 
     bool m_delegate_editing = false;
 
+    bool m_multi_select =false;
     bool m_allow_set_index_widget = true;
 
     bool m_slider_bar_draging = false;
+    bool m_mouse_release_unselect = false;
 };
 
 //IconView2
@@ -236,13 +256,13 @@ public:
         return m_zoom_level;
     }
     int minimumZoomLevel() {
-        return 21;
+        return 41;
     }
     int maximumZoomLevel() {
         return 100;
     }
     bool supportZoom() {
-        return true;
+        return Peony::GlobalSettings::getInstance()->getValue(ZOOM_SLIDER_VISIBLE).toBool();
     }
 
 public Q_SLOTS:
@@ -271,6 +291,9 @@ public Q_SLOTS:
     void invertSelections() {
         m_view->invertSelections();
     }
+    void selectAll() {
+        m_view->selectAll();
+    }
     void scrollToSelection(const QString &uri) {
         m_view->scrollToSelection(uri);
     }
@@ -300,13 +323,19 @@ public Q_SLOTS:
     void setCurrentZoomLevel(int zoomLevel);
 
     void clearIndexWidget();
+    void multiSelect(){
+        m_view->multiSelect();
+    }
+    void disableMultiSelect(){
+        m_view->disableMultiSelect();
+    }
 
 private:
     IconView *m_view = nullptr;
     FileItemModel *m_model = nullptr;
     FileItemProxyFilterSortModel *m_proxy_model = nullptr;
 
-    int m_zoom_level = 25;
+    int m_zoom_level = 70;
 };
 
 }
