@@ -33,6 +33,8 @@
 
 #include "global-settings.h"
 
+#include "file-meta-info.h"
+#include "search-vfs-uri-parser.h"
 #include <QHeaderView>
 
 #include <QVBoxLayout>
@@ -52,26 +54,48 @@
 #include <QApplication>
 #include <QStyleHints>
 
+#include <QToolTip>
 #include <QDebug>
 #include <QToolTip>
 
 #include <QStyleOptionViewItem>
 
+#include <QStandardPaths>
+#include <QMessageBox>
+
+#include <QPainterPath>
+
+#define LISTVIEW_ITEM_BORDER_RADIUS 6
+
 using namespace Peony;
 using namespace Peony::DirectoryView;
 
 ListView::ListView(QWidget *parent) : QTreeView(parent)
-{
+{ 
+    m_touch_active_timer = new QTimer(this);
+    m_touch_active_timer->setInterval(2000);
+    m_touch_active_timer->setSingleShot(true);
+
+    setFrameShape(QFrame::NoFrame);
+
     // use scroll per pixel mode for calculate vertical scroll bar range.
     // see reUpdateScrollBar()
     setVerticalScrollMode(ScrollPerPixel);
-    setAttribute(Qt::WA_TranslucentBackground);
-    setStyle(Peony::DirectoryView::ListViewStyle::getStyle());
+    this->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    //setStyle(Peony::DirectoryView::ListViewStyle::getStyle());
 
     setAutoScroll(true);
     setAutoScrollMargin(100);
+    auto cornerWidget = new QWidget;
+    cornerWidget->setObjectName("_listview_corner");
+    cornerWidget->setAttribute(Qt::WA_AlwaysStackOnTop);
+    cornerWidget->setBackgroundRole(QPalette::Base);
+    cornerWidget->setAutoFillBackground(true);
+    setCornerWidget(cornerWidget);
 
-    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    installEventFilter(horizontalScrollBar());
+
+    setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
 
     setSelectionBehavior(QTreeView::SelectRows);
 
@@ -83,7 +107,30 @@ ListView::ListView(QWidget *parent) : QTreeView(parent)
 
     header()->setSectionResizeMode(QHeaderView::Interactive);
     header()->setSectionsMovable(true);
-    //header()->setStretchLastSection(true);
+    header()->setStretchLastSection(false);
+
+    if (this->topLevelWidget()->objectName() == "_peony_mainwindow") {
+        connect(header(), &QHeaderView::sectionClicked, this, [=](){
+            //update sort policy
+            auto settings = GlobalSettings::getInstance();
+            if (settings->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool()) {
+                settings->setValue(SORT_COLUMN, getSortType());
+                settings->setValue(SORT_ORDER, getSortOrder());
+            } else {
+                auto metaInfo = FileMetaInfo::fromUri(getDirectoryUri());
+                if (metaInfo) {
+                    metaInfo->setMetaInfoVariant(SORT_COLUMN, getSortType());
+                    metaInfo->setMetaInfoVariant(SORT_ORDER, getSortOrder());
+                } else {
+                    qCritical()<<"failed to set meta info"<<getDirectoryUri();
+                }
+            }
+        });
+    }
+
+    connect(header(), &QHeaderView::sectionResized, this, [=]{
+        m_header_section_resized_manually = true;
+    });
 
     setExpandsOnDoubleClick(false);
     setSortingEnabled(true);
@@ -93,9 +140,6 @@ ListView::ListView(QWidget *parent) : QTreeView(parent)
     setDragDropMode(QTreeView::DragDrop);
     setSelectionMode(QTreeView::ExtendedSelection);
 
-    //setAlternatingRowColors(true);
-
-    //setContextMenuPolicy(Qt::CustomContextMenu);
     m_renameTimer = new QTimer(this);
     m_renameTimer->setInterval(3000);
     m_editValid = false;
@@ -107,6 +151,35 @@ ListView::ListView(QWidget *parent) : QTreeView(parent)
     setMouseTracking(true);//追踪鼠标
 
     m_rubberBand = new QRubberBand(QRubberBand::Shape::Rectangle, this);
+
+    //FIXME: do not create proxy in view itself.
+    ListViewDelegate *delegate = new ListViewDelegate(this);
+    setItemDelegate(delegate);
+    connect(delegate, &ListViewDelegate::isEditing, this, [=](const bool &editing)
+    {
+        m_delegate_editing = editing;
+    });
+
+    //fix head indication sort type and order not change in preference file issue, releated to bug#92525,
+    connect(header(), &QHeaderView::sortIndicatorChanged, this, [=](int logicalIndex, Qt::SortOrder order)
+    {
+        m_proxy_model->manualUpdateExpectedSortInfo(logicalIndex, order);
+        //qDebug() << "sortIndicatorChanged:" <<logicalIndex<<order;
+        if (this->topLevelWidget()->objectName() == "_peony_mainwindow") {
+            if (GlobalSettings::getInstance()->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool()) {
+                Peony::GlobalSettings::getInstance()->setValue(SORT_COLUMN, logicalIndex);
+                Peony::GlobalSettings::getInstance()->setValue(SORT_ORDER, order);
+            } else {
+                auto metaInfo = FileMetaInfo::fromUri(m_current_uri);
+                if (!metaInfo) {
+                    qWarning()<<"no meta info"<<m_current_uri;
+                } else {
+                    metaInfo->setMetaInfoInt(SORT_COLUMN, logicalIndex);
+                    metaInfo->setMetaInfoInt(SORT_ORDER, order);
+                }
+            }
+        }
+    });
 }
 
 void ListView::scrollTo(const QModelIndex &index, QAbstractItemView::ScrollHint hint)
@@ -130,37 +203,30 @@ void ListView::bindModel(FileItemModel *sourceModel, FileItemProxyFilterSortMode
         return;
     m_model = sourceModel;
     m_proxy_model = proxyModel;
+
+    auto proxyModelSelectionModelHint = proxyModel->getSelectionModeHint();
+    if (proxyModelSelectionModelHint != NoSelection) {
+        setSelectionMode(proxyModelSelectionModelHint);
+    }
+
+    connect(proxyModel, &FileItemProxyFilterSortModel::setSelectionModeChanged, this, [=]{
+        auto proxyModelSelectionModelHint = proxyModel->getSelectionModeHint();
+        if (proxyModelSelectionModelHint != NoSelection) {
+            setSelectionMode(proxyModelSelectionModelHint);
+        }
+    });
+
     m_proxy_model->setSourceModel(m_model);
     setModel(proxyModel);
     //adjust columns layout.
     adjustColumnsSize();
 
-    //fix diffcult to unselect all item issue
-//    connect(this->selectionModel(), &QItemSelectionModel::currentColumnChanged, [=]
-//            (const QModelIndex &current, const QModelIndex &previous) {
-//        qDebug()<<"list view currentColumnChanged changed";
-//        if (getSelections().count() > 1 && !m_ctrl_key_pressed)
-//        {
-//            this->clearSelection();
-//            if (current.isValid())
-//                setCurrentIndex(current);
-//        }
-//    });
-
-//    connect(this->selectionModel(), &QItemSelectionModel::currentRowChanged, [=]
-//            (const QModelIndex &current, const QModelIndex &previous) {
-//        qDebug()<<"list view currentRowChanged changed";
-//        if (getSelections().count() > 1 && !m_ctrl_key_pressed)
-//        {
-//            this->clearSelection();
-//            if (current.isValid())
-//                setCurrentIndex(current);
-//        }
-//    });
-
     //edit trigger
     connect(this->selectionModel(), &QItemSelectionModel::selectionChanged, [=](const QItemSelection &selection, const QItemSelection &deselection) {
-        qDebug()<<"list view selection changed";
+        //qDebug()<<"list view selection changed"<<m_delegate_editing;
+        //continue to fix bug#89540，98951
+        if (m_delegate_editing)
+            return;
         auto currentSelections = selection.indexes();
 
         for (auto index : deselection.indexes()) {
@@ -194,6 +260,12 @@ void ListView::bindModel(FileItemModel *sourceModel, FileItemProxyFilterSortMode
 void ListView::keyPressEvent(QKeyEvent *e)
 {
     QTreeView::keyPressEvent(e);
+   //if(e->key() == Qt::Key_Down||e->key() == Qt::Key_Up)
+    //{
+     //   QStringList selections = getSelections();
+      //  if(selections.size() == 1)
+       //     this->scrollToSelection(selections.at(0));
+  //  }
     switch (e->key()) {
     case Qt::Key_Control:
         m_ctrl_key_pressed = true;
@@ -215,6 +287,16 @@ void ListView::keyPressEvent(QKeyEvent *e)
         }
         break;
     }
+    case Qt::Key_Home:
+    case Qt::Key_End:
+    case Qt::Key_PageUp:
+    case Qt::Key_PageDown: {
+        //fix bug#160799, can not update scrollBar to show selected file issue
+        if (!selectedIndexes().isEmpty()) {
+            QTreeView::scrollTo(selectedIndexes().first());
+        }
+        break;
+    }
     default:
         break;
     }
@@ -228,7 +310,14 @@ void ListView::keyReleaseEvent(QKeyEvent *e)
 }
 
 void ListView::mousePressEvent(QMouseEvent *e)
-{
+{ 
+    bool singleClicked = qApp->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick);
+    if (singleClicked) {
+        if (!m_touch_active_timer->isActive()) {
+            m_touch_active_timer->start(1100);
+        }
+    }
+
     if (e->button() == Qt::RightButton) {
         if (this->state() == QTreeView::EditingState) {
             if (indexWidget(indexAt(e->pos())))
@@ -239,37 +328,46 @@ void ListView::mousePressEvent(QMouseEvent *e)
         return;
     }
 
-    m_isLeftButtonPressed = true;
     m_rubberBand->hide();
     m_lastPressedLogicPoint = e->pos() + QPoint(horizontalOffset(), verticalOffset());
 
     auto index = indexAt(e->pos());
     bool isIndexSelected = selectedIndexes().contains(index);
 
+    if (isEnableMultiSelect() && index.isValid()) {
+        m_mouse_release_unselect = isIndexSelected;
+    } else {
+        m_mouse_release_unselect = false;
+    }
+
+    if (m_mouse_release_unselect) {
+        this->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select|QItemSelectionModel::Rows);
+    }
+
+    if(getSelections().count()>1) {
+        multiSelect();
+    }
+
     m_editValid = true;
     QTreeView::mousePressEvent(e);
 
     auto visualRect = this->visualRect(index);
     auto sizeHint = itemDelegate()->sizeHint(viewOptions(), index);
     auto validRect = QRect(visualRect.topLeft(), sizeHint);
-    if (!validRect.contains(e->pos())) {
+    if (!isEnableMultiSelect() && !validRect.contains(e->pos())) {
         if (isIndexSelected) {
             clearSelection();
             setCurrentIndex(index);
         }
         this->setState(QAbstractItemView::DragSelectingState);
     }
-    //comment to fix can not enter rename issue
-//    else if (isIndexSelected) {
-//        return;
-//    }
 
     //if click left button at blank space, it should select nothing
     //qDebug() << "indexAt(e->pos()):" <<indexAt(e->pos()).column() << indexAt(e->pos()).row() <<indexAt(e->pos()).isValid();
-    if(e->button() == Qt::LeftButton && (!indexAt(e->pos()).isValid()) )
+    if(!indexAt(e->pos()).isValid())
     {
         this->clearSelection();
-        //this->clearFocus();
+        disableMultiSelect();
         return;
     }
 
@@ -294,7 +392,10 @@ void ListView::mousePressEvent(QMouseEvent *e)
             }
         }
         //qDebug()<<m_renameTimer->remainingTime()<<m_editValid<<all_index_in_same_row<<qApp->styleHints()->mouseDoubleClickInterval();
-        if(m_renameTimer->remainingTime()>=0 && m_renameTimer->remainingTime() <= 3000 - qApp->styleHints()->mouseDoubleClickInterval()
+        //优化文件点击策略，提升用户体验，关联bug#125368
+        //在双击时间间隔内，如果未触发双击事件，但是点击的是同一个有效图标，触发双击事件
+        //系统默认双击间隔为400ms, 策略为[0,400]，触发双击，(400,3000)触发重命名
+        if(m_renameTimer->remainingTime()> 0 && m_renameTimer->remainingTime() < 3000 - qApp->styleHints()->mouseDoubleClickInterval()
                 && indexAt(e->pos()) == m_last_index && m_last_index.isValid() && m_editValid == true && all_index_in_same_row)
         {
             slotRename();
@@ -309,7 +410,6 @@ void ListView::mouseReleaseEvent(QMouseEvent *e)
 {
     QTreeView::mouseReleaseEvent(e);
     m_rubberBand->hide();
-    m_isLeftButtonPressed = false;
 }
 
 void ListView::mouseMoveEvent(QMouseEvent *e)
@@ -317,8 +417,8 @@ void ListView::mouseMoveEvent(QMouseEvent *e)
     QModelIndex itemIndex = indexAt(e->pos());
     if (!itemIndex.isValid()) {
         if (QToolTip::isVisible()) {
-             QToolTip::hideText();
-         }
+            QToolTip::hideText();
+        }
     } else {
         if (0 != itemIndex.column() && QToolTip::isVisible()) {
             QToolTip::hideText();
@@ -327,6 +427,11 @@ void ListView::mouseMoveEvent(QMouseEvent *e)
 
     QTreeView::mouseMoveEvent(e);
 
+    // fix #115124, drag selection can not trigger auto scroll in view.
+    if (e->buttons() & Qt::LeftButton && !this->viewport()->rect().adjusted(0, autoScrollMargin(), 0, -autoScrollMargin()).contains(e->pos())) {
+        doAutoScroll();
+    }
+
     if (e->buttons() & Qt::LeftButton) {
         auto pos = e->pos();
         auto offset = QPoint(horizontalOffset(), verticalOffset());
@@ -344,6 +449,14 @@ void ListView::mouseMoveEvent(QMouseEvent *e)
     } else {
         m_rubberBand->hide();
     }
+
+    // fix #115124, drag selection can not trigger auto scroll in view.
+    if (e->buttons() & Qt::LeftButton && !this->viewport()->rect().adjusted(0, autoScrollMargin(), 0, -autoScrollMargin()).contains(e->pos())) {
+        doAutoScroll();
+    }
+
+    if(getSelections().count()>1)
+        multiSelect();
 }
 
 void ListView::mouseDoubleClickEvent(QMouseEvent *event)
@@ -366,6 +479,13 @@ void ListView::dragEnterEvent(QDragEnterEvent *e)
     auto action = m_ctrl_key_pressed ? Qt::CopyAction : Qt::MoveAction;
     qDebug()<<"dragEnterEvent()" <<action <<m_ctrl_key_pressed;
     if (e->mimeData()->hasUrls()) {
+        if (FileUtils::containsStandardPath(e->mimeData()->urls())) {
+            e->ignore();
+            if (this == e->source()) {
+                clearSelection();
+            }
+            return;
+        }
         e->setDropAction(action);
         e->accept();
     }
@@ -430,9 +550,25 @@ void ListView::dropEvent(QDropEvent *e)
         action = Qt::TargetMoveAction;
     }
 
+    //Do not allow dragging files to file manager when searching
+    //related to bug#107063,118004
+    if (m_current_uri.startsWith("search://") || m_current_uri.startsWith("favorite://")) {
+        QMessageBox::warning(this, tr("warn"), tr("This operation is not supported."));
+        return;
+    }
+
     auto proxy_index = indexAt(e->pos());
     auto index = m_proxy_model->mapToSource(proxy_index);
     qDebug()<<"dropEvent" <<action <<m_ctrl_key_pressed <<indexAt(e->pos()).isValid();
+
+    QString username = QStandardPaths::writableLocation(QStandardPaths::HomeLocation).split("/").last();
+    QString boxpath = "file://"+QStandardPaths::writableLocation(QStandardPaths::HomeLocation)+"/.box";
+    QString oldboxpath = "file://box/"+username;
+
+    if(m_current_uri == boxpath || m_current_uri == oldboxpath || m_current_uri == "filesafe:///"){
+        return;
+    }
+
     //move in current path, do nothing
     if (e->source() == this)
     {
@@ -459,6 +595,9 @@ void ListView::resizeEvent(QResizeEvent *e)
         m_last_size = size();
         adjustColumnsSize();
     }
+    if (state() == QTreeView::EditingState && qApp->property("tabletMode").toBool()) {
+        scrollTo(currentIndex());
+    }
 }
 
 /*!
@@ -482,23 +621,28 @@ void ListView::reUpdateScrollBar()
     if (model()->rowCount() == 0) {
         return;
     }
-
     int totalHeight = 0;
     int rowCount = model()->rowCount();
-    for (int row = 0; row < rowCount; row++) {
-        auto index = model()->index(row, 0);
-        totalHeight += sizeHintForIndex(index).height();
-    }
+    int rowHeight = itemDelegate()->sizeHint(QStyleOptionViewItem(), QModelIndex()).height();
+    totalHeight = rowCount * rowHeight;
+//    for (int row = 0; row < rowCount; row++) {
+//        auto index = model()->index(row, 0);
+//        totalHeight += sizeHintForIndex(index).height();
+//    }
 
+    int currentScrollBarValue = verticalScrollBar()->value();
     verticalScrollBar()->setSingleStep(iconSize().height());
     verticalScrollBar()->setPageStep(viewport()->height() - header()->height());
     verticalScrollBar()->setRange(0, totalHeight + header()->height() + 100 - viewport()->height());
+    verticalScrollBar()->setValue(currentScrollBarValue);
 }
 
 void ListView::updateGeometries()
 {
+    setUpdatesEnabled(false);
     QTreeView::updateGeometries();
     reUpdateScrollBar();
+    setUpdatesEnabled(true);
 }
 
 void ListView::wheelEvent(QWheelEvent *e)
@@ -519,12 +663,11 @@ void ListView::focusInEvent(QFocusEvent *e)
         } else {
             QTreeView::scrollTo(selectedIndexes().first(), QTreeView::EnsureVisible);
             reUpdateScrollBar();
-            auto selections = selectedIndexes();
+            auto selections = getSelections();
             clearSelection();
+            //use uri rather than index, to fix crash bug#68788, 96145
             QTimer::singleShot(100, this, [=](){
-                for (auto index : selections) {
-                    selectionModel()->select(index, QItemSelectionModel::Select);
-                }
+                setSelections(selections);
             });
         }
     }
@@ -559,10 +702,12 @@ void ListView::startDrag(Qt::DropActions flags)
         pixmap.fill(Qt::transparent);
         pixmap.setDevicePixelRatio(scale);
         QPainter painter(&pixmap);
+        quint64 count = 0;
         for (auto index : indexes) {
             painter.save();
             painter.translate(indexRectHash.value(index).topLeft() - rect.boundingRect().topLeft());
             //painter.translate(-rect.boundingRect().topLeft());
+            painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
             QStyleOptionViewItem opt = viewOptions();
             auto viewItemDelegate = static_cast<ListViewDelegate *>(itemDelegate());
             viewItemDelegate->initIndexOption(&opt, index);
@@ -571,7 +716,24 @@ void ListView::startDrag(Qt::DropActions flags)
             opt.rect.moveTo(0, 0);
             opt.state |= QStyle::State_Selected;
             painter.setOpacity(0.8);
-            QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, &painter);
+
+            count++;
+            if(count == 1){
+                QPainterPath leftRoundedRegion;
+                leftRoundedRegion.setFillRule(Qt::WindingFill);
+                leftRoundedRegion.addRoundedRect(opt.rect, LISTVIEW_ITEM_BORDER_RADIUS, LISTVIEW_ITEM_BORDER_RADIUS);
+                leftRoundedRegion.addRect(opt.rect.adjusted(LISTVIEW_ITEM_BORDER_RADIUS, 0, 0, 0));
+                painter.setClipPath(leftRoundedRegion);
+            }else if(count == 4){
+                QPainterPath rightRoundedRegion;
+                rightRoundedRegion.setFillRule(Qt::WindingFill);
+                rightRoundedRegion.addRoundedRect(opt.rect, LISTVIEW_ITEM_BORDER_RADIUS, LISTVIEW_ITEM_BORDER_RADIUS);
+                rightRoundedRegion.addRect(opt.rect.adjusted(0, 0, -LISTVIEW_ITEM_BORDER_RADIUS, 0));
+                painter.setClipPath(rightRoundedRegion);
+                count = 0;
+            }
+
+            QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, &painter, this);
             painter.restore();
         }
 
@@ -582,13 +744,22 @@ void ListView::startDrag(Qt::DropActions flags)
     }
 }
 
+void ListView::setSelection(const QRect &rect, QItemSelectionModel::SelectionFlags command)
+{
+    // fix #I7GWAX【设计走查】【文档管理器】列表视图框选文件时，被框选的文件，其以下的文件会被自动选中
+    QRect adjustedRect = rect;
+    adjustedRect.setLeft(0);
+    QTreeView::setSelection(adjustedRect, command);
+}
+
 void ListView::slotRename()
 {
     //special path like trash path not allow rename
     if (getDirectoryUri().startsWith("trash://")
         || getDirectoryUri().startsWith("recent://")
         || getDirectoryUri().startsWith("favorite://")
-        || getDirectoryUri().startsWith("search://"))
+        || getDirectoryUri().startsWith("search://")
+        || getDirectoryUri().startsWith("network://"))
         return;
 
     //standardPaths not allow rename
@@ -601,7 +772,8 @@ void ListView::slotRename()
     qDebug()<<"slotRename"<<m_editValid;
     QTimer::singleShot(300, this, [&]() {
         qDebug()<<"singleshot"<<m_editValid;
-        if(m_editValid) {
+        //fix bug#98951, click edit box boarder will reenter edit issue
+        if(m_editValid &&  ! m_delegate_editing) {
             m_renameTimer->stop();
             setIndexWidget(m_last_index, nullptr);
             edit(m_last_index);
@@ -628,20 +800,30 @@ void ListView::reportViewDirectoryChanged()
 
 void ListView::adjustColumnsSize()
 {
+    int columnSize = 0;
+
     if (!model())
         return;
 
     if (model()->columnCount() == 0)
         return;
 
+    // try fixing #155969, list view can not save columns' state while resizing.
+    if (m_header_section_resized_manually)
+        return;
+
+    // do not trigger header's sectionResized() signal. related to #155969.
+    header()->blockSignals(true);
     header()->resizeSections(QHeaderView::ResizeToContents);
 
     int rightPartsSize = 0;
     for (int column = 1; column < model()->columnCount(); column++) {
-        int columnSize = header()->sectionSize(column);
+        columnSize = header()->sectionSize(column);
         rightPartsSize += columnSize;
     }
 
+    rightPartsSize += columnSize;
+
     //set column 0 minimum width, fix header icon overlap with name issue
     if(columnWidth(0) < columnWidth(1))
         setColumnWidth(0, columnWidth(1));
@@ -653,10 +835,37 @@ void ListView::adjustColumnsSize()
         for (int column = 1; column < model()->columnCount(); column++) {
             setColumnWidth(column, size);
         }
+        header()->blockSignals(false);
         return;
     }
 
     header()->resizeSection(0, this->viewport()->width() - rightPartsSize);
+    header()->resizeSection(model()->columnCount() - 1, viewport()->width() - 20 - header()->sectionSize(0) - header()->sectionSize(1) - header()->sectionSize(2));
+    header()->blockSignals(false);
+}
+
+void ListView::multiSelect()
+{
+    if (selectionMode() == MultiSelection) {
+        return;
+    }
+    if (GlobalSettings::getInstance()->getValue(MULTI_SELECT).toBool()) {
+        m_multi_select = true;
+    }
+    setSelectionMode(MultiSelection);
+    viewport()->update(viewport()->rect());
+    Q_EMIT updateSelectStatus(m_multi_select);
+}
+
+void ListView::disableMultiSelect()
+{
+    if (selectionMode() == ExtendedSelection) {
+        return;
+    }
+    m_multi_select = false;
+    setSelectionMode(ExtendedSelection);
+    viewport()->update(viewport()->rect());
+    Q_EMIT updateSelectStatus(m_multi_select);
 }
 
 void ListView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
@@ -680,6 +889,13 @@ const QString ListView::getDirectoryUri()
 void ListView::setDirectoryUri(const QString &uri)
 {
     m_current_uri = uri;
+    if (m_current_uri.startsWith("search://")) {
+        QString nameRegexp = SearchVFSUriParser::getSearchUriNameRegexp(uri);
+        setSearchKey(nameRegexp);
+    } else {
+        setSearchKey("");
+    }
+
 }
 
 const QStringList ListView::getSelections()
@@ -715,15 +931,23 @@ const QStringList ListView::getAllFileUris()
     return m_proxy_model->getAllFileUris();
 }
 
-QRect ListView::visualRect(const QModelIndex &index) const
+int ListView::getCurrentCheckboxColumn()
 {
-    auto rect = QTreeView::visualRect(index);
-    //comment to fix rename state not show icon issue
-//    if (index.column() == 0) {
-//        rect.setX(0);
-//    }
+    int section =header()->sectionViewportPosition(3);
+    int viewportWidth =viewport()->width()+viewport()->x();
+    int selectBox = 3;
 
-    return rect;
+    for(int i=1;i<=model()->columnCount()-1;i++)
+    {
+
+        section =header()->sectionViewportPosition(i);
+        if(section+32>=viewportWidth)
+        {
+            selectBox = i-1;
+            break;
+        }
+    }
+    return selectBox;
 }
 
 void ListView::open(const QStringList &uris, bool newWindow)
@@ -755,6 +979,8 @@ void ListView::invertSelections()
     const QItemSelection currentSelection = selectionModel->selection();
     this->selectAll();
     selectionModel->select(currentSelection, QItemSelectionModel::Deselect);
+
+    viewport()->update();
 }
 
 void ListView::scrollToSelection(const QString &uri)
@@ -769,28 +995,42 @@ void ListView::setCutFiles(const QStringList &uris)
     return;
 }
 
+bool ListView::getDelegateEditFlag()
+{
+    return m_delegate_editing;
+}
+
+void ListView::setItemsVisible(bool visible)
+{
+    viewport()->setVisible(visible);
+}
+
 int ListView::getSortType()
 {
-    int type = m_proxy_model->sortColumn();
+    int type = m_proxy_model->expectedSortType();
     return type<0? 0: type;
 }
 
 void ListView::setSortType(int sortType)
 {
     //fix indicator not agree with actual sort order issue, link to bug#71475
-    header()->setSortIndicator(sortType, Qt::SortOrder(getSortOrder()));
+    QTimer::singleShot(0, this, [=]{
+        header()->setSortIndicator(sortType, Qt::SortOrder(getSortOrder()));
+    });
     m_proxy_model->sort(sortType, Qt::SortOrder(getSortOrder()));
 }
 
 int ListView::getSortOrder()
 {
-    return m_proxy_model->sortOrder();
+    return m_proxy_model->expectedSortOrder();
 }
 
 void ListView::setSortOrder(int sortOrder)
 {
     //fix indicator not agree with actual sort order issue, link to bug#71475
-    header()->setSortIndicator(getSortType(), Qt::SortOrder(sortOrder));
+    QTimer::singleShot(0, this, [=]{
+        header()->setSortIndicator(getSortType(), Qt::SortOrder(sortOrder));
+    });
     m_proxy_model->sort(getSortType(), Qt::SortOrder(sortOrder));
 }
 
@@ -798,10 +1038,25 @@ void ListView::editUri(const QString &uri)
 {
     setState(QTreeView::NoState);
     auto origin = FileUtils::getOriginalUri(uri);
-    setIndexWidget(m_proxy_model->indexFromUri(origin), nullptr);
+    if(uri.startsWith("mtp://"))/* Fixbug#82649:在手机内部存储里新建文件/文件夹时，名称不是可编辑状态,都是默认文件名/文件夹名 */
+        origin = uri;
+    QModelIndex index =m_proxy_model->indexFromUri(origin);
+    setIndexWidget(index, nullptr);
     //注释该行以修复bug:#60474
 //    QTreeView::scrollTo(m_proxy_model->indexFromUri(origin));
-    edit(m_proxy_model->indexFromUri(origin));
+    edit(index);
+    //fix bug#70769, edit box overlapped with status bar issue
+    //qDebug() <<"editUri row"<<m_proxy_model->rowCount()<<index.row();
+    if(index.row() >= m_proxy_model->rowCount()-1) {
+        reUpdateScrollBar();
+        QTreeView::scrollToBottom();
+        QTimer::singleShot(300, this, [=]{
+            if (qApp->property("tabletMode").toBool()) {
+                reUpdateScrollBar();
+                QTreeView::scrollToBottom();
+            }
+        });
+    }
 }
 
 void ListView::editUris(const QStringList uris)
@@ -810,6 +1065,11 @@ void ListView::editUris(const QStringList uris)
     //implement batch rename.
 }
 
+bool ListView::isEnableMultiSelect()
+{
+    return m_multi_select;
+}
+
 void ListView::keyboardSearch(const QString &key)
 {
     // ensure current index is index in display name column
@@ -835,14 +1095,38 @@ void ListView::keyboardSearch(const QString &key)
     }
 }
 
+void ListView::setSearchKey(const QString &key)
+{
+    auto viewItemDelegate = static_cast<ListViewDelegate *>(itemDelegate());
+    viewItemDelegate->setSearchKeyword(key);
+}
+
+void ListView::doMultiSelect(bool isMultiSlelect)
+{
+    if (isMultiSlelect) {
+        multiSelect();
+    } else {
+        disableMultiSelect();
+    }
+
+    viewport()->update();
+}
+
 //List View 2
 ListView2::ListView2(QWidget *parent) : DirectoryViewWidget(parent)
 {
     auto layout = new QVBoxLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
+    layout->setObjectName("_listview2_layout");
+    setBackgroundRole(QPalette::Base);
+    setAutoFillBackground(true);
     m_view = new ListView(this);
 
+    DirectoryViewHelper * viewHelper = DirectoryViewHelper::globalInstance();
+    viewHelper->addListViewWithDirectoryViewWidget(m_view, this);
+    connect(m_view, &ListView::updateSelectStatus, viewHelper, &DirectoryViewHelper::updateSelectStatus);
+
     int defaultZoomLevel = GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ZOOM_LEVEL).toInt();
     if (defaultZoomLevel >= minimumZoomLevel() && defaultZoomLevel <= maximumZoomLevel())
         m_zoom_level = defaultZoomLevel;
@@ -860,6 +1144,15 @@ ListView2::~ListView2()
 
 void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *proxyModel)
 {
+    auto layout = findChild<QVBoxLayout *>("_listview2_layout");
+    bool ok = false;
+    if (parentWidget()) {
+        int statusBarHeight = parentWidget()->property("statusBarHeight").toInt(&ok);
+        if (ok) {
+            layout->setContentsMargins(0, 0, 0, statusBarHeight);
+        }
+    }
+
     disconnect(m_model);
     disconnect(m_proxy_model);
     m_model = model;
@@ -869,18 +1162,35 @@ void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
 
     m_view->bindModel(model, proxyModel);
     connect(m_model, &FileItemModel::selectRequest, this, &DirectoryViewWidget::updateWindowSelectionRequest);
+    connect(m_model,&FileItemModel::signal_itemAdded, this, [=](const QString& uri){
+        Q_EMIT this->signal_itemAdded(uri);
+    });
     connect(model, &FileItemModel::findChildrenFinished, this, &DirectoryViewWidget::viewDirectoryChanged);
     //connect(m_model, &FileItemModel::updated, m_view, &ListView::resort);
+    connect(m_model, &FileItemModel::updated, m_view->viewport(), QOverload<>::of(&QWidget::update));
 
-    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged,
-            this, &DirectoryViewWidget::viewSelectionChanged);
+    connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged, this, [=]() {
+        Q_EMIT viewSelectionChanged();
+    });
 
     connect(m_view, &ListView::activated, this, [=](const QModelIndex &index) {
+        if (m_view->m_touch_active_timer->isActive()) {
+            auto costTime = m_view->m_touch_active_timer->interval() - m_view->m_touch_active_timer->remainingTime();
+            if (costTime > qApp->doubleClickInterval()) {
+                m_view->m_touch_active_timer->stop();
+                return;
+            }
+        }
+
         //when selections is more than 1, let mainwindow to process
         if (getSelections().count() != 1)
             return;
         auto uri = getSelections().first();
-        Q_EMIT this->viewDoubleClicked(uri);
+        if(!m_view->isEnableMultiSelect()) {
+            Q_EMIT this->viewDoubleClicked(uri);
+        }
+
+        m_view->m_touch_active_timer->stop();
     });
 
     //FIXME: how about multi-selection?
@@ -912,8 +1222,9 @@ void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
 
         //NOTE: we have to ensure that we have cleared the
         //selection if menu request at blank pos.
-        QTimer::singleShot(1, [=]() {
-            Q_EMIT this->menuRequest(QCursor::pos());
+        QTimer::singleShot(1, this, [=]() {
+            m_view->m_touch_active_timer->stop();
+            Q_EMIT this->menuRequest(mapToGlobal(pos + m_view->header()->geometry().bottomLeft()));
         });
     });
 
@@ -926,7 +1237,9 @@ void ListView2::bindModel(FileItemModel *model, FileItemProxyFilterSortModel *pr
 
     connect(m_model, &FileItemModel::findChildrenFinished, this, [=]() {
         if (m_need_resize_header) {
-            m_view->adjustColumnsSize();
+            QTimer::singleShot(0, this, [=]{
+                m_view->adjustColumnsSize();
+            });
         }
         m_need_resize_header = false;
     });
