@@ -22,12 +22,14 @@
 
 #ifndef LISTVIEW_H
 #define LISTVIEW_H
-
+#include <QObject>
 #include <QTreeView>
 #include "directory-view-plugin-iface.h"
 #include "peony-core_global.h"
 
 #include "directory-view-widget.h"
+#include "global-settings.h"
+#include "directoryviewhelper.h"
 
 #include <QTimer>
 
@@ -43,9 +45,10 @@ namespace DirectoryView {
  * \todo
  * improve extend selection actions.
  */
-class PEONYCORESHARED_EXPORT ListView : public QTreeView, public DirectoryViewIface
+class PEONYCORESHARED_EXPORT ListView : public QTreeView, public DirectoryViewIface, public DirectoryViewIface2
 {
     friend class ListView2;
+    friend class ListViewDelegate;
     Q_OBJECT
 public:
     explicit ListView(QWidget *parent = nullptr);
@@ -77,10 +80,20 @@ public:
     //children
     const QStringList getAllFileUris() override;
 
-    QRect visualRect(const QModelIndex &index) const override;
+    int getCurrentCheckboxColumn();
+
+    /**
+     * @brief 定制版本需要显示多选框
+     * @return
+     */
+    bool isEnableMultiSelect();
+    bool getDelegateEditFlag();
+
+    void setItemsVisible(bool visible) override;
 
 Q_SIGNALS:
     void zoomLevelChangedRequest(bool zoomIn);
+    void updateSelectStatus(bool status);
 
 public Q_SLOTS:
     //location
@@ -107,13 +120,23 @@ public Q_SLOTS:
     void editUri(const QString &uri) override;
     void editUris(const QStringList uris) override;
 
+    void keyboardSearch(const QString &key) override;
+
     void resort();
     void reportViewDirectoryChanged();
     void adjustColumnsSize();
+    void multiSelect();
+    void disableMultiSelect();
+
+    void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles);
+    void setSearchKey(const QString &key);
+
+    void doMultiSelect(bool isMultiSlelect);
 
 protected:
     void mousePressEvent(QMouseEvent *e) override;
     void mouseReleaseEvent(QMouseEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
     void mouseDoubleClickEvent(QMouseEvent *event) override;
 
     void keyPressEvent(QKeyEvent *e) override;
@@ -126,11 +149,19 @@ protected:
     void resizeEvent(QResizeEvent *e) override;
 
     void updateGeometries() override;
+    void reUpdateScrollBar();
 
     void wheelEvent (QWheelEvent *e) override;
 
+    void focusInEvent(QFocusEvent *e) override;
+
+    void startDrag(Qt::DropActions flags) override;
+
+    void setSelection(const QRect &rect, QItemSelectionModel::SelectionFlags command) override;
+
 private Q_SLOTS:
     void slotRename();
+
 private:
     FileItemModel *m_model = nullptr;
     FileItemProxyFilterSortModel *m_proxy_model = nullptr;
@@ -138,6 +169,12 @@ private:
     QTimer* m_renameTimer;
     bool  m_editValid;
     bool  m_ctrl_key_pressed;
+    bool  m_delegate_editing = false;
+
+    QRubberBand *m_rubberBand;
+    QPoint m_lastPressedLogicPoint;
+    QRect m_logicRect;
+    bool m_isLeftButtonPressed = false;
 
     QModelIndex m_last_index;
 
@@ -147,7 +184,12 @@ private:
 
     QSize m_last_size;
 
-    const int BOTTOM_STATUS_MARGIN = 36;
+    const int BOTTOM_STATUS_MARGIN = 200;
+
+    QTimer *m_touch_active_timer = nullptr;
+    bool m_multi_select = false;
+    bool m_mouse_release_unselect = false;
+    bool m_header_section_resized_manually = false;
 };
 
 //ListView2
@@ -192,11 +234,11 @@ public:
         return 0;
     }
     int maximumZoomLevel() {
-        return 20;
+        return 40;
     }
 
     bool supportZoom() {
-        return true;
+        return Peony::GlobalSettings::getInstance()->getValue(ZOOM_SLIDER_VISIBLE).toBool();
     }
 
 public Q_SLOTS:
@@ -226,6 +268,9 @@ public Q_SLOTS:
     void invertSelections() {
         m_view->invertSelections();
     }
+    void selectAll() {
+        m_view->selectAll();
+    }
     void scrollToSelection(const QString &uri) {
         m_view->scrollToSelection(uri);
     }
@@ -254,12 +299,21 @@ public Q_SLOTS:
 
     void clearIndexWidget();
 
+    void multiSelect(){
+        m_view->multiSelect();
+    }
+    void disableMultiSelect(){
+        m_view->disableMultiSelect();
+    }
+
+    void repaintView();
+
 private:
     ListView *m_view = nullptr;
     FileItemModel *m_model = nullptr;
     FileItemProxyFilterSortModel *m_proxy_model = nullptr;
 
-    int m_zoom_level = 0;
+    int m_zoom_level = 24;
     bool m_need_resize_header;
 };
 
