@@ -23,10 +23,13 @@
 #include "path-edit.h"
 #include "path-bar-model.h"
 #include "path-completer.h"
+#include "file-utils.h"
 
 #include <QKeyEvent>
 #include <QAction>
 #include <QUrl>
+#include <QAbstractItemView>
+#include <QVector4D>
 
 #include <QDebug>
 
@@ -39,12 +42,25 @@ PathEdit::PathEdit(QWidget *parent) : QLineEdit(parent)
     m_model = new PathBarModel(this);
     m_completer = new PathCompleter(this);
     m_completer->setModel(m_model);
+    //m_completer->setCompletionMode(QCompleter::CompletionMode::UnfilteredPopupCompletion);
+
+    m_completer->popup()->setAttribute(Qt::WA_TranslucentBackground);
+
+    m_completer->popup()->setProperty("useCustomShadow", true);
+    m_completer->popup()->setProperty("customShadowDarkness", 0.5);
+    m_completer->popup()->setProperty("customShadowWidth", 20);
+    m_completer->popup()->setProperty("customShadowRadius", QVector4D(6, 6, 6, 6));
+    m_completer->popup()->setProperty("customShadowMargins", QVector4D(20, 20, 20, 20));
+
     m_completer->setCaseSensitivity(Qt::CaseInsensitive);
 
     setLayoutDirection(Qt::LeftToRight);
 
-    QAction *goToAction = new QAction(QIcon::fromTheme("forward"), tr("Go To"), this);
+    QAction *goToAction = new QAction(QIcon::fromTheme("ukui-end-symbolic", QIcon(":/icons/ukui-end-symbolic")), tr("Go To"), this);
     addAction(goToAction, QLineEdit::TrailingPosition);
+    goToAction->setProperty("isWindowButton", 1);
+    goToAction->setProperty("useIconHighlightEffect", 2);
+    goToAction->setProperty("isIcon", true);
 
     connect(goToAction, &QAction::triggered, this, &QLineEdit::returnPressed);
 
@@ -56,13 +72,38 @@ PathEdit::PathEdit(QWidget *parent) : QLineEdit(parent)
             this->editCancelled();
             return;
         } else {
-            qDebug()<<"change dir request"<<this->text();
             Q_EMIT this->uriChangeRequest(this->text());
             //NOTE: we have send the signal for location change.
             //so we can use editCancelled hide the path edit.
             this->editCancelled();
         }
     });
+
+    connect(this, &PathEdit::textChanged, this, [=](){
+        if (!isVisible())
+            return;
+
+        auto uri = text();
+        if (uri.endsWith("/")) {
+            m_model->setRootUri(uri);
+        }
+//        auto parentUri = FileUtils::getParentUri(uri);
+//        if (parentUri == m_model->currentDirUri() && !m_model->stringList().isEmpty())
+//            return;
+
+//        if (uri.endsWith("/")) {
+//            //m_model->setRootUri(uri);
+//        } else {
+//            m_model->setRootUri(parentUri);
+//        }
+    });
+
+    connect(m_model, &PathBarModel::updated, this, [=](){
+        if (m_model->stringList().isEmpty())
+            return;
+
+        m_completer->complete();
+    });
 }
 
 void PathEdit::setUri(const QString &uri)
@@ -74,15 +115,20 @@ void PathEdit::setUri(const QString &uri)
 void PathEdit::focusOutEvent(QFocusEvent *e)
 {
     QLineEdit::focusOutEvent(e);
-    if (! m_right_click)
+    if (! m_right_click) {
         Q_EMIT editCancelled();
+    }
+    m_right_click = false;
 }
 
 void PathEdit::focusInEvent(QFocusEvent *e)
 {
     QLineEdit::focusInEvent(e);
-    m_model->setRootUri(this->text());
-    m_completer->complete();
+}
+
+void PathEdit::cancelList()
+{
+    m_completer->activated(m_completer->currentIndex());
 }
 
 void PathEdit::keyPressEvent(QKeyEvent *e)
@@ -96,7 +142,6 @@ void PathEdit::keyPressEvent(QKeyEvent *e)
 void PathEdit::mousePressEvent(QMouseEvent *e)
 {
     QLineEdit::mousePressEvent(e);
-    //qDebug() << "mousePressEvent"<<e->button();
     if (e->button() == Qt::RightButton)
         m_right_click = true;
     else
