@@ -27,7 +27,9 @@
 #include "file-utils.h"
 #include "global-settings.h"
 #include "file-count-operation.h"
+#include "file-operation-utils.h"
 
+#include <QGSettings>
 #include <QFormLayout>
 #include <QPushButton>
 #include <QLineEdit>
@@ -46,15 +48,7 @@ QString RecentAndTrashPropertiesPage::getIconName() {
         return "application-x-desktop";
 
     QString realPath;
-    bool startWithTrash = m_fileInfo->uri().startsWith("trash:///");
-
-    if (startWithTrash) {
-        realPath = QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first()
-                + "/.local/share/Trash/files/"
-                + m_fileInfo->displayName();
-    } else {
-        realPath = m_fileInfo->targetUri();
-    }
+    realPath = m_fileInfo->targetUri();
 
     auto _desktop_file = g_desktop_app_info_new_from_filename(QUrl(realPath).path().toUtf8().constData());
     if (_desktop_file) {
@@ -81,6 +75,11 @@ void RecentAndTrashPropertiesPage::init()
         delete m_futureWatcher;
         m_futureWatcher = nullptr;
     }
+
+    auto targetFileInfo = FileInfo::fromUri(m_fileInfo.get()->targetUri());
+    FileInfoJob j(targetFileInfo);
+    j.querySync();
+
     m_layout = new QFormLayout(this);
     m_layout->setRowWrapPolicy(QFormLayout::WrapLongRows);
     m_layout->setFormAlignment(Qt::AlignLeft|Qt::AlignHCenter);
@@ -100,6 +99,9 @@ void RecentAndTrashPropertiesPage::init()
     auto name = new QLineEdit(this);
     name->setReadOnly(true);
     name->setText(m_fileInfo->displayName());
+    if (!targetFileInfo.get()->displayName().isEmpty()) {
+        name->setText(targetFileInfo.get()->displayName());
+    }
 
     boxLayout->addWidget(name);
     boxLayout->setAlignment(Qt::AlignBottom);
@@ -172,12 +174,25 @@ void RecentAndTrashPropertiesPage::init()
                                      nullptr,
                                      nullptr);
 
-            QString deletion_date = g_file_info_get_attribute_as_string(info, G_FILE_ATTRIBUTE_TRASH_DELETION_DATE);
-            deletion_date = deletion_date.replace("T", " ");
+            QString deletion_date = m_fileInfo->deletionDate();
             quint64 delete_width = FIXED_ROW_WIDTH - delete_label->fontMetrics().width(tr("Deletion Date: "));
             delete_label->setText(label->fontMetrics().elidedText(deletion_date, Qt::ElideMiddle, delete_width));
             delete_label->setWordWrap(true);
 
+            if (QGSettings::isSchemaInstalled("org.ukui.control-center.panel.plugins")) {
+                QGSettings *settings = new QGSettings("org.ukui.control-center.panel.plugins", "", this);
+                connect(settings, &QGSettings::changed, this, [=](const QString &key) {
+                    if(key == "date" || "hoursystem" == key) {
+                        QDateTime deleteTime = QDateTime::fromMSecsSinceEpoch(m_fileInfo->deletionTime (), Qt::LocalTime);
+                        QString format = GlobalSettings::getInstance()->getSystemTimeFormat();
+                        QString deletion_date = deleteTime.toString(format);
+                        quint64 delete_width = FIXED_ROW_WIDTH - delete_label->fontMetrics().width(tr("Deletion Date: "));
+                        delete_label->setText(label->fontMetrics().elidedText(deletion_date, Qt::ElideMiddle, delete_width));
+                        delete_label->setWordWrap(true);
+                    }
+                });
+            }
+
             g_object_unref(info);
             g_object_unref(file);
             m_layout->addRow(tr("Deletion Date: "), delete_label);
@@ -212,4 +227,10 @@ void RecentAndTrashPropertiesPage::saveAllChange()
 {
     bool check = this->property("check").toBool();
     GlobalSettings::getInstance()->setGSettingValue("showTrashDialog", check);
+
+    //task#100231 trash page OK button set as restore, restore file
+    //fix bug#143817, trash properties issue
+    if (m_uri.startsWith("trash:///") && m_uri != "trash:///"){
+       FileOperationUtils::restore(m_uri);
+    }
 }
