@@ -78,7 +78,6 @@ void TabPage::addPage(const QString &uri)
     container->switchViewType(DirectoryViewFactoryManager2::getInstance()->getDefaultViewId());
     container->getView()->setDirectoryUri(uri);
     container->getView()->beginLocationChange();
-    //FIXME: replace BLOCKING api in ui thread.
     auto displayName = FileUtils::getFileDisplayName(uri);
     if (displayName.length() > ELIDE_TEXT_LENGTH)
     {
@@ -86,7 +85,9 @@ void TabPage::addPage(const QString &uri)
         displayName = fontMetrics().elidedText(displayName, Qt::ElideRight, ELIDE_TEXT_LENGTH * charWidth);
     }
 
-    //FIXME: replace BLOCKING api in ui thread.
+    if (displayName.contains("&")) {
+        displayName = Peony::FileUtils::handleSpecialSymbols(displayName);
+    }
     addTab(container,
            QIcon::fromTheme(FileUtils::getFileIconName(uri), QIcon::fromTheme("folder")),
            displayName);
@@ -108,19 +109,15 @@ void TabPage::rebindContainer()
         m_double_click_limiter.start(500);
 
         qDebug()<<"tab page double clicked"<<uri;
-        auto info = Peony::FileInfo::fromUri(uri, false);
+        //FIXME: replace BLOCKING api in ui thread.
+        auto info = Peony::FileInfo::fromUri(uri);
         if (info->uri().startsWith("trash://")) {
             auto w = new PropertiesWindow(QStringList()<<uri);
             w->show();
             return;
         }
         if (info->isDir() || info->isVolume() || info->isVirtual()) {
-            //process open symbolic link
-            QString targetUri = uri;
-            auto info = FileInfo::fromUri(uri, false);
-            if (info->isSymbolLink() && uri.startsWith("file://") && info->isValid())
-                targetUri = "file://" + FileUtils::getSymbolicTarget(uri);
-            Q_EMIT this->updateWindowLocationRequest(targetUri);
+            Q_EMIT this->updateWindowLocationRequest(uri);
         } else {
             FileLaunchManager::openAsync(uri, false, false);
         }
@@ -142,9 +139,7 @@ void TabPage::rebindContainer()
 void TabPage::refreshCurrentTabText()
 {
     auto uri = getActivePage()->getCurrentUri();
-    //FIXME: replace BLOCKING api in ui thread.
     setTabText(currentIndex(), FileUtils::getFileDisplayName(uri));
-    //FIXME: replace BLOCKING api in ui thread.
     setTabIcon(currentIndex(),
                QIcon::fromTheme(FileUtils::getFileIconName(uri),
                                 QIcon::fromTheme("folder")));
