@@ -31,7 +31,7 @@
 #include <QListView>
 #include <QStringList>
 #include <QTimer>
-
+#include <QProxyStyle>
 namespace Peony {
 
 class SearchBarContainer : public QWidget
@@ -59,10 +59,20 @@ public:
     int getFilterIndex() {
         return m_filter_box->currentIndex();
     }
+
     void clearFilter() {
         m_filter_box->setCurrentIndex(0);
     }
 
+    void deselectSearchBox() {
+        // Take action in the search bar to refresh search results
+        m_search_box->deselect();
+    }
+
+    void setSearchBoxHeight(qint32 height) {
+        m_search_box->setFixedHeight(height);
+    }
+
 Q_SIGNALS:
     void returnPressed();
     void filterUpdate(const int &index);
@@ -90,6 +100,14 @@ private:
                                    };
 };
 
+class ToolButtonStyle : public QProxyStyle
+{
+public:
+    static ToolButtonStyle *getStyle();
+    ToolButtonStyle() {}
+
+    void drawComplexControl(ComplexControl control, const QStyleOptionComplex *option, QPainter *painter, const QWidget *widget) const override;
+};
 }
 
 #endif // SEARCH_BAR_CONTAINER_H
