@@ -60,12 +60,17 @@ public:
     std::shared_ptr<FileInfo> findFileInfoByUri(const QString &uri); //{return global_info_list->value(uri);}
 
     void lock() {
-        m_mutex.tryLock();
+        m_mutex.lock();
     }
     void unlock() {
         m_mutex.unlock();
     }
 
+    /*!
+     * \brief isAutoParted
+     * true if using kylin-installer's default pareted strategy.
+     */
+    bool isAutoParted();
     void showState();
 
 protected:
