@@ -27,8 +27,11 @@
 #include "file-meta-info.h"
 #include "file-utils.h"
 #include "thumbnail-manager.h"
+#include "emblem-provider.h"
 
 #include <QUrl>
+#include <QtDBus/QDBusConnection>
+#include <QStandardPaths>
 #include <QDir>
 #include <QDebug>
 
@@ -51,9 +54,12 @@ FileInfo::FileInfo(const QString &uri, QObject *parent) : QObject (parent)
      * bug in PathBarModel enumeration.
      */
     m_uri = uri;
-    m_file = g_file_new_for_uri(uri.toUtf8().data());
+    m_file = g_file_new_for_uri(uri.toUtf8().constData());
     m_parent = g_file_get_parent(m_file);
     m_is_remote = !g_file_is_native(m_file);
+    m_is_dir = false;
+    m_is_volume = false;
+    m_meta_info = FileMetaInfo::fromGFileInfo(uri, nullptr);
     GFileType type = g_file_query_file_type(m_file, G_FILE_QUERY_INFO_NONE, nullptr);
     switch (type) {
     case G_FILE_TYPE_DIRECTORY:
@@ -72,6 +78,7 @@ FileInfo::FileInfo(const QString &uri, QObject *parent) : QObject (parent)
 FileInfo::~FileInfo()
 {
     ThumbnailManager::getInstance()->releaseThumbnail(m_uri);
+    EmblemProviderManager::getInstance()->cancelQuery(m_uri);
     //qDebug()<<"~FileInfo"<<m_uri;
     disconnect();
 
@@ -87,6 +94,12 @@ FileInfo::~FileInfo()
 std::shared_ptr<FileInfo> FileInfo::fromUri(QString uri)
 {
     FileInfoManager *info_manager = FileInfoManager::getInstance();
+    // avoid using binding mount original uri. link to: #48982.
+    if (info_manager->isAutoParted()) {
+        if (uri.contains("file:///data/home")) {
+            uri.replace("file:///data/home", "file:///home");
+        }
+    }
     info_manager->lock();
     std::shared_ptr<FileInfo> info = info_manager->findFileInfoByUri(uri);
     if (info != nullptr) {
@@ -96,10 +109,13 @@ std::shared_ptr<FileInfo> FileInfo::fromUri(QString uri)
         std::shared_ptr<FileInfo> newly_info = std::make_shared<FileInfo>();
 
         newly_info->m_uri = uri;
-        newly_info->m_file = g_file_new_for_uri(uri.toUtf8().data());
+        newly_info->m_file = g_file_new_for_uri(uri.toUtf8().constData());
 
         newly_info->m_parent = g_file_get_parent(newly_info->m_file);
         newly_info->m_is_remote = ! g_file_is_native(newly_info->m_file);
+        newly_info->m_is_dir = false;
+        newly_info->m_is_volume = false;
+        newly_info->m_meta_info = FileMetaInfo::fromGFileInfo(uri, nullptr);
         if (! newly_info->m_is_remote && false) {
             GFileType type = g_file_query_file_type(newly_info->m_file, G_FILE_QUERY_INFO_NONE, nullptr);
             switch (type) {
@@ -171,6 +187,17 @@ bool FileInfo::isVideoFile()
     }
 }
 
+bool FileInfo::isExecDisable()
+{
+    if (m_meta_info) {
+        int nRet = m_meta_info->getMetaInfoInt("exec_disable");
+        if(1 == nRet) {
+            return true;
+        }
+    }
+
+    return false;
+}
 
 bool FileInfo::isOfficeFile()
 {
@@ -269,7 +296,10 @@ const QString FileInfo::displayName()
     unixDevice = unixDeviceFile();
     isMountPoint = FileUtils::isMountPoint(m_uri);
 
-    if(m_uri == "file:///DATA")
+    QString targetUri = FileUtils::getTargetUri(m_uri);
+    if(m_uri == "file:///DATA"
+            || m_uri == "file:///data"
+            || targetUri == "file:///data")
     {
         return tr("data");
     }
@@ -295,3 +325,28 @@ const QString FileInfo::displayName()
     FileUtils::handleVolumeLabelForFat32(deviceName,unixDevice);
     return deviceName;
 }
+
+QString FileInfo::displayFileType()
+{
+    if (isDir()) {
+        return tr("folder");
+    } else if (isOfficeFile()) {
+        return m_file_type;
+    } else if (isDesktopFile()) {
+        return "DESKTOP" + tr("file");
+    } else {
+        if (m_file_type.contains("plain text document")) {
+            return tr("text file");
+        } else {
+            QString fileName = displayName();
+            if (fileName.contains(".")) {
+                QStringList strElement = fileName.split(".");
+                return QString(strElement.last()).toUpper() + tr("file");
+            } else {
+                return tr("file");
+            }
+        }
+    }
+
+    return m_file_type;
+}
