@@ -59,6 +59,7 @@ protected:
     bool isValid();
     void execFile();
     void execFileInterm();
+    void preCheck();
 
 public Q_SLOTS:
     void lauchFileSync(bool forceWithArg = false, bool skipDialog = true);
@@ -67,6 +68,14 @@ public Q_SLOTS:
 
     bool isExcuteableFile(QString fileType);
 
+private:
+    bool launchAppWithDBus();
+    bool launchAppWithAppMgr();
+    bool launchDefaultAppWithUrl();
+    bool launchAppWithSession();
+
+    bool checkAppDisabled();
+
 private:
     QString m_uri;
     bool m_is_desktop_file;
