@@ -154,10 +154,16 @@ retry_create_template:
                                     G_FILE_ATTRIBUTE_TIME_MODIFIED,
                                     (guint64)now_time,
                                     G_FILE_QUERY_INFO_NONE, nullptr, &err);
+
+        //需要设置一下访问时间属性，修复前场反馈的在U盘创建wps文件，访问时间异常问题，时分秒为：000000
+        g_file_set_attribute_uint64(wrapGFile(g_file_new_for_uri(m_target_uri.toUtf8())).get()->get(),
+                                    G_FILE_ATTRIBUTE_TIME_ACCESS,
+                                    (guint64)now_time,
+                                    G_FILE_QUERY_INFO_NONE, nullptr, &err);
         break;
     }
     }
-
+    FileUtils::saveCreateTime (m_target_uri);
     // judge if the operation should sync.
     bool needSync = false;
     GFile *src_first_file = g_file_new_for_uri(FileUtils::urlEncode(m_src_uri).toUtf8().constData());
@@ -173,13 +179,18 @@ retry_create_template:
 
     GFile *dest_dir_file = g_file_new_for_uri(FileUtils::urlEncode(m_dest_dir_uri).toUtf8().constData());
     GMount *dest_dir_mount = g_file_find_enclosing_mount(dest_dir_file, nullptr, nullptr);
+
+    //fix create folder not sync issue, bug#128665, 132326
+    if (m_type == EmptyFolder) {
+        dest_dir_file = g_file_new_for_uri(FileUtils::urlEncode(m_target_uri).toUtf8().constData());
+    }
+
     if (src_first_mount) {
         needSync = g_mount_can_unmount(dest_dir_mount);
         g_object_unref(dest_dir_mount);
     } else {
         needSync = true;
     }
-    g_object_unref(dest_dir_file);
 
     //needSync = true;
 
@@ -194,6 +205,8 @@ retry_create_template:
         }
     }
 
+    g_object_unref(dest_dir_file);
+
     // as target()
     m_info.get()->m_dest_dir_uri = m_target_uri;
     m_info.get()->m_dest_uris.clear();
