@@ -21,18 +21,17 @@
  */
 
 #include "file-copy-operation.h"
-
 #include "file-node-reporter.h"
 #include "file-node.h"
 #include "file-enumerator.h"
 #include "file-info.h"
 
 #include "file-utils.h"
-
 #include "file-operation-manager.h"
-
+#include "sound-effect.h"
 #include "clipboard-utils.h"
 #include <QProcess>
+#include <QDir>
 #include <QDebug>
 #include "file-copy.h"
 #include <gio/gdesktopappinfo.h>
@@ -46,11 +45,19 @@ static void handleDuplicate(FileNode *node)
 
 FileCopyOperation::FileCopyOperation(QStringList sourceUris, QString destDirUri, QObject *parent) : FileOperation (parent)
 {
+    for (auto u : sourceUris) {
+        if (u.split ("://").length () != 2) {
+            sourceUris.removeOne (u);
+        }
+    }
+
     QUrl destDirUrl = Peony::FileUtils::urlEncode(destDirUri);
     QUrl firstSrcUrl = Peony::FileUtils::urlEncode(sourceUris.first());
 
     if (destDirUrl.isParentOf(firstSrcUrl)) {
-        m_is_duplicated_copy = true;
+        if (1 == firstSrcUrl.path().split("/").count() - destDirUrl.path().split("/").count()) {
+            m_is_duplicated_copy = true;
+        }
     }/* else {
         // fix #83068
         // windows里的重复复制操作没有备份选项，但是会一直弹框提示，这里和windows的行为靠拢
@@ -66,7 +73,6 @@ FileCopyOperation::FileCopyOperation(QStringList sourceUris, QString destDirUri,
     m_dest_dir_uri = FileUtils::urlDecode(destDirUri);
     m_reporter = new FileNodeReporter;
     connect(m_reporter, &FileNodeReporter::nodeFound, this, &FileOperation::operationPreparedOne);
-
     m_info = std::make_shared<FileOperationInfo>(sourceUris, destDirUri, FileOperationInfo::Copy);
 }
 
@@ -79,6 +85,7 @@ FileCopyOperation::~FileCopyOperation()
 ExceptionResponse FileCopyOperation::prehandle(GError *err)
 {
     setHasError(true);
+//    SoundEffect::getInstance()->copyOrMoveFailedMusic();
 
     switch (err->code) {
         case G_IO_ERROR_BUSY:
@@ -93,6 +100,14 @@ ExceptionResponse FileCopyOperation::prehandle(GError *err)
             return Other;
     }
 
+    /**
+     * @note FIX BUG 79363
+     * 文件传输中拔掉U盘，第一次报错:G_IO_ERROR_FAILED，后续报错:G_IO_ERROR_NOT_FOUND
+     */
+    if (G_IO_ERROR_NOT_FOUND == err->code && m_prehandle_hash.contains(G_IO_ERROR_FAILED)) {
+        return IgnoreAll;
+    }
+
     if (G_IO_ERROR_EXISTS == err->code && m_is_duplicated_copy) {
         return BackupAll;
     }
@@ -113,10 +128,9 @@ void FileCopyOperation::progress_callback(goffset current_num_bytes,
     QUrl url(Peony::FileUtils::urlEncode(p_this->m_current_src_uri));
     auto currnet = p_this->m_current_offset + current_num_bytes;
     auto total = p_this->m_total_szie;
-    auto fileIconName = FileUtils::getFileIconName(p_this->m_current_src_uri, false);
+    auto fileIconName = FileUtilsPrivate::getFileIconName(p_this->m_current_src_uri);
     auto destFileName = FileUtils::isFileDirectory(p_this->m_current_dest_dir_uri) ?
                 p_this->m_current_dest_dir_uri + "/" + url.fileName() : p_this->m_current_dest_dir_uri;
-//    qDebug()<<currnet*1.0/total;
     Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri, destFileName, fileIconName, currnet, total);
 }
 
@@ -130,18 +144,41 @@ void FileCopyOperation::copyRecursively(FileNode *node)
 
 fallback_retry:
     QString destFileUri = node->resolveDestFileUri(m_dest_dir_uri);
-    QUrl destFileUrl = Peony::FileUtils::urlEncode(destFileUri);
+    //QUrl destFileUrl = Peony::FileUtils::urlEncode(destFileUri);
+    destFileUri = FileUtils::urlEncode(destFileUri);
     node->setDestUri(destFileUri);
     QString srcUri = node->uri();
-    qDebug()<<"dest file uri:"<<destFileUri;
 
     GFileWrapperPtr destFile = wrapGFile(g_file_new_for_uri(destFileUri.toUtf8().constData()));
+    GFileWrapperPtr srcFile = wrapGFile(g_file_new_for_uri(srcUri.toUtf8().constData()));
 
     m_current_src_uri = node->uri();
     m_current_dest_dir_uri = destFileUri;
 
+    //fix bug#163573, can not copy readonly folder issue
+    gboolean readonly_source_fs = FALSE;
+    GFile *source_dir;
+    QString srcParent;
+    srcParent = FileUtils::getParentUri(node->uri());
+    source_dir = g_file_new_for_uri(FileUtils::urlEncode(srcParent).toUtf8());
+    /* Query the source dir, not the file because if its a symlink we'll follow it */
+    qDebug() << "node->uri():"<<node->uri()<<"srcParent:"<<QUrl(srcParent).url();
+    if (source_dir) {
+        GFileInfo *inf;
+        inf = g_file_query_filesystem_info (source_dir, "filesystem::readonly", NULL, NULL);
+        if (inf != NULL) {
+            readonly_source_fs = g_file_info_get_attribute_boolean (inf, "filesystem::readonly");
+            g_object_unref (inf);
+        }
+        g_object_unref (source_dir);
+    }
+
+    auto flags = (readonly_source_fs) ? G_FILE_COPY_NOFOLLOW_SYMLINKS | G_FILE_COPY_TARGET_DEFAULT_PERMS
+                     : G_FILE_COPY_NOFOLLOW_SYMLINKS | G_FILE_COPY_ALL_METADATA;
+
     if (node->isFolder()) {
         GError *err = nullptr;
+        GError *error = nullptr;
 
         //NOTE: mkdir doesn't have a progress callback.
         g_file_make_directory(destFile.get()->get(),
@@ -155,22 +192,38 @@ fallback_retry:
             auto errWrapperPtr = GErrorWrapper::wrapFrom(err);
             int handle_type = prehandle(err);
             except.errorType = ET_GIO;
+            except.errorStr = tr("Create folder %1 failed: %2").arg(node->destBaseName()).arg(err->message);
             except.srcUri = m_current_src_uri;
             except.destDirUri = m_current_dest_dir_uri;
             except.op = FileOpCopy;
             except.title = tr("File copy error");
             except.errorCode = err->code;
             if (handle_type == Other) {
-                if (G_IO_ERROR_EXISTS == err->code) {
+                switch (err->code) {
+                case G_IO_ERROR_EXISTS: {
                     except.dlgType = ED_CONFLICT;
                     Q_EMIT errored(except);
                     auto typeData = except.respCode;
                     handle_type = typeData;
-                } else {
+                    break;
+                }
+                case G_IO_ERROR_FILENAME_TOO_LONG: {
+                    except.dlgType = ED_RENAME;
+                    Q_EMIT errored(except);
+                    auto typeData = except.respCode;
+                    handle_type = typeData;
+                    break;
+                }
+                default: {
                     except.dlgType = ED_WARNING;
                     Q_EMIT errored(except);
                     auto typeData = except.respCode;
                     handle_type = typeData;
+                    if (handle_type != Cancel) {
+                        return;
+                    }
+                    break;
+                }
                 }
             }
             //handle.
@@ -189,6 +242,15 @@ fallback_retry:
             case OverWriteOne: {
                 node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
+//                g_file_copy_attributes(srcFile.get()->get(),
+//                                       destFile.get()->get(),
+//                                       GFileCopyFlags(flags),
+//                                       nullptr,
+//                                       &error);
+//                if (error) {
+//                    qDebug() << __func__ << error->code << error->message;
+//                }
+//                g_error_free(error);
                 //make dir has no overwrite
                 break;
             }
@@ -196,6 +258,15 @@ fallback_retry:
                 node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 m_prehandle_hash.insert(err->code, OverWriteOne);
+//                g_file_copy_attributes(srcFile.get()->get(),
+//                                       destFile.get()->get(),
+//                                       GFileCopyFlags(flags),
+//                                       nullptr,
+//                                       &error);
+//                if (error) {
+//                    qDebug() << __func__ << error->code << error->message;
+//                }
+//                g_error_free(error);
                 break;
             }
             case BackupOne: {
@@ -219,6 +290,16 @@ fallback_retry:
                 while (FileUtils::isFileExsit(node->resolveDestFileUri(m_dest_dir_uri))) {
                     handleDuplicate(node);
                 }
+//                GFileWrapperPtr destDir = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+//                g_file_copy_attributes(srcFile.get()->get(),
+//                                       destDir.get()->get(),
+//                                       GFileCopyFlags(flags),
+//                                       nullptr,
+//                                       &error);
+//                if (error) {
+//                    qDebug() << __func__ << error->code << error->message;
+//                }
+//                g_error_free(error);
                 goto fallback_retry;
             }
             case BackupAll: {
@@ -229,11 +310,26 @@ fallback_retry:
                 }
                 //make dir has no backup
                 m_prehandle_hash.insert(err->code, BackupOne);
+                GFileWrapperPtr destDir = wrapGFile(g_file_new_for_uri(node->destUri().toUtf8().constData()));
+//                g_file_copy_attributes(srcFile.get()->get(),
+//                                       destDir.get()->get(),
+//                                       GFileCopyFlags(flags),
+//                                       nullptr,
+//                                       &error);
+//                if (error) {
+//                    qDebug() << __func__ << error->code << error->message;
+//                }
+//                g_error_free(error);
                 goto fallback_retry;
             }
             case Retry: {
                 goto fallback_retry;
             }
+            case RenameOne: {
+                node->setDestFileName(except.respValue.value("newName").toString());
+                setHasError(false);
+                goto fallback_retry;
+            }
             case Cancel: {
                 node->setState(FileNode::Unhandled);
                 cancel();
@@ -251,6 +347,18 @@ fallback_retry:
         for (auto child : *(node->children())) {
             copyRecursively(child);
         }
+
+        //copy folder attributes after copy child, support copy readonly files
+        //related bug#163573
+        g_file_copy_attributes(srcFile.get()->get(),
+                               destFile.get()->get(),
+                               GFileCopyFlags(flags),
+                               nullptr,
+                               &error);
+        if (error) {
+            qDebug() << __func__ << error->code << error->message;
+        }
+        g_error_free(error);
     } else {
         GError *err = nullptr;
         QUrl url = node->uri();
@@ -359,24 +467,36 @@ fallback_retry:
             except.errorStr = err->message;
             except.destDirUri = m_current_dest_dir_uri;
 
-            //
+            //fix bug#121093, paste deleted file issue
             if (err->code == G_IO_ERROR_PERMISSION_DENIED) {
                 except.errorStr = tr("Cannot opening file, permission denied!");
+            }else if (err->code == G_IO_ERROR_NOT_FOUND) {
+                except.errorStr = tr("File:%1 was not found.").arg(except.srcUri);
             }
 
             if (handle_type == Other) {
-                if (G_IO_ERROR_EXISTS == err->code) {
+                switch (err->code) {
+                case G_IO_ERROR_EXISTS: {
                     except.dlgType = ED_CONFLICT;
                     Q_EMIT errored(except);
                     auto typeData = except.respCode;
-                    qDebug()<<"get return";
                     handle_type = typeData;
-                } else {
+                    break;
+                }
+                case G_IO_ERROR_FILENAME_TOO_LONG: {
+                    except.dlgType = ED_RENAME;
+                    Q_EMIT errored(except);
+                    auto typeData = except.respCode;
+                    handle_type = typeData;
+                    break;
+                }
+                default: {
                     except.dlgType = ED_WARNING;
                     Q_EMIT errored(except);
                     auto typeData = except.respCode;
-                    qDebug()<<"get return";
                     handle_type = typeData;
+                    break;
+                }
                 }
             }
             //handle.
@@ -463,6 +583,11 @@ fallback_retry:
             case Retry: {
                 goto fallback_retry;
             }
+            case RenameOne: {
+                node->setDestFileName(except.respValue.value("newName").toString());
+                setHasError(false);
+                goto fallback_retry;
+            }
             case Cancel: {
                 node->setState(FileNode::Unhandled);
                 cancel();
@@ -527,6 +652,11 @@ fallback_retry:
         m_current_offset += node->size();
         fileSync(srcUri, destFileUri);
         Q_EMIT operationProgressedOne(node->uri(), node->destUri(), node->size());
+
+        if(srcUri.endsWith(".dsps") && destFileUri.endsWith(".dsps")){
+            m_srcUrisOfCopyDspsFiles.append(FileUtils::urlDecode(srcUri));
+            m_destUrisOfCopyDspsFiles.append(FileUtils::urlDecode(destFileUri));
+        }
     }
     destFile.reset();
 }
@@ -588,16 +718,42 @@ void FileCopyOperation::run()
     if (isCancelled())
         return;
 
+    if (hook_check_operation_valid) {
+        if (!hook_check_operation_valid(m_source_uris, m_dest_dir_uri, FILE_OPERATION_COPY)) {
+            setHasError(true);
+            cancel();
+            Q_EMIT operationFinished();
+            return;
+        }
+    }
+
     Q_EMIT operationStarted();
 
+#ifdef KY_UDF_BURN
+    std::shared_ptr<FileOperationHelper> mHelper = std::make_shared<FileOperationHelper>(m_dest_dir_uri);
+    if (mHelper->isUnixCDDevice()) {
+        m_is_udf_burn_work = true;
+        bool isMountpoint = false;
+        mHelper->judgeSpecialDiscOperation();
+        g_autoptr(GFile) file = g_file_new_for_uri (m_dest_dir_uri.toUtf8().constData());
+        if (file) {
+            g_autoptr(GFileInfo) fileInfo = g_file_query_info(file, G_FILE_ATTRIBUTE_UNIX_IS_MOUNTPOINT, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, nullptr, nullptr);
+            if (fileInfo) {
+                isMountpoint = g_file_info_get_attribute_boolean(fileInfo, G_FILE_ATTRIBUTE_UNIX_IS_MOUNTPOINT);
+            }
+        }
+        if (!mHelper->dealDVDReduce().isEmpty() && isMountpoint) {
+            m_dest_dir_uri = mHelper->dealDVDReduce();
+        }
+    }
+#endif
+
     Q_EMIT operationRequestShowWizard();
 
     goffset *total_size = new goffset(0);
 
     QList<FileNode*> nodes;
     for (auto uri : m_source_uris) {
-        qDebug() << "copy uri:" << uri;
-
         QString szTempUri = uri;
         if(szTempUri.startsWith("filesafe:///") && szTempUri.remove("filesafe:///").indexOf("/") == -1) {
             continue;
@@ -614,6 +770,9 @@ void FileCopyOperation::run()
     m_total_szie = *total_size;
     delete total_size;
 
+    m_srcUrisOfCopyDspsFiles.clear();
+    m_destUrisOfCopyDspsFiles.clear();
+
     for (auto node : nodes) {
         copyRecursively(node);
     }
@@ -622,7 +781,6 @@ void FileCopyOperation::run()
     if (isCancelled()) {
         Q_EMIT operationStartRollbacked();
         for (auto file : nodes) {
-            qDebug()<<file->uri();
             if (isCancelled()) {
                 rollbackNodeRecursively(file);
             }
@@ -630,18 +788,51 @@ void FileCopyOperation::run()
     }
 
     setHasError(false);
-
+    QStringList burnUris = m_source_uris;
     for (auto node : nodes) {
-        if (!isCancelled())
+        if (!isCancelled()) {
             m_info->m_node_map.insert(node->uri(), node->destUri());
+            if (m_is_udf_burn_work) {
+                switch (node->responseType()) {
+                case IgnoreOne:
+                    burnUris.removeOne(node->uri());
+                    break;
+                case BackupOne:
+                    burnUris.replaceInStrings(node->uri(), node->destUri());
+                    break;
+                default:
+                    break;
+                }
+            }
+        }
         delete node;
     }
 
     m_info->m_dest_uris = m_info->m_node_map.values();
-
     nodes.clear();
+#ifdef KY_UDF_BURN
+    if (mHelper->isUnixCDDevice() && !isCancelled()) {
+        if(!mHelper->discWriteOperation(burnUris, m_dest_dir_uri)) {
+            FileOperationError except;
+            except.errorType = ET_CUSTOM;
+            except.op = FileOpCopy;
+            except.title = tr("File copy error");
+            except.srcUri = m_source_uris.first();
+            except.errorStr = tr("Burn failed");
+            except.destDirUri = m_dest_dir_uri;
+            except.dlgType = ED_WARNING;
+            Q_EMIT errored(except);
+        }
+        m_is_udf_burn_work = false;
+    } else {
+        if (m_is_udf_burn_work) {
+            m_is_udf_burn_work = false;
+        }
+    }
+#endif
 
     Q_EMIT operationFinished();
+    sendSrcAndDestUrisOfCopyDspsFiles();
 }
 
 void FileCopyOperation::cancel()
