@@ -24,12 +24,16 @@
 #include "file-operation-manager.h"
 #include "file-node.h"
 #include "file-node-reporter.h"
+#include "sound-effect.h"
+#include <QApplication>
+#include <QStandardPaths>
+#include <QProcess>
 
 using namespace Peony;
 
 FileDeleteOperation::FileDeleteOperation(QStringList sourceUris, QObject *parent) : FileOperation(parent)
 {
-    m_source_uris = sourceUris;
+    m_src_uris = sourceUris;
     m_reporter = new FileNodeReporter;
     m_info = std::make_shared<FileOperationInfo>(sourceUris, nullptr, FileOperationInfo::Delete);
     connect(m_reporter, &FileNodeReporter::nodeFound, this, &FileOperation::operationPreparedOne);
@@ -50,7 +54,7 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
     if (isCancelled())
         return;
 
-    auto fileIconName = FileUtils::getFileIconName(FileUtils::urlEncode(node->uri()), false);
+    auto fileIconName = FileUtilsPrivate::getFileIconName(FileUtils::urlEncode(node->uri()));
     GFile *file = g_file_new_for_uri(FileUtils::urlEncode(node->uri()).toUtf8().constData());
     if (node->isFolder()) {
         for (auto child : *(node->children())) {
@@ -102,7 +106,6 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
             except.errorStr = err->message;
             Q_EMIT errored(except);
             auto response = except.respCode;
-            qDebug()<<response;
             auto responseType = response;
             if (responseType == Cancel) {
                 cancel();
@@ -112,7 +115,7 @@ void FileDeleteOperation::deleteRecursively(FileNode *node)
         }
     }
     g_object_unref(file);
-    qDebug()<<"deleted";
+    //qDebug()<<"deleted";
     //operationAfterProgressedOne(node->uri());
     m_current_offset += node->size();
 
@@ -125,13 +128,37 @@ void FileDeleteOperation::run()
         return;
 
     Q_EMIT operationStarted();
+    for (auto src : m_src_uris) {
+        // pre-check for delete special directory
+        if (src == "file:///data/home" || src == "file:///data/usershare" ||
+                src == "file:///data/root" || src == "file:///home" ||
+                FileUtils::isStandardPath(src) || src == "file://" + QStandardPaths::writableLocation(QStandardPaths::HomeLocation)) {
+            FileOperationError except;
+            except.srcUri = src;
+            except.destDirUri = nullptr;
+            except.isCritical = true;
+            except.op = FileOpTrash;
+            except.title = tr("Delete file error");
+            except.errorType = ET_GIO;
+            except.dlgType = ED_WARNING;
+            except.errorStr = tr("Invalid Operation! Can not delete \"%1\".").arg(FileUtils::urlDecode(src));
+            errored(except);
+            cancel();
+        }
+
+        if (isCancelled()) {
+            Q_EMIT operationFinished();
+            return;
+        }
+    }
 
     Q_EMIT operationRequestShowWizard();
 
     goffset *total_size = new goffset(0);
+    bool isMobileDevice = FileUtils::isMobileDeviceFile(m_src_uris.first());
 
     QList<FileNode*> nodes;
-    for (auto uri : m_source_uris) {
+    for (auto uri : m_src_uris) {
         FileNode *node = new FileNode(FileUtils::urlEncode(uri), nullptr, m_reporter);
         node->findChildrenRecursively();
         node->computeTotalSize(total_size);
@@ -154,7 +181,31 @@ void FileDeleteOperation::run()
         delete node;
     }
 
+    //fix delete file not sync issue,link to bug#113826
+    if (isMobileDevice) {
+        auto path = FileUtils::getParentUri(m_src_uris.first());
+        if (! path.isEmpty()) {
+            operationStartSnyc();
+            QProcess p;
+            p.start(QString("sync -f '%1'").arg(path));
+            p.waitForFinished(-1);
+        }
+    }
+
+#ifdef KY_UDF_BURN
+    std::shared_ptr<FileOperationHelper> mHelper = std::make_shared<FileOperationHelper>(m_src_uris.first());
+    if (mHelper->isUnixCDDevice()) {
+        mHelper->judgeSpecialDiscOperation();
+        mHelper->discDeleteOperation(m_src_uris);
+    }
+#endif
+
     Q_EMIT operationFinished();
+
+    qApp->property("clearTrash");
+    if(true == qApp->property("clearTrash").toBool()){
+        Peony::SoundEffect::getInstance()->recycleBinClearMusic();
+    }
 }
 
 void FileDeleteOperation::cancel()
