@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,9 +35,13 @@ public:
     FileLinkOperation(QString srcUri, QString destDirUri, QObject *parent = nullptr);
     ~FileLinkOperation() override;
 
-    std::shared_ptr<FileOperationInfo> getOperationInfo() override {return m_info;}
+    std::shared_ptr<FileOperationInfo> getOperationInfo() override {
+        return m_info;
+    }
     void run() override;
 
+    void linkrun();
+
 private:
     QString m_src_uri = nullptr;
     QString m_dest_uri = nullptr;
