@@ -107,6 +107,9 @@ public:
     std::shared_ptr<FileOperationInfo> getOperationInfo() override {
         return m_info;
     }
+    bool isCopyMove() {
+        return m_copy_move;
+    }
 
 public Q_SLOTS:
     void cancel() override;
@@ -141,7 +144,7 @@ protected:
     ExceptionResponse prehandle(GError *err);
 
 private:
-    QStringList m_source_uris;
+    //QStringList m_source_uris;
     QString m_dest_dir_uri = nullptr;
 
     /*!
@@ -193,6 +196,10 @@ private:
 
     FileNodeReporter *m_reporter = nullptr;
 
+    bool m_is_udf_burn_work = false;
+
+    QStringList m_burn_uris;
+
     /*!
      * \brief m_prehandle_hash
      * \details
