@@ -37,7 +37,7 @@ FileNode::FileNode(QString uri, FileNode *parent, FileNodeReporter *reporter)
     char *basename = g_file_get_basename(file);
     m_basename = basename;
     m_dest_basename = basename;
-    m_basename = m_uri.split("/").last();
+    m_basename =  FileUtils::urlDecode(m_uri).split("/").last();
     m_dest_basename = m_basename;
     g_free(basename);
 
@@ -50,6 +50,9 @@ FileNode::FileNode(QString uri, FileNode *parent, FileNodeReporter *reporter)
                                         nullptr);
     g_object_unref(file);
     m_size = g_file_info_get_size(info);
+    if (0 == m_size) {
+        m_size = 1024;
+    }
     if (uri == "file:///proc/kcore")
         m_size = 0;
     g_object_unref(info);
