@@ -39,16 +39,19 @@
 #include "file-untrash-operation.h"
 
 #include "file-operation-error-dialog.h"
+#include "file-operation-internal-dialog.h"
 #include "file-operation-progress-wizard.h"
 
 #include "file-watcher.h"
 #include "audio-play-manager.h"
 
 #include "properties-window.h"
+#include "sound-effect.h"
 
 #include <QVector4D>
 
 #include <QDebug>
+#include <unistd.h>
 
 using namespace Peony;
 
@@ -76,13 +79,7 @@ FileOperationManager::FileOperationManager(QObject *parent) : QObject(parent)
     // 休眠检测
     GDBusConnection* pconnection = g_bus_get_sync(G_BUS_TYPE_SYSTEM, NULL, NULL);
     if (pconnection) {
-        g_dbus_connection_signal_subscribe(pconnection,
-                       "org.freedesktop.login1",
-                       "org.freedesktop.login1.Manager",
-                       "PrepareForSleep",
-                       "/org/freedesktop/login1", NULL,
-                       G_DBUS_SIGNAL_FLAGS_NONE,
-                       systemSleep, this, NULL);
+        g_dbus_connection_signal_subscribe(pconnection, "org.freedesktop.login1", "org.freedesktop.login1.Manager", "PrepareForSleep", "/org/freedesktop/login1", NULL, G_DBUS_SIGNAL_FLAGS_NONE, systemSleep, this, NULL);
     }
 }
 
@@ -123,10 +120,80 @@ bool FileOperationManager::isAllowParallel()
     return m_allow_parallel;
 }
 
-void FileOperationManager::startOperation(FileOperation *operation, bool addToHistory)
+QStringList FileOperationManager::getFilesOpenedByProc(const QString &procName)
 {
+    QStringList occupiedFiles;
+
+    QProcess process;
+    QString cmd = QString("lsof -c %1").arg(procName);
+    process.start(cmd);
+    process.waitForFinished();
+    QString infos = QString(process.readAll());
+    if(infos.isEmpty())
+        return occupiedFiles;
+
+    qDebug()<<infos;
+    QStringList infoList = infos.split("\n");
+    for(auto& info : infoList){
+        QString fileName = QString(info).section(" ", -1, -1);
+        occupiedFiles.append(fileName);
+    }
+
+    return occupiedFiles;
+}
+
+void FileOperationManager::startOperation(FileOperation *operation, bool addToHistory)
+{    
     auto operationInfo = operation->getOperationInfo();
 
+    QStringList uriList = operationInfo.get()->sources();
+    if(!uriList.count())
+        return;
+
+    bool bDocIsOccupiedByWps = Peony::GlobalSettings::getInstance()->isExist(DOC_IS_OCCUPIED_BY_WPS)?
+                Peony::GlobalSettings::getInstance()->getValue(DOC_IS_OCCUPIED_BY_WPS).toBool() : false;
+    if(bDocIsOccupiedByWps){
+        /* 文件被wps-office占用时处理流程;link to task#79151 文档防护软件适配---打开的文档可以被删除或重命名 */
+        QString occupiedFiles;
+        auto operationType = operationInfo->operationType();
+        if (operationType == FileOperationInfo::Trash
+             || operationType == FileOperationInfo::Delete
+             || operationType == FileOperationInfo::Move
+             || operationType == FileOperationInfo::Copy && operation->isCopyMove()/* 鼠标拖动文件情形 */
+             || operationType == FileOperationInfo::Rename)
+
+        {
+            QStringList filesOpenedByWps = getFilesOpenedByProc("wps");
+            QStringList filesOpenedByWpp = getFilesOpenedByProc("wpp");
+            QStringList filesOpenedByEt = getFilesOpenedByProc("et");
+            QStringList filesOpenedByproc = (filesOpenedByWps + filesOpenedByWpp + filesOpenedByEt).toSet().toList();/* 去重 */
+            for(auto& uri :uriList){
+                std::shared_ptr<FileInfo> fileinfo = FileInfo::fromUri(uri);
+                if(fileinfo && !fileinfo->isDir()){
+                    if(!uri.endsWith(".txt") && !(fileinfo->type().startsWith("application/wps-office")))
+                        continue;
+                }
+
+                QString absolutePath = FileUtils::urlDecode(uri).remove("file://");
+                for(auto& fileName :filesOpenedByproc){
+                    if(!fileName.startsWith(absolutePath))
+                        continue;
+
+                    operationInfo.get()->m_src_uris.removeOne(uri);
+                    operation->m_src_uris.removeOne(uri);
+                    occupiedFiles.append(QString("file://").append(fileName)).append("  ");
+                }
+            }
+
+        }
+        if(!occupiedFiles.isEmpty()){
+            QMessageBox::warning(nullptr, tr("Warn"), tr("'%1' is occupied，you cannot operate!").arg(occupiedFiles));
+            return;
+        }
+    }
+    //end
+
+
     if (operationInfo.get()->operationType() == FileOperationInfo::Trash) {
         auto value = GlobalSettings::getInstance()->getValue("showTrashDialog");
         if (value.isValid()) {
@@ -134,24 +201,58 @@ void FileOperationManager::startOperation(FileOperation *operation, bool addToHi
                 goto start;
             }
         }
-        // check dialog
-        QMessageBox questionBox;
-        questionBox.addButton(QMessageBox::Yes);
-        questionBox.addButton(QMessageBox::No);
-        questionBox.addButton(tr("No, go to settings"), QMessageBox::ActionRole);
-        questionBox.setText(tr("Do you want to put selected %1 item(s) into trash?").arg(operationInfo.get()->sources().count()));
-        auto result = questionBox.exec();
 
-        if (result != QMessageBox::Yes) {
-            if (result != QMessageBox::No) {
-                // settings
-                QStringList uris;
-                uris<<"trash:///";
-                auto propertyWindow = new PropertiesWindow(uris);
-                propertyWindow->show();
+        // check dialog
+        QWidget *widget = QApplication::topLevelAt(QCursor::pos());
+        qDebug()<<"top level widget:"<<widget<<",current QPoint:"<<QCursor::pos();
+        FileOperationInternalDialog questionbox((QDialog*)widget);
+        auto okButton = questionbox.addButton(tr("OK"));
+        connect(okButton, &QPushButton::clicked, &questionbox, [&]{
+            questionbox.accept();
+        });
+        auto cancelButton = questionbox.addButton(tr("Cancel"));
+        connect(cancelButton, &QPushButton::clicked, &questionbox, [&]{
+            questionbox.reject();
+        });
+        okButton->setFocus();
+        questionbox.setText(tr("Do you want to put selected %1 item(s) into trash?").arg(operationInfo.get()->sources().count()));
+        questionbox.setIcon("user-trash");
+        auto checkbox = questionbox.addCheckBoxLeft(tr("Do not show again"));
+        if (questionbox.exec()) {
+//            SoundEffect::getInstance()->recycleBinDeleteMusic();
+            if (checkbox->isChecked()) {
+                GlobalSettings::getInstance()->setGSettingValue(SHOW_TRASH_DIALOG, false);
             }
+        } else {
             return;
         }
+
+//        QMessageBox questionBox;
+//        questionBox.setIcon(QMessageBox::Question);
+//        questionBox.setIconPixmap(QIcon::fromTheme("user-trash").pixmap(64, 64));
+//        questionBox.addButton(QMessageBox::Yes);
+//        questionBox.addButton(QMessageBox::No);
+//        //questionBox.addButton(tr("No, go to settings"), QMessageBox::ActionRole);
+//        QCheckBox checkbox(tr("Do not show again"), &questionBox);
+//        questionBox.setCheckBox(&checkbox);
+//        questionBox.setText(tr("Do you want to put selected %1 item(s) into trash?").arg(operationInfo.get()->sources().count()));
+//        auto result = questionBox.exec();
+//        if(result == QMessageBox::Yes){
+//            SoundEffect::getInstance()->recycleBinDeleteMusic();
+//            if (checkbox.isChecked()) {
+//                GlobalSettings::getInstance()->setGSettingValue(SHOW_TRASH_DIALOG, false);
+//            }
+//        }
+//        if (result != QMessageBox::Yes) {
+//            if (result != QMessageBox::No) {
+//                // settings
+//                QStringList uris;
+//                uris<<"trash:///";
+//                auto propertyWindow = new PropertiesWindow(uris);
+//                propertyWindow->show();
+//            }
+//            return;
+//        }
     }
 
     // do not add move operation between favorite:///
@@ -279,6 +380,12 @@ start:
            if (!info)
                return;
            if (info->operationType() != FileOperationInfo::Delete) {
+               //fix bug#162024, play sound when operation finished
+               if (info->operationType() == FileOperationInfo::Copy ||
+                   info->operationType() == FileOperationInfo::Move){
+                   SoundEffect::getInstance()->copyOrMoveSucceedMusic();
+               }
+
                m_undo_stack.push(info);
                m_redo_stack.clear();
            } else {
@@ -287,6 +394,18 @@ start:
        }
    }, Qt::BlockingQueuedConnection);
 
+   // fix #92481
+   if (auto trashOp = qobject_cast<FileTrashOperation *>(operation)) {
+       connect(trashOp, &FileTrashOperation::deleteRequest, this, [=](const QStringList &srcUris){
+           auto deleteOperation = new FileDeleteOperation(srcUris);
+           // wait trash operation finished. otherwise manager will asume
+           // the operation is invalid due to deletion checkment.
+           QTimer::singleShot(1000, this, [=]{
+               startOperation(deleteOperation, true);
+           });
+       }, Qt::BlockingQueuedConnection);
+   }
+
     if (!allowParallel) {
         if (m_thread_pool->activeThreadCount() > 0) {
             QMessageBox::warning(nullptr,
@@ -439,6 +558,7 @@ void FileOperationManager::handleError(FileOperationError &error)
         if (m_progressbar->isHidden()) {
             m_progressbar->m_error = true;
         }
+#if 0
         auto dialog = dynamic_cast<QWidget *>(handle);
         if (dialog) {
             dialog->setProperty("useCustomShadow", true);
@@ -447,7 +567,7 @@ void FileOperationManager::handleError(FileOperationError &error)
             dialog->setProperty("customShadowRadius", QVector4D(1, 1, 1, 1));
             dialog->setProperty("customShadowMargins", QVector4D(30, 30, 30, 30));
         }
-
+#endif
         handle->handle(error);
         delete handle;
         m_progressbar->m_error = false;
@@ -483,7 +603,7 @@ void FileOperationManager::manuallyNotifyDirectoryChanged(FileOperationInfo *inf
             auto firstUri = info->m_src_uris.first();
             
             //'file:///run/user/1000/gvfs/smb-share:server=xxx,share=xxx/' converted to 'smb://xxx'
-            GFile * file  = g_file_new_for_uri(destDir.toLatin1().data());
+            GFile * file  = g_file_new_for_uri(destDir.toUtf8().data());
             char *uri = g_file_get_uri(file);	
             if (uri) {
                 destDir = uri;
@@ -680,6 +800,7 @@ std::shared_ptr<FileOperationInfo> FileOperationInfo::getOppositeInfo(FileOperat
     return oppositeInfo;
 }
 
+// S3/S4
 void FileOperationManager::systemSleep (GDBusConnection *connection, const gchar *senderName, const gchar *objectPath, const gchar *interfaceName, const gchar *signalName, GVariant *parameters, gpointer udata)
 {
     FileOperationProgressBar* pb = static_cast<FileOperationManager*>(udata)->m_progressbar;
