@@ -28,12 +28,20 @@
 #include <QMouseEvent>
 #include <QPushButton>
 #include <QMessageBox>
-
+#include <QToolTip>
 #include <QTimer>
 #include "file-utils.h"
+#include "xatom-helper.h"
 
 #include <QVector4D>
 
+#ifdef KY_SDK_WAYLANDHELPER
+#include <ukuistylehelper/ukuistylehelper.h>
+#else
+#include <QX11Info>
+#include "xatom-helper.h"
+#endif
+
 QPushButton* btn;
 
 static QPixmap drawSymbolicColoredPixmap (const QPixmap&);
@@ -65,7 +73,11 @@ void FileOperationProgressBar::removeAllProgressbar()
     m_widget_list->clear();
     m_list_widget->clear();
     m_progress_list->clear();
+    m_pro_list->clear();
     m_progress_size = 0;
+
+    uninhibit();
+
     hide();
 }
 
@@ -77,6 +89,7 @@ ProgressBar *FileOperationProgressBar::addFileOperation()
     m_list_widget->setItemWidget(li, proc);
     (*m_progress_list)[proc] = li;
     (*m_widget_list)[li] = proc;
+    m_pro_list->append(proc);
     li->setSizeHint(QSize(m_list_widget->width(), m_progress_item_height));
     li->setFlags(Qt::NoItemFlags);
 
@@ -87,23 +100,25 @@ ProgressBar *FileOperationProgressBar::addFileOperation()
         mainProgressChange(li);
     }
 
-    setWindowState(windowState() & ~Qt::WindowMinimized | Qt::WindowActive);
+    if (!isInhibit()) {
+        inhibit();
+    }
 
     showMore();
 
+    if (m_progress_size > 0 && !isHidden()) {
+        setWindowState(windowState() & ~Qt::WindowMinimized | Qt::WindowActive);
+    }
+
     return proc;
 }
 
 void FileOperationProgressBar::showProgress(ProgressBar &progress)
 {
     if (m_progress_size > 0) {
-        setAttribute(Qt::WA_TranslucentBackground, true);
+        kdk::UkuiStyleHelper::self()->removeHeader(this);
         progress.show();
         show();
-
-        QTimer::singleShot(300, [=] () {
-            setAttribute(Qt::WA_TranslucentBackground, false);
-        });
     }
 }
 
@@ -115,6 +130,7 @@ void FileOperationProgressBar::removeFileOperation(ProgressBar *progress)
     m_list_widget->removeItemWidget(li);
     m_progress_list->remove(progress);
     m_widget_list->remove(li);
+    m_pro_list->removeOne(progress);
 
     --m_progress_size;
 
@@ -122,7 +138,7 @@ void FileOperationProgressBar::removeFileOperation(ProgressBar *progress)
     if (m_current_main == progress) {
         // check other progress
         if (m_progress_size > 0) {
-            QListWidgetItem* pg = m_progress_list->first();
+            QListWidgetItem* pg = m_progress_list->value(m_pro_list->first());
             m_current_main = (*m_widget_list)[pg];
             mainProgressChange(pg);
         }
@@ -132,26 +148,52 @@ void FileOperationProgressBar::removeFileOperation(ProgressBar *progress)
     progress->deleteLater();
     delete li;
 
+    showMore();
+
     if (m_progress_size <= 0) {
         m_progress_size = 0;
         m_current_main = nullptr;
+        setWindowState(Qt::WindowNoState);
         hide();
+        uninhibit();
     }
+}
 
-    showMore();
+bool FileOperationProgressBar::isInhibit()
+{
+    return m_fds != nullptr;
 }
 
 FileOperationProgressBar::FileOperationProgressBar(QWidget *parent) : QWidget(parent)
 {
     m_current_main = nullptr;
-    setWindowFlags(Qt::FramelessWindowHint);
     setContentsMargins(0, 0, 0, 0);
 
+    setAutoFillBackground (true);
+    setBackgroundRole (QPalette::Base);
+
+#ifdef KY_SDK_WAYLANDHELPER
+    kdk::UkuiStyleHelper::self()->removeHeader(this);
+#else
+    if (QX11Info::isPlatformX11()) {
+        XAtomHelper::getInstance()->setUKUIDecoraiontHint(this->winId(), true);
+        MotifWmHints hints;
+        hints.flags = MWM_HINTS_FUNCTIONS|MWM_HINTS_DECORATIONS;
+        hints.functions = MWM_FUNC_ALL;
+        hints.decorations = MWM_DECOR_BORDER;
+        XAtomHelper::getInstance()->setWindowMotifHint(this->winId(), hints);
+    }
+#endif
+
+    setWindowOpacity(0.9999);
+
+#if 0
     setProperty("useCustomShadow", true);
     setProperty("customShadowDarkness", 0.5);
     setProperty("customShadowWidth", 30);
     setProperty("customShadowRadius", QVector4D(1, 1, 1, 1));
     setProperty("customShadowMargins", QVector4D(30, 30, 30, 30));
+#endif
 
     btn = new QPushButton(nullptr);
     m_main_layout = new QVBoxLayout(this);
@@ -165,12 +207,14 @@ FileOperationProgressBar::FileOperationProgressBar(QWidget *parent) : QWidget(pa
     m_list_widget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     m_list_widget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
+    m_main_layout->setSpacing(2);
     m_main_layout->addWidget(m_main_progressbar);
     m_main_layout->addWidget(m_other_progressbar);
     m_main_layout->addWidget(m_list_widget);
 
     m_progress_list = new QMap<ProgressBar*, QListWidgetItem*>;
     m_widget_list = new QMap<QListWidgetItem*, ProgressBar*>;
+    m_pro_list = new QList<ProgressBar*>;
 
     showWidgetList(false);
 
@@ -200,6 +244,19 @@ FileOperationProgressBar::FileOperationProgressBar(QWidget *parent) : QWidget(pa
 FileOperationProgressBar::~FileOperationProgressBar()
 {
     delete btn;
+    if (m_dbus_connection) g_object_unref(m_dbus_connection);
+    if (!m_pro_list->isEmpty()) {
+        delete m_pro_list;
+        m_pro_list = nullptr;
+    }
+    if (!m_progress_list->isEmpty()) {
+        delete m_progress_list;
+        m_progress_list = nullptr;
+    }
+    if (!m_widget_list->isEmpty()) {
+        delete m_widget_list;
+        m_widget_list = nullptr;
+    }
 }
 
 void FileOperationProgressBar::showMore()
@@ -215,10 +272,10 @@ void FileOperationProgressBar::showMore()
         if (m_show_more) {
             m_list_widget->show();
             m_other_progressbar->show();
-            setFixedSize(m_main_progressbar->width(), m_main_progressbar->height() + m_other_progressbar->height() + m_list_widget->height());
+            setFixedSize(m_main_progressbar->width(), m_main_progressbar->height() + m_other_progressbar->height() + m_list_widget->height() + m_main_layout->spacing()*2);
         } else {
             m_list_widget->hide();
-            setFixedSize(m_main_progressbar->width(), m_main_progressbar->height() + m_other_progressbar->height());
+            setFixedSize(m_main_progressbar->width(), m_main_progressbar->height() + m_other_progressbar->height() + m_main_layout->spacing());
         }
     } else {
         m_list_widget->hide();
@@ -228,6 +285,43 @@ void FileOperationProgressBar::showMore()
     update();
 }
 
+bool FileOperationProgressBar::inhibit()
+{
+    g_autoptr(GError) error = NULL;
+    g_autoptr(GDBusConnection) pconnection = g_bus_get_sync(G_BUS_TYPE_SYSTEM, NULL, &error);
+    if (error) {
+        printf("error:%s\n", error->message);
+        return false;
+    }
+
+    uninhibit();
+
+    if (pconnection) {
+        g_autoptr(GVariantType) rtype = g_variant_type_new("(h)");
+
+        g_autoptr(GVariant) ret = g_dbus_connection_call_with_unix_fd_list_sync(pconnection, "org.freedesktop.login1", "/org/freedesktop/login1",
+                                                                      "org.freedesktop.login1.Manager", "Inhibit",
+                                                                      g_variant_new("(ssss)", "sleep", "peony", "file operation", "block"),
+                                                                      rtype, G_DBUS_CALL_FLAGS_NONE, G_MAXINT, NULL, &m_fds, NULL, &error);
+        if (error) {
+            printf("cannot block s4: %s\n", error->message);
+        }
+
+        Q_UNUSED(ret);
+    }
+
+    return true;
+}
+
+void FileOperationProgressBar::uninhibit()
+{
+    if (m_fds) {
+        g_object_unref(m_fds);
+        m_fds = nullptr;
+    }
+}
+
+#if 0
 void FileOperationProgressBar::mouseMoveEvent(QMouseEvent *event)
 {
     if (m_is_press) {
@@ -250,6 +344,7 @@ void FileOperationProgressBar::mouseReleaseEvent(QMouseEvent *event)
         m_is_press = false;
     }
 }
+#endif
 
 void FileOperationProgressBar::showWidgetList(bool show)
 {
@@ -306,6 +401,7 @@ void FileOperationProgressBar::showDelay(int msec)
 {
     QTimer::singleShot(msec, this, [=] () {
         if (m_list_widget->count() > 0 && !m_error) {
+            kdk::UkuiStyleHelper::self()->removeHeader(this);
             show();
         }
     });
@@ -318,6 +414,36 @@ MainProgressBar::MainProgressBar(QWidget *parent) : QWidget(parent)
 
     m_title = tr("File operation");
 
+    m_btn_close = new QPushButton(this);
+    m_btn_mini = new QPushButton (this);
+
+    m_btn_mini->setFlat (true);
+    m_btn_mini->setProperty ("isWindowButton", 0x01);
+    m_btn_mini->setIcon (QIcon::fromTheme("window-minimize-symbolic"));
+    m_btn_mini->setToolTip(tr("Minimize"));
+    connect (m_btn_mini, &QPushButton::clicked, this, [=] () {
+        Q_EMIT minimized();
+    });
+
+    m_btn_close->setFlat (true);
+    m_btn_close->setProperty ("isWindowButton", 0x02);
+    m_btn_close->setIcon (QIcon::fromTheme("window-close-symbolic"));
+    m_btn_close->setToolTip(tr("Close"));
+    connect (m_btn_close, &QPushButton::clicked, this, [=] () {
+        QMessageBox msgBox(QMessageBox::Warning, tr("cancel all file operations"),
+            tr("Are you sure to cancel all file operations?"),
+            QMessageBox::Ok | QMessageBox::Cancel);
+        msgBox.button(QMessageBox::Ok)->setText(tr("OK"));
+        msgBox.button(QMessageBox::Cancel)->setText(tr("Cancel"));
+        msgBox.setDefaultButton(QMessageBox::Ok);
+        if (QMessageBox::Ok == msgBox.exec()) {
+            Q_EMIT closeWindow();
+        }
+    });
+
+    m_btn_mini->setGeometry (m_minilize_button_x_l, m_minilize_button_y_t, m_btn_size, m_btn_size);
+    m_btn_close->setGeometry (m_close_button_x_l, m_close_button_y_t, m_btn_size, m_btn_size);
+
     setFixedSize(m_fix_width, m_fix_height);
 }
 
@@ -368,6 +494,17 @@ void MainProgressBar::setFileName(QString name)
     m_file_name = name;
 }
 
+QString MainProgressBar::elideText(const QFont &font, const int &width, const QString &strInfo)
+{
+    QFontMetrics fontMetrics(font);
+    QString display_name = strInfo;
+    if(fontMetrics.width(strInfo) > 2*width) {
+        display_name = QFontMetrics(font).elidedText(strInfo, Qt::ElideMiddle, 2*width-20);
+    }
+    return display_name;
+
+}
+
 void MainProgressBar::paintEvent(QPaintEvent *event)
 {
     QPainter painter (this);
@@ -381,6 +518,7 @@ void MainProgressBar::paintEvent(QPaintEvent *event)
     Q_UNUSED(event);
 }
 
+#if 0
 void MainProgressBar::mouseMoveEvent(QMouseEvent *event)
 {
     // minilize button
@@ -405,11 +543,13 @@ void MainProgressBar::mouseMoveEvent(QMouseEvent *event)
         QWidget::mouseMoveEvent(event);
     }
 }
+#endif
 
 void MainProgressBar::mouseReleaseEvent(QMouseEvent *event)
 {
     // minilize button
     QPoint pos = event->pos();
+#if 0
     if ((pos.x() >= m_minilize_button_x_l)
             && (pos.x() <= m_minilize_button_x_r)
             && (pos.y() >= m_minilize_button_y_t)
@@ -424,10 +564,13 @@ void MainProgressBar::mouseReleaseEvent(QMouseEvent *event)
                            QMessageBox::Ok | QMessageBox::Cancel);
         msgBox.button(QMessageBox::Ok)->setText(tr("OK"));
         msgBox.button(QMessageBox::Cancel)->setText(tr("Cancel"));
+        msgBox.setDefaultButton(QMessageBox::Ok);
         if (QMessageBox::Ok == msgBox.exec()) {
             Q_EMIT closeWindow();
         }
-    } else if ((pos.x() >= m_progress_pause_x)
+    } else
+#endif
+    if ((pos.x() >= m_progress_pause_x)
                && (pos.x() <= m_progress_pause_x_r)
                && (pos.y() >= m_progress_pause_y)
                && (pos.y() <= m_progress_pause_y_b)) {
@@ -441,6 +584,29 @@ void MainProgressBar::mouseReleaseEvent(QMouseEvent *event)
     QWidget::mouseReleaseEvent(event);
 }
 
+bool MainProgressBar::event(QEvent *event)
+{
+    if (event->type() == QEvent::ToolTip) {
+        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        QPoint pos = helpEvent->pos();
+        if ((pos.x() >= m_progress_pause_x)
+                   && (pos.x() <= m_progress_pause_x_r)
+                   && (pos.y() >= m_progress_pause_y)
+                   && (pos.y() <= m_progress_pause_y_b)){
+            QString tooltipText = "";
+            if (m_pause) {
+                tooltipText = tr("continue");
+            } else {
+                tooltipText = tr("pause");
+            }
+
+            QToolTip::showText(helpEvent->globalPos(), tooltipText, this);
+            return true;
+        }
+    }
+    return QWidget::event(event);
+}
+
 void MainProgressBar::paintFoot(QPainter &painter)
 {
     painter.save();
@@ -465,13 +631,23 @@ void MainProgressBar::paintHeader(QPainter &painter)
 {
     painter.save();
 
-    // paint title
-    QRect textArea (m_text_area_x, 0, m_title_width, m_header_height);
-    QFont font = painter.font();
-    font.setPixelSize(14);
-    painter.setFont(font);
-    painter.drawText(textArea, Qt::AlignVCenter | Qt::AlignHCenter, m_title);
+    // paint icon
+    int iconSize = m_header_height - m_btn_margin * 2;
+    QRect iconArea (m_btn_margin * 2, m_btn_margin, iconSize, iconSize);
+    painter.drawPixmap (iconArea, QIcon::fromTheme("system-file-manager").pixmap (iconSize, iconSize)); //(textArea, Qt::Ali | Qt::AlignHCenter, m_title);
 
+    // paint title
+    if("bo_CN" == QLocale::system().name()){
+       m_header_height = 30 + 15;
+    }
+    QRect textArea (m_text_area_x + iconSize, 0, m_title_width, m_header_height);
+
+    QFont font = painter.font();
+//    font.setPixelSize(14);
+    painter.setFont(font);
+    painter.drawText(textArea, Qt::AlignVCenter | Qt::AlignLeft, m_title);
+
+#if 0
     // paint minilize button
     painter.drawPixmap(m_minilize_button_x_l, m_btn_margin_top, m_btn_size, m_btn_size,
                        drawSymbolicColoredPixmap(QIcon::fromTheme("window-minimize-symbolic").pixmap(m_btn_size, m_btn_size)));
@@ -479,7 +655,7 @@ void MainProgressBar::paintHeader(QPainter &painter)
     // paint close button
     painter.drawPixmap(m_close_button_x_l, m_btn_margin_top, m_btn_size, m_btn_size,
                        drawSymbolicColoredPixmap(QIcon::fromTheme("window-close-symbolic").pixmap(m_btn_size, m_btn_size)));
-
+#endif
     painter.restore();
 }
 
@@ -498,29 +674,35 @@ void MainProgressBar::paintContent(QPainter &painter)
 
     // paint file name
     QFont font = painter.font();
-    font.setPixelSize(14);
+//    font.setPixelSize(14);
     painter.setFont(font);
     if (m_stopping) {
         painter.drawText(m_file_name_x, m_file_name_y, m_file_name_w, m_file_name_height, Qt::AlignLeft | Qt::AlignVCenter, tr("canceling ..."));
     } else {
         if (m_sync) {
             painter.drawText(m_file_name_x, m_file_name_y, m_file_name_w, m_file_name_height, Qt::AlignLeft | Qt::AlignVCenter, tr("sync ..."));
-            painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height));
+            painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height)));
         } else {
-            painter.drawText(m_file_name_x, m_file_name_y, m_file_name_w, m_file_name_height, Qt::AlignLeft | Qt::AlignVCenter | Qt::TextWordWrap | Qt::TextWrapAnywhere, m_file_name);
+            this->setToolTip(m_file_name);
+            QString display_name;
+            display_name = elideText(this->font(),400,m_file_name);
+            int fontHeight = painter.fontMetrics().boundingRect(display_name).height() * 2;
+            int fileNameHeight = qMax(m_file_name_height, fontHeight);
+            int textY = m_fix_height / 2 - fileNameHeight / 2;
+            painter.drawText(m_file_name_x, textY, m_file_name_w, fileNameHeight, Qt::AlignLeft | Qt::AlignVCenter | Qt::TextWordWrap | Qt::TextWrapAnywhere, display_name);
             if (m_pause) {
-                painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height));
+                painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height)));
             } else {
-                painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height));
+                painter.drawPixmap(m_progress_pause_x, m_progress_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_pause_btn_height, m_pause_btn_height)));
             }
         }
     }
 
     // paint percentage
-    font.setPixelSize(12);
+//    font.setPixelSize(12);
     painter.setFont(font);
     painter.setBrush(QBrush(btn->palette().color(QPalette::Highlight)));
-    painter.drawText(m_percent_x, m_percent_y, m_percent_height, m_percent_height, Qt::AlignRight | Qt::AlignBottom,
+    painter.drawText(m_percent_x, m_percent_y, m_fix_width - m_percent_margin, m_percent_height, Qt::AlignRight | Qt::AlignBottom,
                      QString(" %1 %").arg(QString::number(m_current_value * 100, 'f', 1)));
 
     painter.restore();
@@ -595,11 +777,11 @@ void OtherButton::paintEvent(QPaintEvent *event)
     x = x + m_icon_size + 10;
     QRect textArea (x, 0, m_text_length, m_button_heigth);
     QFont font = painter.font();
-    font.setPixelSize(10);
+//    font.setPixelSize(10);
     painter.setFont(font);
     pen.setBrush(QBrush(btn->palette().color(QPalette::WindowText)));
     painter.setPen(pen);
-    painter.drawText(textArea, Qt::AlignLeft | Qt::AlignVCenter, m_text);
+    painter.drawText(textArea, Qt::AlignLeft | Qt::AlignVCenter, tr("Other queue"));
 
     painter.restore();
 
@@ -633,6 +815,7 @@ ProgressBar::ProgressBar(QWidget *parent) : QWidget(parent)
     setMouseTracking(true);
     m_is_stopping = false;
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    m_update_count = 0;
     m_dest_uri = tr("starting ...");
     connect(this, &ProgressBar::cancelled, this, &ProgressBar::onCancelled);
     connect(this, &ProgressBar::destroyed, this, [=] () {m_has_finished = true;});
@@ -691,6 +874,16 @@ void ProgressBar::setResume()
     update();
 }
 
+QString ProgressBar::elideText(const QFont &font, const int &width, const QString &strInfo)
+{
+    QFontMetrics fontMetrics(font);
+    QString display_name = strInfo;
+    if(fontMetrics.width(strInfo) > width) {
+        display_name = QFontMetrics(font).elidedText(strInfo, Qt::ElideMiddle, width);
+    }
+    return display_name;
+}
+
 ProgressBar::~ProgressBar()
 {
 
@@ -717,15 +910,21 @@ void ProgressBar::paintEvent(QPaintEvent *event)
     pen.setStyle(Qt::SolidLine);
     painter.setPen(pen);
     QFont font = painter.font();
-    font.setPixelSize(12);
+//    font.setPixelSize(12);
     painter.setFont(font);
     if (m_is_stopping) {
         painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, tr("canceling ..."));
     } else if (m_sync) {
         painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, tr("sync ..."));
-        painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size));
+        painter.drawPixmap(m_pause_x, m_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size)));
     } else {
-        painter.drawText(m_text_x, m_text_y, m_text_w, m_text_height, Qt::AlignLeft | Qt::AlignVCenter, m_dest_uri);
+        this->setToolTip(m_dest_uri);
+        QString display_name;
+        display_name = elideText(this->font(),335,m_dest_uri);
+        int fontHeight = painter.fontMetrics().boundingRect(display_name).height() * 2;
+        int fileNameHeight = qMax(m_text_height, fontHeight);
+        int textY = (m_fix_height - m_margin_ud * 2 - fileNameHeight) / 2 + m_margin_ud;
+        painter.drawText(m_text_x, textY, m_text_w, fileNameHeight, Qt::AlignLeft | Qt::AlignVCenter, display_name);
     }
 
     // paint progress
@@ -743,9 +942,9 @@ void ProgressBar::paintEvent(QPaintEvent *event)
 
     if (!m_sync) {
         if (m_pause) {
-            painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_btn_size, m_btn_size));
+            painter.drawPixmap(m_pause_x, m_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-start-symbolic").pixmap(m_btn_size, m_btn_size)));
         } else {
-            painter.drawPixmap(m_pause_x, m_pause_y, QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size));
+            painter.drawPixmap(m_pause_x, m_pause_y, drawSymbolicColoredPixmap(QIcon::fromTheme("media-playback-pause-symbolic").pixmap(m_btn_size, m_btn_size)));
         }
     }
 
@@ -852,8 +1051,8 @@ void ProgressBar::onFileOperationProgressedOne(const QString &uri, const QString
 
 void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri, const QString& fIcon, const quint64& current, const quint64& total)
 {
-    if (current >= m_total_size) {
-        qDebug() << "progress bar value error!";
+    if ((current > m_total_size && m_total_size>0) || m_update_count > m_total_count) {
+        qDebug() << "progress bar value error!:"<<current<<m_total_size;
         return;
     }
 
@@ -861,14 +1060,22 @@ void ProgressBar::updateProgress(const QString &srcUri, const QString &destUri,
     if (nullptr != destUri) {
         m_dest_uri = Peony::FileUtils::urlDecode(destUri);
     }
-
-    if (fIcon != getIcon().name()) {
-        setIcon(fIcon);
+    QString newIcon = fIcon;
+    if (newIcon.isNull()) {
+        newIcon = Peony::FileUtilsPrivate::getFileIconName(srcUri);
+    }
+    if (newIcon != getIcon().name()) {
+        setIcon(newIcon);
     }
 
     double currentPercent = current * 1.0 / total;
+    //fix bug#133624,133380, delete all empty files, not update progress bar
+//    if (m_total_size <= 0 || 16 * m_total_count <= m_total_size){
+//        m_update_count++;
+//        currentPercent = m_update_count * 1.0 /m_total_count;
+//    }
 
-//    qDebug() << "progress bar: " << currentPercent;
+    qDebug() << "progress bar: " << currentPercent <<current<<total<<m_update_count<<m_total_count;
 
     updateValue(currentPercent);
 
