@@ -27,6 +27,9 @@
 #include "file-info.h"
 #include "file-meta-info.h"
 #include <QUrl>
+#include <QStandardPaths>
+#include "sound-effect.h"
+#include <QApplication>
 
 using namespace Peony;
 
@@ -358,7 +361,14 @@ void FileUntrashOperation::run()
       it caused by the parent uri string has chinese.
       */
     int ret = 0;
+    quint64 total_size = 0;
 
+    for (auto src : m_uris) {
+        Q_EMIT operationPreparedOne (src, 1);
+        total_size += 1;
+    }
+
+    quint64 curSize = 0;
     for (auto uri : m_uris) {
         //cacheOriginalUri();
         auto originUri = m_restore_hash.value(uri);
@@ -401,6 +411,38 @@ retry:
                         nullptr,
                         nullptr,
                         &err);
+            if(err){
+                ExceptionResponse type = prehandle(err);
+                if(Other == type){
+                    QStringList originUris;
+                    QString tmpOriginUri = originUri;
+                    tmpOriginUri = tmpOriginUri.remove("file:///");
+                    originUris = tmpOriginUri.split("/");
+
+                    QList<QString>::iterator it = originUris.begin();
+                    QString tmpPath;
+                    QString originPath;
+                    for(int i = 0; i < originUris.count() - 1; i++, ++it){
+                        GError *error = nullptr;
+                        tmpPath = tmpPath + "/" + (*it);
+                        originPath = "file:///" + tmpPath;
+                        if(!FileUtils::isFileExsit(originPath)){
+                            g_autoptr(GFile) file = g_file_new_for_uri(originPath.toUtf8().constData());
+                            if(file){
+                                g_file_make_directory(file, nullptr, &error);
+                                if(error){
+                                    FileOperationError except;
+                                    untrashFileErrDlg(except, uri, originPath, error);                 
+                                    g_error_free(error);
+                                    //qDebug() << "g_file_make_directory error" << error->message << error->code;
+                                }else{
+                                    goto retry;
+                                }
+                            }
+                        }
+                    }
+                }
+            }
         }
 
         if (err) {
@@ -459,6 +501,8 @@ retry:
                 break;
             }
         }
+
+        Q_EMIT FileProgressCallback("trash:///", uri, "", ++curSize, total_size);
     }
 
 l_out:
