@@ -22,7 +22,9 @@
 
 #include "file-utils.h"
 #include "file-info.h"
+#include "file-info-job.h"
 #include "volume-manager.h"
+#include "linux-pwd-helper.h"
 #include <QUrl>
 #include <QFileInfo>
 #include <QFileInfoList>
@@ -35,6 +37,8 @@
 #include <udisks/udisks.h>
 #include <QDBusConnection>
 #include <QDBusInterface>
+#include <QDBusReply>
+#include <gio/gdesktopappinfo.h>
 
 using namespace Peony;
 
@@ -118,7 +122,7 @@ QString FileUtils::urlEncode(const QString& url)
 
 QString FileUtils::urlDecode(const QString &url)
 {
-    g_autofree gchar* decodeUrl = g_uri_unescape_string(url.toUtf8(), ":/");
+    g_autofree gchar* decodeUrl = g_uri_unescape_string(url.toUtf8().constData(), ":/");
     if (!decodeUrl) {
 //        qDebug() << "decode url from:'" << url <<"' to '" << url << "'";
         return url;
@@ -129,6 +133,22 @@ QString FileUtils::urlDecode(const QString &url)
     return decodeUrl;
 }
 
+QString FileUtils::getBaseNameOfFile(const QString &file)
+{
+    /* 一些常见扩展名处理，特殊情况以后待完善 */
+    QFileInfo qFileInfo(file);
+    QString suffix = qFileInfo.suffix();
+    QString fileBaseName = file.left(file.length() - suffix.length() - 1);
+     if (fileBaseName.isEmpty())
+         return file;
+     else if(fileBaseName.endsWith(".tar"))
+         return fileBaseName.remove(".tar");
+     else if(fileBaseName.endsWith(".7z"))
+         return fileBaseName.remove(".7z");
+     else
+         return fileBaseName;
+}
+
 QString FileUtils::handleDuplicateName(const QString& uri)
 {
     QString handledName = nullptr;
@@ -326,9 +346,45 @@ QString FileUtils::getFileDisplayName(const QString &uri)
     auto fileInfo = FileInfo::fromUri(uri);
     if (uri == "file:///data")
         return QObject::tr("data");
+    //fix bug#47597, show as root.link issue. 125255, file system show tip "/" issue
+    if (uri == "file:///")
+        return QObject::tr("File System");
+
+    //fix bug#139600，替换windows共享名称, “172.17.123.173上的Windows共享” 显示为 "172.17.123.173上的共享"
+    bool isSmbPath = uri.startsWith("smb://");
+    QString showName = fileInfo.get()->displayName();
+    //设置尽量苛刻的条件减少错误的替换
+    if (isSmbPath && showName.length()>=18 && showName.contains("Windows") && showName.split(".").length() ==4){
+        showName = showName.replace("Windows", "");
+        //only replaced one "Windows" to specific match
+        if (fileInfo.get()->displayName().length() - showName.length() == 7){
+            return showName;
+        }
+    }
     return fileInfo.get()->displayName();
 }
 
+QString FileUtils::getApplicationName(const QString &uri)
+{
+    QString displayName = getFileDisplayName(uri);
+    if (uri.endsWith(".desktop")){
+        g_autoptr(GFile) gfile = g_file_new_for_uri(uri.toUtf8().constData());
+        g_autofree gchar *desktop_file_path = g_file_get_path(gfile);
+        g_autoptr(GDesktopAppInfo) gdesktopappinfo = g_desktop_app_info_new_from_filename(desktop_file_path);
+        if (gdesktopappinfo) {
+            g_autofree gchar *desktop_name = g_desktop_app_info_get_locale_string(gdesktopappinfo, "Name");
+            if (!desktop_name) {
+                desktop_name = g_desktop_app_info_get_string(gdesktopappinfo, "Name");
+            }
+            if (desktop_name) {
+                displayName = desktop_name;
+            }
+        }
+    }
+
+    return displayName;
+}
+
 QString FileUtils::getFileIconName(const QString &uri, bool checkValid)
 {
     if (checkValid) {
@@ -501,10 +557,11 @@ bool FileUtils::isStandardPath(const QString &uri)
     QString videoPath= QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
     QString downloadPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation);
     QString musicPath = QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+    QString publicPath = g_get_user_special_dir(G_USER_DIRECTORY_PUBLIC_SHARE);
     QStringList mStandardPaths;
     //qDebug() << "isStandardPath :" <<templateDir.path();
     mStandardPaths <<desktopPath <<documentPath <<picturePath <<videoPath
-                  <<downloadPath <<musicPath <<templateDir.path();
+                  <<downloadPath <<musicPath <<templateDir.path()<<publicPath;
 
     if (mStandardPaths.contains(url.path()))
         return true;
@@ -512,13 +569,45 @@ bool FileUtils::isStandardPath(const QString &uri)
     return false;
 }
 
+/* @func: 使用设备是否可卸载的方式判断是否为移动设备
+ * 可移动设备是可以卸载的，可卸载的不一定是移动设备
+ * 排除掉网络地址，如ftp,sftp,smb挂载
+*/
+bool FileUtils::isMobileDeviceFile(const QString &uri)
+{
+    if (uri.isEmpty() || uri.startsWith("ftp:///") || uri.startsWith("sftp:///") || uri.startsWith("smb:///"))
+        return false;
+
+    bool isMobile = false;
+    //多次测试发现不准确，使用canEject和canStop属性来做判断
+//    GFile *dest_dir_file = g_file_new_for_path(uri.toUtf8().constData());
+//    GMount *dest_dir_mount = g_file_find_enclosing_mount(dest_dir_file, nullptr, nullptr);
+//    if (dest_dir_mount) {
+//        isMobile = g_mount_can_unmount(dest_dir_mount);
+//        g_object_unref(dest_dir_mount);
+//    }
+//    g_object_unref(dest_dir_file);
+    auto dev = VolumeManager::getDriveFromUri(getParentUri(uri));
+    if(dev != nullptr){
+        bool canEject = g_drive_can_eject(dev.get()->getGDrive());
+        bool canStop = g_drive_can_stop(dev.get()->getGDrive());
+        if(canEject || canStop){
+            isMobile = true;
+        }
+        qDebug() << "isMobile :" << isMobile;
+    }
+    return isMobile;
+}
+
 bool FileUtils::isSamePath(const QString &uri, const QString &targetUri)
 {
     //computer:/// and file:///, favorite:/// path check
     if (uri.endsWith(":///") && targetUri.endsWith(":///"))
         return uri == targetUri;
 
-    return QUrl(uri).path() == QUrl(targetUri).path();
+    //return QUrl(uri).path() == QUrl(targetUri).path();
+    //fix bug#84324
+    return QUrl(urlEncode(uri)).path() == QUrl(urlEncode(targetUri)).path();
 }
 
 bool FileUtils::containsStandardPath(const QStringList &list)
@@ -532,6 +621,17 @@ bool FileUtils::containsStandardPath(const QStringList &list)
     return false;
 }
 
+bool FileUtils::containsStandardPath(const QList<QUrl> &urls)
+{
+    for (QUrl url : urls) {
+        if (isStandardPath(url.toDisplayString())) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 bool FileUtils::isFileExsit(const QString &uri)
 {
     //FIXME: replace BLOCKING api in ui thread.
@@ -591,7 +691,7 @@ bool FileUtils::queryVolumeInfo(const QString &volumeUri, QString &volumeName, Q
 
     GFile *file = g_file_new_for_uri(volumeUri.toUtf8().constData());
     GFileInfo *info = g_file_query_info(file,
-                                        "*",
+                                        G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE_FILE","G_FILE_ATTRIBUTE_STANDARD_TARGET_URI,
                                         G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
                                         nullptr,
                                         nullptr);
@@ -734,6 +834,49 @@ QString transcodeForGbkCode(QByteArray gbkName, QString &volumeName)
     return name;
 }
 
+/* @func:           calculate all files size, recursively calculate folder files size
+ * @uri             file uri 文件uri, 如果是文件夹将会递归计算子文件大小
+ */
+quint64 FileUtils::getFileTotalSize(const QString &uri)
+{
+    auto info = FileInfo::fromUri(uri);
+    if (info->isDir())
+    {
+        guint64 disk_usage = 0, num_dirs = 0, num_files = 0;
+        GFile          *m_file = g_file_new_for_uri(uri.toUtf8().constData());
+        GCancellable   *m_cancel = g_cancellable_new();
+        GError         *err = nullptr;
+        g_file_measure_disk_usage (m_file,
+                                   G_FILE_MEASURE_NONE,
+                                   m_cancel,
+                                   nullptr,
+                                   nullptr,
+                                   &disk_usage,
+                                   &num_dirs,
+                                   &num_files,
+                                   &err);
+
+        if (err){
+            qWarning()<< "getFileTotalSize has error:" <<err->code<<err->message<<disk_usage;
+        }
+
+        g_object_unref(m_file);
+        g_object_unref(m_cancel);
+
+        return disk_usage;
+    }
+
+    //if not have size info, need update it
+    if (info->isEmptyInfo())
+    {
+        auto infoJob = new FileInfoJob(info);
+        infoJob->setAutoDelete();
+        infoJob->querySync();
+    }
+
+    return info->size();
+}
+
 /* @func:           determines whether the @volumeName needs to be transcoded. 判断字符串是否需要转码.
  * @volumeName      a string that needs to be converted from ascii to  Unicode. eg:"\\xb8\\xfc\\xd0\\xc2CODE"
  * @unixDeviceName  a device name. eg: /dev/sdb
@@ -819,7 +962,7 @@ QString FileUtils::getUnixDevice(const QString &uri)
         return nullptr;
 
     cancel = g_cancellable_new();
-    file = g_file_new_for_uri(uri.toUtf8().data());
+    file = g_file_new_for_uri(uri.toUtf8().constData());
     if(!file ||!cancel)
         return nullptr;
 
@@ -840,7 +983,7 @@ QString FileUtils::getUnixDevice(const QString &uri)
     if(targetUri.isEmpty())
         return nullptr;
 
-    mountPoint = g_filename_from_uri(targetUri.toUtf8().data(),NULL,NULL);
+    mountPoint = g_filename_from_uri(targetUri.toUtf8().constData(),NULL,NULL);
     if(mountPoint)
         tmpPath = Peony::VolumeManager::getUnixDeviceFileFromMountPoint(mountPoint);
     devicePath = tmpPath;
@@ -877,7 +1020,7 @@ double FileUtils::getDeviceSize(const gchar * device_name)
     object = UDISKS_OBJECT (g_dbus_interface_dup_object (G_DBUS_INTERFACE (block)));
     g_object_unref (block);
 
-    crypto_backing_device = udisks_block_get_crypto_backing_device ((udisks_object_peek_block (object)));
+    crypto_backing_device = udisks_block_get_crypto_backing_device ((udisks_object_get_block (object)));
     crypto_backing_object = udisks_client_get_object (client, crypto_backing_device);
     if (crypto_backing_object != NULL)
     {
@@ -903,7 +1046,9 @@ quint64 FileUtils::getFileSystemSize(QString uri)
 
     unixDevice = FileUtils::getUnixDevice(uri);
 
-    if (unixDevice.isEmpty()) {
+    //related bug#95731, encrypted data disk show property crash issue
+    if (unixDevice.isEmpty() ||
+        ! (unixDevice.startsWith("/dev/sd") || unixDevice.startsWith("/dev/sr"))) {
         return total;
     }
     dbusPath = "/org/freedesktop/UDisks2/block_devices/" + unixDevice.split("/").last();
@@ -927,7 +1072,10 @@ QString FileUtils::getFileSystemType(QString uri)
 
     unixDevice = getUnixDevice(uri);
 
-    if (unixDevice.isEmpty()) {
+    //fix bug#95731, encrypted data disk show property crash issue
+    //encrypted disk unixDevice name is like /dev/mapper/kylin--vg-data
+    if (unixDevice.isEmpty() ||
+        ! (unixDevice.startsWith("/dev/sd") || unixDevice.startsWith("/dev/sr"))) {
         return fsType;
     }
     dbusPath = "/org/freedesktop/UDisks2/block_devices/" + unixDevice.split("/").last();
@@ -947,3 +1095,244 @@ QString FileUtils::getFileSystemType(QString uri)
 
     return fsType;
 }
+
+QString FileUtils::getMobieDataPath()
+{
+    //path like "file:///var/lib/kmre/data/kmre-1000-kylin/KmreData"
+    //file:///var/lib/kmre/data/kmre-1000-hemh/KmreData
+    //1000 is uuid, kylin is username
+    QString prePath = "/var/lib/kmre/data";
+    //user infos
+    auto user = LinuxPWDHelper::getCurrentUser();
+    QString sufPath =  QString("/kmre-%1-%2/KmreData").arg(user.userId()).arg(user.userName());
+    QString completePath = prePath + sufPath;
+    qDebug() <<"getMobieDataPath:" <<completePath;
+    if (QFile::exists(completePath))
+        return "file://" + completePath;
+    else
+        return "";
+}
+
+bool FileUtils::isRemoteServerUri(const QString &uri)
+{
+    if(uri.startsWith("smb://") || uri.startsWith("ftp://") || uri.startsWith("sftp://"))
+        return true;
+
+    return false;
+}
+
+bool FileUtils::isEmptyDisc(const QString &unixDevice)
+{
+    if (unixDevice.isEmpty()) //没有设备时不做后续处理
+        return false;
+
+    if (!QDBusConnection::systemBus().isConnected())
+        return false;
+
+    /* 通过Properties获取Drive的path */
+    QString  dbusPath = "/org/freedesktop/UDisks2/block_devices/" + unixDevice.split("/").last();
+    QDBusInterface PropertiesIf("org.freedesktop.UDisks2",
+                                  dbusPath,
+                                  "org.freedesktop.DBus.Properties",
+                                  QDBusConnection::systemBus());
+    if(!PropertiesIf.isValid())
+        return false;
+
+    QDBusReply<QDBusVariant> reply = PropertiesIf.call("Get", "org.freedesktop.UDisks2.Block", "Drive");
+    if(!reply.isValid())
+        return false;
+
+    QDBusObjectPath* busObjectPath = (QDBusObjectPath*)(reply.value().variant().data());
+    if(!busObjectPath)
+        return false;
+
+    QString drivePath = busObjectPath->path();//end
+
+    /* 获取Drive的"OpticalBlank"属性，判断是否是空光盘 */
+    QDBusInterface driveInterface("org.freedesktop.UDisks2",
+                                  drivePath,
+                                  "org.freedesktop.UDisks2.Drive",
+                                  QDBusConnection::systemBus());
+
+    bool isBlank = false;
+    if(driveInterface.isValid()){
+        isBlank = driveInterface.property("OpticalBlank").toBool(); /* 获取"OpticalBlank"属性值 */
+    }
+
+    return isBlank;
+}
+
+bool FileUtils::isBusyDevice(const QString &unixDevice)
+{
+    if (unixDevice.isEmpty()) /* 没有设备时不做后续处理 */
+        return false;
+
+    QDBusMessage msg = QDBusMessage::createMethodCall("com.kylin.burner.manager", "/com/kylin/burner/manager",
+                     "com.kylin.burner.manager", "isBusyDevice");
+    QList<QVariant> args;
+    args.append(QVariant(unixDevice));
+    msg.setArguments(args);
+    QDBusMessage response = QDBusConnection::sessionBus().call(msg);
+
+    bool isBusy = false;
+    if (response.type() == QDBusMessage::ReplyMessage){
+        isBusy = response.arguments().takeFirst().toBool();
+    }
+    return isBusy;
+}
+
+QString FileUtils::getIconStringFromGIcon(GIcon *gicon, QString deviceFile)
+{
+    QString iconName;
+    if (G_IS_THEMED_ICON (gicon)) {
+        const char * const * icon_names = g_themed_icon_get_names((GThemedIcon *)gicon);
+        if(icon_names) {
+            iconName = *icon_names;
+
+            // fix #81852, refer to #57660, #70014, #96652, task #25343
+            if (QString(iconName) == "drive-harddisk-usb") {
+                double size = 0.0;
+                if(!deviceFile.isEmpty()){
+                    size = Peony::FileUtils::getDeviceSize(deviceFile.toUtf8().constData());
+                    if (size < 128) {
+                        iconName = "drive-removable-media-usb";
+                    }
+                }
+            }
+        }
+    } else if (G_IS_FILE_ICON (gicon)) {
+        g_autofree gchar *icon_name = g_icon_to_string(gicon);
+        iconName = icon_name;
+    } else if (G_IS_EMBLEMED_ICON (gicon)) {
+        GIcon *icon_emblemed = g_emblemed_icon_get_icon((GEmblemedIcon *)(gicon));
+        const char * const * icon_names = g_themed_icon_get_names((GThemedIcon *)icon_emblemed);
+        if(icon_names) {
+            iconName = *icon_names;
+        }
+    }
+    return iconName;
+}
+
+QString FileUtils::handleSpecialSymbols(const QString &displayName)
+{
+    QString tmpStr = displayName;
+    if (displayName.contains("&")) {
+        tmpStr = tmpStr.replace("&", "&&");
+    }
+    return tmpStr;
+}
+
+QString FileUtils::getFsTypeFromFile(const QString &fileUri)
+{
+    QString fsType = "";
+
+    g_autoptr (GFile) file = g_file_new_for_uri(fileUri.toUtf8().constData());
+    g_autoptr (GMount) mount = g_file_find_enclosing_mount(file, nullptr, nullptr);
+    if (!mount)
+        return "ext";
+
+    g_autoptr (GVolume) volume = g_mount_get_volume(mount);
+    if (!volume)
+        return fsType;
+
+    g_autofree gchar* unix_file = g_volume_get_identifier(volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+    if (!unix_file)
+        return fsType;
+
+    QString unixDevice = unix_file;
+    QString dbusPath = "/org/freedesktop/UDisks2/block_devices/" + unixDevice.split("/").last();
+    if (! QDBusConnection::systemBus().isConnected())
+        return fsType;
+    QDBusInterface blockInterface("org.freedesktop.UDisks2",
+                                  dbusPath,
+                                  "org.freedesktop.UDisks2.Block",
+                                  QDBusConnection::systemBus());
+
+    if(blockInterface.isValid())
+        fsType = blockInterface.property("IdType").toString();
+
+    //if need diff FAT16 and FAT32, should use IdVersion
+//    if(fsType == "" && blockInterface.isValid())
+//        fsType = blockInterface.property("IdVersion").toString();
+
+    return fsType;
+}
+
+QString FileUtilsPrivate::getFileIconName(const QString &uri)
+{
+    if (nullptr == uri) return "";
+
+    auto file = wrapGFile(g_file_new_for_uri(uri.toUtf8().constData()));
+    auto info = wrapGFileInfo(g_file_query_info(file.get()->get(),
+        G_FILE_ATTRIBUTE_STANDARD_ICON,
+        G_FILE_QUERY_INFO_NONE,
+        nullptr,
+        nullptr));
+    if (!G_IS_FILE_INFO (info.get()->get()))
+        return nullptr;
+    GIcon *g_icon = g_file_info_get_icon (info.get()->get());
+    QString icon_name;
+    //do not unref the GIcon from info.
+    if (g_icon && G_IS_ICON(g_icon)) {
+        const gchar* const* icon_names = g_themed_icon_get_names(G_THEMED_ICON (g_icon));
+        if (icon_names) {
+            auto p = icon_names;
+            while (*p) {
+                QIcon icon = QIcon::fromTheme(*p);
+                if (!icon.isNull()) {
+                    icon_name = QString (*p);
+                    break;
+                } else {
+                    p++;
+                }
+            }
+        } else {
+            //if it's a bootable-media,maybe we can get the icon from the mount directory.
+            char *bootableIcon = g_icon_to_string(g_icon);
+            if(bootableIcon){
+                icon_name = QString(bootableIcon);
+                g_free(bootableIcon);
+            }
+        }
+    }
+
+    return icon_name;
+}
+
+void FileUtils::saveCreateTime(const QString &url)
+{
+    g_autoptr (GError) error = NULL;
+    g_autoptr (GFile) file = url.startsWith ("file://") ? g_file_new_for_uri (url.toUtf8 ().constData ()) : g_file_new_for_path (url.toUtf8 ().constData ());
+    g_autofree gchar* currentTime = g_strdup_printf ("%ld", g_get_real_time ());
+
+    g_return_if_fail (G_IS_FILE (file) && g_file_query_exists (file, NULL));
+    g_file_set_attribute (file, "metadata::CreateTime", G_FILE_ATTRIBUTE_TYPE_STRING, currentTime, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &error);
+
+    if (error)      qDebug () << "set create time error: " << error->message;
+}
+
+gint64 FileUtils::getCreateTimeOfMicro(const QString &url)
+{
+    g_autoptr (GError) error = NULL;
+    g_autoptr (GFile) file = g_file_new_for_uri (url.toUtf8 ().constData ());
+    g_autoptr (GFileInfo) fileInfo = g_file_query_info (file, G_FILE_ATTRIBUTE_TIME_CHANGED "," G_FILE_ATTRIBUTE_TIME_CREATED "," "metadata::CreateTime", G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &error);
+    g_return_val_if_fail (G_IS_FILE (file) && G_IS_FILE_INFO (fileInfo) && g_file_query_exists (file, NULL), 0);
+
+    if (g_file_info_has_attribute (fileInfo, G_FILE_ATTRIBUTE_TIME_CREATED)) {
+        gint64 createTime = g_file_info_get_attribute_uint64 (fileInfo, G_FILE_ATTRIBUTE_TIME_CREATED);
+        gint64 modifyTime = g_file_info_get_attribute_uint64 (fileInfo, G_FILE_ATTRIBUTE_TIME_CHANGED);
+        if (createTime != 0 && createTime <= modifyTime) {
+            return createTime;
+        }
+    }
+
+    if (g_file_info_has_attribute (fileInfo, "metadata::CreateTime")) {
+        const gchar* createTimeStr = g_file_info_get_attribute_string (fileInfo, "metadata::CreateTime");
+        if (createTimeStr) {
+            g_autofree char* createTime10 = g_strndup (createTimeStr, 10);
+            return atoll (createTime10);
+        }
+    }
+
+    return 0;
+}
