@@ -32,6 +32,7 @@
 #include "volume-manager.h"
 #include "volumeManager.h"
 #include <QDebug>
+#include <QStandardPaths>
 
 using namespace Peony;
 
@@ -52,6 +53,22 @@ FileWatcher::FileWatcher(QString uri, QObject *parent, bool isWatchMovesFlag)
     creatorMonitor();
 
     FileOperationManager::getInstance()->registerFileWatcher(this);
+
+    // fix 97517, could not monitor filesafe box directory changement after unmounted and mount again.
+    connect(this, &FileWatcher::directoryUnmounted, this, [=](const QString &uri){
+        if (FileUtils::isSamePath(m_uri, uri)) {
+            if (m_monitor) {
+                //g_file_monitor_cancel(m_monitor);
+                g_object_unref(m_monitor);
+                m_monitor = nullptr;
+            }
+            if (m_dir_monitor) {
+                //g_file_monitor_cancel(m_dir_monitor);
+                g_object_unref(m_dir_monitor);
+                m_dir_monitor = nullptr;
+            }
+        }
+    });
 }
 
 FileWatcher::~FileWatcher()
@@ -110,13 +127,23 @@ void FileWatcher::startMonitor()
 {
     //make sure only connect once in a watcher.
     stopMonitor();
-    m_file_handle = g_signal_connect(m_monitor, "changed", G_CALLBACK(file_changed_callback), this);
-    m_dir_handle = g_signal_connect(m_dir_monitor, "changed", G_CALLBACK(dir_changed_callback), this);
+    if (m_monitor) {
+        m_file_handle = g_signal_connect(m_monitor, "changed", G_CALLBACK(file_changed_callback), this);
+    }
+    if (m_dir_monitor) {
+        m_dir_handle = g_signal_connect(m_dir_monitor, "changed", G_CALLBACK(dir_changed_callback), this);
+    }
 
     connect(FileLabelModel::getGlobalModel(), &FileLabelModel::fileLabelChanged, this, [=](const QString &uri) {
         auto parentUri = FileUtils::getParentUri(uri);
         QUrl parentUrl = parentUri;
-        if (parentUri == m_uri || parentUri == m_target_uri || parentUrl.toDisplayString() == m_uri || parentUrl.toDisplayString() == m_target_uri) {
+        QString originalUri = FileUtils::getOriginalUri(m_uri);
+        QString homeUri = "file://" +  QStandardPaths::writableLocation(QStandardPaths::HomeLocation);/* 家目录 */
+        bool favoriteCond  = (m_uri=="favorite:///" && parentUri == homeUri);/* 快速访问下 */
+        bool filesafeCond = (uri.startsWith("filesafe:///") && originalUri.startsWith("file:///"));
+        if (parentUri == m_uri || parentUri == m_target_uri || parentUrl.toDisplayString() == m_uri
+            || parentUrl.toDisplayString() == m_target_uri || parentUri == originalUri || favoriteCond
+            || filesafeCond) {
             Q_EMIT fileChanged(uri);
             qDebug()<<"file label changed"<<uri;
         }
@@ -129,9 +156,10 @@ void FileWatcher::startMonitor()
         }
     });
     connect(Experimental_Peony::VolumeManager::getInstance(), &Experimental_Peony::VolumeManager::signal_unmountFinished, this, [=](const QString &uri){
-        /* volume卸载完成跳转到计算机目录 */
-        if (m_uri.contains(uri)||m_target_uri.contains(uri)) {
-            Q_EMIT directoryUnmounted("computer:///");
+        /* volume卸载完成跳转到计算机目录(只有进入volume内部目录，卸载时才跳转) */
+        auto fixedUri = uri;
+        if (m_uri.contains(uri)||m_target_uri.contains(uri)|| m_uri + "/" == fixedUri) {
+            Q_EMIT directoryUnmounted(uri);
         }
     });
 }
@@ -160,7 +188,7 @@ void FileWatcher::creatorMonitor()
 {
     GError *err1 = nullptr;
     m_monitor = g_file_monitor_file(m_file,
-                                    G_FILE_MONITOR_WATCH_MOVES,
+                                    GFileMonitorFlags(G_FILE_MONITOR_WATCH_MOVES | G_FILE_MONITOR_WATCH_MOUNTS),
                                     m_cancellable,
                                     &err1);
     if (err1) {
@@ -225,12 +253,6 @@ void FileWatcher::file_changed_callback(GFileMonitor *monitor,
     case G_FILE_MONITOR_EVENT_MOVED_IN:
     case G_FILE_MONITOR_EVENT_MOVED_OUT:
     case G_FILE_MONITOR_EVENT_RENAMED: {
-        /*!
-         * \bug
-         * renaming a desktop file can not get new uri correctly.
-         *
-         * we have to consider trigger it by another way.
-         */
         char *new_uri = g_file_get_uri(other_file);
         QString uri = new_uri;
         //QUrl url =  uri;
@@ -254,11 +276,20 @@ void FileWatcher::file_changed_callback(GFileMonitor *monitor,
     }
     case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED: {
         char *uri = g_file_get_uri(file);
-        qDebug()<<uri;
+        //qDebug()<<uri;
         Q_EMIT p_this->fileChanged(uri);
         g_free(uri);
         break;
     }
+    case G_FILE_MONITOR_EVENT_UNMOUNTED: {
+        char *uri = g_file_get_uri(file);
+        QString deletedFileUri = uri;
+        //QUrl url = deletedFileUri;
+        //deletedFileUri = url.toDisplayString();
+        g_free(uri);
+        Q_EMIT p_this->directoryUnmounted(deletedFileUri);
+        break;
+    }
     default:
         break;
     }
@@ -290,7 +321,7 @@ void FileWatcher::dir_changed_callback(GFileMonitor *monitor,
     case G_FILE_MONITOR_EVENT_CREATED:
     case G_FILE_MONITOR_EVENT_MOVED_IN: {
         char *uri = g_file_get_uri(file);
-        QString createdFileUri = uri;       
+        QString createdFileUri = uri;
         //qDebug()<<"***create uri***"<<createdFileUri;
         g_free(uri);
 
@@ -309,9 +340,15 @@ void FileWatcher::dir_changed_callback(GFileMonitor *monitor,
     }
 
     case G_FILE_MONITOR_EVENT_RENAMED: {
+        /*!
+         * \bug
+         * renaming a desktop file can not get new uri correctly.
+         *
+         * we have to consider trigger it by another way.
+         */
         char *old_uri = g_file_get_uri (file);
         char *new_uri = g_file_get_uri(other_file);
-        Q_EMIT p_this->fileRenamed(old_uri,new_uri);     
+        Q_EMIT p_this->fileRenamed(old_uri,new_uri);
         qDebug()<<"***oldUri***newUri***"<<old_uri<<" "<<new_uri;
         g_free(old_uri);
         g_free(new_uri);
@@ -323,11 +360,14 @@ void FileWatcher::dir_changed_callback(GFileMonitor *monitor,
         //QUrl url = deletedFileUri;
         //deletedFileUri = url.toDisplayString();
         g_free(uri);
-        Q_EMIT p_this->directoryUnmounted(deletedFileUri);
+        //Q_EMIT p_this->directoryUnmounted(deletedFileUri);
+        Q_EMIT p_this->fileChanged(deletedFileUri);
+        if (FileUtils::urlDecode(deletedFileUri) == FileUtils::urlDecode(p_this->m_uri)) {
+            Q_EMIT p_this->directoryUnmounted(deletedFileUri);
+        }
         break;
     }
     default:
         break;
     }
 }
-
