@@ -23,6 +23,7 @@
 #include "linux-pwd-helper.h"
 
 #include <unistd.h>
+#include <QtNetwork/QHostInfo>
 
 LinuxPWDHelper::LinuxPWDHelper()
 {
@@ -58,3 +59,8 @@ const PWDItem LinuxPWDHelper::getCurrentUser()
     struct passwd *pw = getpwuid(uid);
     return PWDItem(pw);
 }
+
+const QString LinuxPWDHelper::localHost()
+{
+    return QHostInfo::localHostName();
+}
