@@ -32,9 +32,13 @@
 #include "file-utils.h"
 
 #include "thumbnail-manager.h"
+#include "global-settings.h"
 
 #include "file-operation-utils.h"
 
+#include "emblem-provider.h"
+#include "sound-effect.h"
+
 #include <QIcon>
 #include <QMimeData>
 #include <QUrl>
@@ -49,6 +53,21 @@ using namespace Peony;
 FileItemModel::FileItemModel(QObject *parent) : QAbstractItemModel (parent)
 {
     setPositiveResponse(true);
+
+
+    connect(EmblemProviderManager::getInstance(), &EmblemProviderManager::requestUpdateFile, this, &FileItemModel::updated);
+    connect(EmblemProviderManager::getInstance(), &EmblemProviderManager::requestUpdateAllFiles, this, &FileItemModel::updated);
+    connect(EmblemProviderManager::getInstance(), &EmblemProviderManager::visibleChanged, this, &FileItemModel::updated);
+
+    auto settings = GlobalSettings::getInstance();
+    m_showFileExtension = settings->isExist(SHOW_FILE_EXTENSION)? settings->getValue(SHOW_FILE_EXTENSION).toBool(): true;
+    connect(GlobalSettings::getInstance(), &GlobalSettings::valueChanged, this, [=] (const QString& key) {
+        if (SHOW_FILE_EXTENSION == key) {
+            m_showFileExtension= GlobalSettings::getInstance()->getValue(key).toBool();
+            beginResetModel();
+            endResetModel();
+        }
+    });
 }
 
 FileItemModel::~FileItemModel()
@@ -156,16 +175,19 @@ QModelIndex FileItemModel::lastColumnIndex(FileItem *item)
 const QModelIndex FileItemModel::indexFromUri(const QString &uri)
 {
     //FIXME: support recursively finding?
-    for (auto child : *m_root_item->m_children) {
-        GFile *left = g_file_new_for_uri(child->uri().toUtf8().constData());
-        GFile *right = g_file_new_for_uri(uri.toUtf8().constData());
-        bool equal = g_file_equal(left, right);
-        g_object_unref(left);
-        g_object_unref(right);
-        if (equal) {
-            return child->firstColumnIndex();
-        }
+    if(m_root_item->m_uri_item_hash.contains(uri)) {
+        auto child = m_root_item->m_uri_item_hash[uri];
+        return indexFromItemAndUri(child, uri);
+    }else if(m_root_item->m_uri_item_hash.contains(FileUtils::getEncodedUri(uri))){/* 中文编码问题 */
+        QString encodedUri = FileUtils::getEncodedUri(uri);
+        auto child = m_root_item->m_uri_item_hash[encodedUri];
+        return indexFromItemAndUri(child, encodedUri);
+    }else if(m_root_item->m_uri_item_hash.contains(FileUtils::urlDecode(uri))){/* 中文编码问题 */
+            QString decodedUri = FileUtils::urlDecode(uri);
+            auto child = m_root_item->m_uri_item_hash[decodedUri];
+            return indexFromItemAndUri(child, decodedUri);
     }
+
     return QModelIndex();
 }
 
@@ -181,6 +203,9 @@ QModelIndex FileItemModel::parent(const QModelIndex &child) const
 int FileItemModel::columnCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
+    if (m_root_uri == "trash:///") {
+        return FileSize + 2;
+    }
     return FileSize+1;
 }
 
@@ -218,19 +243,27 @@ QVariant FileItemModel::data(const QModelIndex &index, int role) const
         }
         case Qt::DisplayRole: {
             //fix bug#53504, desktop files not show same name issue
+            QString displayName = item->m_info->displayName();
             if (item->m_info->isDesktopFile())
             {
-                auto displayName = FileUtils::handleDesktopFileName(item->m_info->uri(), item->m_info->displayName());
+                displayName = FileUtils::handleDesktopFileName(item->m_info->uri(), item->m_info->displayName());
                 return QVariant(displayName);
             }
-            return QVariant(item->m_info->displayName());
+            /* story#8359 【文件管理器】手动开启关闭文件拓展名 */
+            if(!m_showFileExtension){
+                if (item->m_info->isDir()||(!displayName.contains("."))) {
+                    return QVariant(displayName);
+                }
+                return QVariant(FileUtils::getBaseNameOfFile(displayName));
+            }else
+                return QVariant(displayName);
         }
         case Qt::DecorationRole: {
             auto thumbnail = ThumbnailManager::getInstance()->tryGetThumbnail(item->m_info->uri());
             if (!thumbnail.isNull()) {
                 return thumbnail;
             }
-            QIcon icon = QIcon::fromTheme(item->m_info->iconName(), QIcon::fromTheme("text-x-generic"));
+            QIcon icon = QIcon::fromTheme(item->m_info->iconName(), QIcon::fromTheme("unknown"));
             return QVariant(icon);
         }
         case Qt::ToolTipRole: {
@@ -242,6 +275,9 @@ QVariant FileItemModel::data(const QModelIndex &index, int role) const
             }
             return QVariant(item->m_info->displayName());
         }
+        case Qt::UserRole + 1: {
+            return item->m_info->displayName();
+        }
         default:
             return QVariant();
         }
@@ -249,20 +285,11 @@ QVariant FileItemModel::data(const QModelIndex &index, int role) const
     case ModifiedDate: {
         switch (role) {
         case Qt::DisplayRole:
-            //can not sort, comment this
             //trash files show delete Date
             if (m_root_uri.startsWith("trash://") && !item->m_info->deletionDate().isNull()) {
                 QDateTime deleteTime = QDateTime::fromMSecsSinceEpoch(item->m_info->deletionTime (), Qt::LocalTime);
-                if (QGSettings::isSchemaInstalled("org.ukui.control-center.panel.plugins")) {
-                    QGSettings setting("org.ukui.control-center.panel.plugins");
-                    QString val = setting.get ("date").toString ();
-                    if ("cn" == val) {
-                        return QVariant(deleteTime.toString ("yyyy/MM/dd HH:mm:ss"));
-                    } else {
-                        return QVariant(deleteTime.toString ("yyyy-MM-dd HH:mm:ss"));
-                    }
-                }
-                return QVariant(item->m_info->deletionDate());
+                QString format = GlobalSettings::getInstance()->getSystemTimeFormat();
+                return QVariant(deleteTime.toString(format));
             }
             return QVariant(item->m_info->modifiedDate());
         default:
@@ -295,6 +322,17 @@ QVariant FileItemModel::data(const QModelIndex &index, int role) const
             return QVariant();
         }
     }
+    case TrashOriginPath: {
+        switch (role) {
+        case Qt::DisplayRole:
+        case Qt::ToolTipRole: {
+            return item->m_info->property("orig-path");
+            break;
+        }
+        default:
+            break;
+        }
+    }
     default:
         return QVariant();
     }
@@ -310,15 +348,16 @@ QVariant FileItemModel::headerData(int section, Qt::Orientation orientation, int
         case FileName:
             return tr("File Name");
         case ModifiedDate:
-            //can not sort, comment this
             //trash files show delete Date
-//            if (m_root_uri.startsWith("trash:///"))
-//                return tr("Delete Date");
+            if (m_root_uri.startsWith("trash:///"))
+                return tr("Delete Date");
             return tr("Modified Date");
         case FileType:
             return tr("File Type");
         case FileSize:
             return tr("File Size");
+        case TrashOriginPath:
+            return tr("Original Path");
         default:
             return QVariant();
         }
@@ -349,6 +388,11 @@ Qt::ItemFlags FileItemModel::flags(const QModelIndex &index) const
             flags |= Qt::ItemIsDragEnabled;
             flags |= Qt::ItemIsEditable;
         }
+        // to make the applications disable
+        if(item->m_info->canExecute()&&item->m_info->isExecDisable()) {
+            flags &= ~Qt::ItemIsEnabled;
+            flags |= Qt::ItemIsSelectable;
+        }
         return flags;
     } else {
         return Qt::ItemIsDropEnabled;
@@ -456,20 +500,24 @@ QMimeData *FileItemModel::mimeData(const QModelIndexList &indexes) const
     //set urls data URLs correspond to the MIME type text/uri-list.
     QList<QUrl> urls;
     QStringList uris;
+    QStringList encodedUris;
     for (auto index : indexes) {
         auto item = itemFromIndex(index);
-        auto encodeUrl = Peony::FileUtils::urlEncode(item->m_info->uri());
-        QUrl url = encodeUrl;
+        auto uri = item->m_info->uri();
+        QUrl url = uri;
         if (!urls.contains(url)) {
             qDebug() << "mimeData:" << url;
 
             urls << url;
-            uris << encodeUrl;
+            uris << uri;
+            auto encodeUri = Peony::FileUtils::urlEncode(uri);
+            encodedUris<<encodeUri;
         }
     }
     data->setUrls(urls);
     auto string = uris.join(" ");
-    data->setData("peony-qt/encoded-uris", string.toUtf8());
+    auto encodedString = encodedUris.join(" ");
+    data->setData("peony-qt/encoded-uris", encodedString.toUtf8());
     data->setText(string);
     return data;
 }
@@ -511,10 +559,12 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         //we have to set the dest dir uri as its mount point.
         //maybe i should do this when set model root item.
         destDirUri = m_root_item->m_info->uri();
-        auto targetUri = FileUtils::getTargetUri(destDirUri);
-        if (!targetUri.isEmpty()) {
-            destDirUri = targetUri;
-        }
+    }
+
+    //get real destDirUri
+    auto targetUri = FileUtils::getTargetUri(destDirUri);
+    if (!targetUri.isEmpty()) {
+        destDirUri = targetUri;
     }
 
     //if destDirUri was not set, do not execute a drop.
@@ -522,6 +572,11 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         return false;
     }
 
+    //if drag file to empty CD or DVD, is invalid operation, link to bug#129347
+    //如果是拖拽文件到空光盘，操作无效，光盘只能刻录，不能直接写入文件
+    if (destDirUri.startsWith("burn:///"))
+        return false;
+
     auto info = Peony::FileInfo::fromUri(destDirUri);
     //qDebug() << "FileItemModel::dropMimeData:" <<info->isDir() <<info->type();
     //if (!FileUtils::getFileIsFolder(destDirUri))
@@ -532,10 +587,19 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     //NOTE:
     //do not allow drop on it self.
     auto urls = data->urls();
+    if (urls.isEmpty())
+        return false;
+
+    bool hasPeonyEncodedUris = false;
+    if (data->hasFormat("peony-qt/encoded-uris")) {
+        if (!data->data("peony-qt/encoded-uris").isEmpty()) {
+            hasPeonyEncodedUris = true;
+        }
+    }
 
     QStringList srcUris;
-    if (data->hasFormat("peony-qt/encoded-uris")) {
-        srcUris = data->text().split(" ");
+    if (hasPeonyEncodedUris) {
+        srcUris = QString(data->data("peony-qt/encoded-uris")).split(" ");
         for (QString uri : srcUris) {
             if (uri.startsWith("recent://"))
                 srcUris.removeOne(uri);
@@ -561,6 +625,11 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         return false;
     }
 
+    //can not move StandardPath to any dir
+    if (action == Qt::MoveAction && FileUtils::containsStandardPath(srcUris)) {
+        return false;
+    }
+
     bool b_trash_item = false;
     for(auto path : srcUris)
     {
@@ -571,8 +640,9 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         }
     }
     //drag from trash to another place, return false
-    if (b_trash_item && destDirUri != "trash:///")
-        return false;
+    //comment to fix can not drag to copy trash file,link to bug#117741
+//    if (b_trash_item && destDirUri != "trash:///")
+//        return false;
 
     //fix drag file to trash issue, #42328
     if (destDirUri.startsWith("trash:///"))
@@ -585,6 +655,13 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         return true;
     }
 
+    //fix drag trash file to other path is copy issue,link to bug#117741
+    if (srcUris.first().startsWith("trash:///") && action == Qt::MoveAction){
+        //not copy move, do target move to delete file in trash
+        action = Qt::TargetMoveAction;
+    }
+
+
     qDebug() << "dropMimeData:" <<action<<destDirUri;
     bool addHistory = true;
     //krme files can not move to other place, default set as copy action
@@ -599,6 +676,7 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
 
     auto op = FileOperationUtils::moveWithAction(srcUris, destDirUri, addHistory, action);
     connect(op, &FileOperation::operationFinished, this, [=](){
+        Peony::SoundEffect::getInstance()->copyOrMoveSucceedMusic();
         auto opInfo = op->getOperationInfo();
         auto targetUris = opInfo.get()->dests();
         Q_EMIT this->selectRequest(targetUris);
@@ -619,7 +697,29 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     return true;
 }
 
-void FileItemModel::sendPathChangeRequest(const QString &uri)
+void FileItemModel::sendPathChangeRequest(const QString &destUri, const QString &sourceUri)
 {
-    Q_EMIT this->changePathRequest(uri, true, true);
+    Q_EMIT this->changePathRequest(destUri, sourceUri);
+}
+
+void FileItemModel::setShowFileExtensions(bool show)
+{
+    m_showFileExtension = show;
+    GlobalSettings::getInstance()->setGSettingValue(SHOW_FILE_EXTENSION, show);
+}
+
+const QModelIndex FileItemModel::indexFromItemAndUri(FileItem *item, const QString &uri)
+{
+    if(!item)
+        return QModelIndex();
+
+    GFile *left = g_file_new_for_uri(item->uri().toUtf8().constData());
+    GFile *right = g_file_new_for_uri(uri.toUtf8().constData());
+    bool equal = g_file_equal(left, right);
+    g_object_unref(left);
+    g_object_unref(right);
+    if (equal) {
+        return item->firstColumnIndex();
+    }
+    return QModelIndex();
 }
