@@ -57,6 +57,7 @@ public:
         ModifiedDate,
         FileType,
         FileSize,
+        TrashOriginPath,
         Owner,
         Other
     };
@@ -207,7 +208,12 @@ public:
 
     Qt::DropActions supportedDropActions() const override;
     Qt::DropActions supportedDragActions() const override;
-    void sendPathChangeRequest(const QString &uri);
+    void sendPathChangeRequest(const QString &destUri, const QString &sourceUri);
+
+    void setShowFileExtensions(bool show);
+
+private:
+    const QModelIndex indexFromItemAndUri(FileItem *item, const QString &uri);
 
 Q_SIGNALS:
     /*!
@@ -239,7 +245,10 @@ Q_SIGNALS:
     void updated();
 
     void selectRequest(const QStringList &uris);
-    void changePathRequest(const QString &uri, bool addHistory, bool forceUpdate);
+    void changePathRequest(const QString &destUri, const QString &sourceUri);
+
+    void signal_itemAdded(const QString& uri);/* 新增文件（夹），item创建完成 */
+    void thumbnailUpdated(const QString& uri);
 
 public Q_SLOTS:
     /*!
@@ -270,6 +279,7 @@ private:
     bool m_is_positive = false;
     bool m_can_expand = false;
     QString m_root_uri = "file:///";
+    bool m_showFileExtension = true;
 };
 
 }
