@@ -25,6 +25,7 @@
 #include "file-item.h"
 #include "file-item-proxy-filter-sort-model.h"
 #include "file-info.h"
+#include "file-info-job.h"
 #include "file-meta-info.h"
 #include "file-label-model.h"
 
@@ -40,17 +41,54 @@
 #include <QLocale>
 #include <QCollator>
 
+#include <QRegularExpression>
+
 using namespace Peony;
 
 QLocale locale = QLocale(QLocale::system().name());
 QCollator comparer = QCollator(locale);
 
+const QString getModelDirectoryUri(FileItemProxyFilterSortModel *model)
+{
+    FileItemModel *srcModel = qobject_cast<FileItemModel *>(model->sourceModel());
+    if (!srcModel) {
+        qInfo()<<"source model not avaliable now";
+        return nullptr;
+    }
+    return srcModel->getRootUri();
+}
+
+void setModelMetaInfo(FileItemProxyFilterSortModel *model, const QString &key, const QVariant &value)
+{
+    auto uri = getModelDirectoryUri(model);
+    if (uri.isEmpty()) {
+        qCritical()<<"set model meta info failed, can not get model directory uri";
+    } else {
+        auto fileMetaInfo = FileMetaInfo::fromUri(getModelDirectoryUri(model));
+        if (fileMetaInfo) {
+            fileMetaInfo->setMetaInfoVariant(key, value);
+        } else {
+            qCritical()<<"set model meta info failed, can not get model meta info.";
+        }
+    }
+}
+
 FileItemProxyFilterSortModel::FileItemProxyFilterSortModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
     setDynamicSortFilter(false);
     //enable number sort, like 100 is after 99
     comparer.setNumericMode(true);
     auto settings = GlobalSettings::getInstance();
+    m_settings = settings;
+
+    m_sortTimer = new QTimer(this);
+    m_sortTimer->setSingleShot(true);
+    connect(m_sortTimer, &QTimer::timeout, this, [=]{
+        checkSortSettings();
+        qDebug()<<"sort type:"<<m_sortType<<" sort order:"<<m_sortOrder<<" folder first:"<<m_folder_first;
+        return QSortFilterProxyModel::sort(m_sortType, m_sortOrder);
+    });
+
     m_show_hidden = settings->isExist(SHOW_HIDDEN_PREFERENCE)? settings->getValue(SHOW_HIDDEN_PREFERENCE).toBool(): false;
     connect(GlobalSettings::getInstance(), &GlobalSettings::valueChanged, this, [=] (const QString& key) {
         if (SHOW_HIDDEN_PREFERENCE == key) {
@@ -58,8 +96,6 @@ FileItemProxyFilterSortModel::FileItemProxyFilterSortModel(QObject *parent) : QS
             invalidateFilter();
         }
     });
-    m_use_default_name_sort_order = settings->isExist(SORT_CHINESE_FIRST)? settings->getValue(SORT_CHINESE_FIRST).toBool(): false;
-    m_folder_first = settings->isExist(SORT_FOLDER_FIRST)? settings->getValue(SORT_FOLDER_FIRST).toBool(): true;
 }
 
 void FileItemProxyFilterSortModel::setSourceModel(QAbstractItemModel *model)
@@ -67,7 +103,27 @@ void FileItemProxyFilterSortModel::setSourceModel(QAbstractItemModel *model)
     if (sourceModel())
         disconnect(sourceModel());
     QSortFilterProxyModel::setSourceModel(model);
-    FileItemModel *file_item_model = static_cast<FileItemModel*>(model);
+    //FileItemModel *file_item_model = static_cast<FileItemModel*>(model);
+
+    auto fileInfo = FileInfo::fromUri(getModelDirectoryUri(this));
+    if (!fileInfo.get()->isEmptyInfo()) {
+        auto job = new FileInfoJob(fileInfo);
+        job->setAutoDelete();
+        connect(job, &FileInfoJob::queryAsyncFinished, this, [=]{
+            checkSortSettings();
+            update();
+        });
+        job->queryAsync();
+    } else {
+        checkSortSettings();
+    }
+
+    connect(m_settings, &GlobalSettings::valueChanged, this, [=](const QString &key){
+        if (key == USE_GLOBAL_DEFAULT_SORTING) {
+            setUseGlobalSort(m_settings->getValue(key).toBool());
+        }
+    });
+
     //connect(file_item_model, &FileItemModel::updated, this, &FileItemProxyFilterSortModel::update);
 }
 
@@ -111,55 +167,103 @@ bool FileItemProxyFilterSortModel::lessThan(const QModelIndex &left, const QMode
         auto leftItem = model->itemFromIndex(left);
         auto rightItem = model->itemFromIndex(right);
         if (!(leftItem->hasChildren() && rightItem->hasChildren())) {
-            //make folder always has a higher order.
-            if (!leftItem->hasChildren() && !rightItem->hasChildren()) {
-                goto default_sort;
-            }
-            if (m_folder_first) {
+            //make folder always has a higher order
+            if ((leftItem->hasChildren() || rightItem->hasChildren()) && m_folder_first) {
                 bool lesser = leftItem->hasChildren();
                 if (sortOrder() == Qt::AscendingOrder)
                     return lesser;
                 return !lesser;
             }
+        }else if (sortColumn() != FileItemModel::ModifiedDate){
+            goto default_sort;
         }
 
-default_sort:
+        //fix bug#97408,change indicator meanings
+        //箭头向上为升序，向下为降序，与通常的理解对应，对比了UOS是这样的
+        //将所有排序对比跟之前的方式反过来，小于改为大于，返回true的改为false
         switch (sortColumn()) {
         case FileItemModel::FileName: {
-            if (FileOperationUtils::leftNameIsDuplicatedFileOfRightName(leftItem->m_info->displayName(), rightItem->m_info->displayName())) {
-                return FileOperationUtils::leftNameLesserThanRightName(leftItem->info()->displayName(), rightItem->info()->displayName());
-            }
-            if (m_use_default_name_sort_order) {
-                QString leftDisplayName = leftItem->m_info->displayName();
-                QString rightDisplayName = rightItem->m_info->displayName();
-
-                //fix chinese first sort wrong issue, link to bug#70836
-                if(startWithChinese(leftDisplayName) && ! startWithChinese(rightDisplayName))
-                    return false;
-                else if(! startWithChinese(leftDisplayName) && startWithChinese(rightDisplayName))
-                    return true;
-                else
-                    return comparer.compare(leftDisplayName, rightDisplayName) < 0;
-            }
-            //return leftItem->m_info->displayName().toLower() < rightItem->m_info->displayName().toLower();
-            return comparer.compare(leftItem->m_info->displayName(), rightItem->m_info->displayName()) < 0;
+            goto default_sort;
         }
         case FileItemModel::FileSize: {
-            return leftItem->m_info->size() < rightItem->m_info->size();
+//            qDebug() << "FileSize:" <<leftItem->m_info->displayName()<<leftItem->m_info->size()
+//                     <<rightItem->m_info->displayName()<<rightItem->m_info->size();
+            //fix refresh sort order change issue, use file name to compare, link to bug#92525
+            if (leftItem->m_info->size() == rightItem->m_info->size())
+            {
+                goto default_sort;
+            }
+            return leftItem->m_info->size() > rightItem->m_info->size();
         }
         case FileItemModel::FileType: {
-            return leftItem->m_info->fileType() < rightItem->m_info->fileType();
+            //fix refresh sort order change issue, use file name to compare, link to bug#92525
+            if (leftItem->m_info->fileType() == rightItem->m_info->fileType())
+            {
+                 goto default_sort;
+            }
+            return leftItem->m_info->fileType() > rightItem->m_info->fileType();
         }
         case FileItemModel::ModifiedDate: {
             //delete time sort in trash, fix bug#63093
             if (leftItem->uri().startsWith("trash://"))
-                return leftItem->m_info->deletionDate() < rightItem->m_info->deletionDate();
+            {
+                if (leftItem->m_info->deletionDate() == rightItem->m_info->deletionDate())
+                {
+                    goto default_sort;
+                }
+                return leftItem->m_info->deletionDate() > rightItem->m_info->deletionDate();
+            }
 
-            return leftItem->m_info->modifiedTime() < rightItem->m_info->modifiedTime();
+            //non trash files, use modifiedTime sort
+            if (leftItem->m_info->modifiedTime() == rightItem->m_info->modifiedTime())
+            {
+                goto default_sort;
+            }
+            return leftItem->m_info->modifiedTime() > rightItem->m_info->modifiedTime();
+        }
+        case FileItemModel::TrashOriginPath: {
+            auto leftString = leftItem->m_info->property("orig-path").toString();
+            auto rightString = rightItem->m_info->property("orig-path").toString();
+            if (leftString == rightString) {
+                goto default_sort;
+            }
+            return comparer.compare(leftString, rightString) > 0;
         }
         default:
             break;
         }
+
+default_sort:
+        //function was deprecated
+//        if (FileOperationUtils::leftNameIsDuplicatedFileOfRightName(leftItem->m_info->displayName(), rightItem->m_info->displayName())) {
+//            return FileOperationUtils::leftNameLesserThanRightName(leftItem->info()->displayName(), rightItem->info()->displayName());
+//        }
+
+        //when other sort value is the same, use sort by name way，link to bug#92525
+        //排序条件下的值相等时，使用名称进行排序，保持排序稳定，刷新后不改变, 关联bug#92525
+        QString leftDisplayName = leftItem->m_info->displayName();
+        QString rightDisplayName = rightItem->m_info->displayName();
+        if (m_use_default_name_sort_order) {
+            //fix chinese first sort wrong issue, link to bug#70836
+            //fix bug#97408,change indicator meanings
+            bool lesser = true;
+            if(startWithChinese(leftDisplayName) && ! startWithChinese(rightDisplayName)) {
+                // fix #103343
+                lesser = true;
+                if (sortOrder() == Qt::AscendingOrder)
+                    return lesser;
+                return !lesser;
+            }
+            else if(! startWithChinese(leftDisplayName) && startWithChinese(rightDisplayName)) {
+                lesser = false;
+                if (sortOrder() == Qt::AscendingOrder)
+                    return lesser;
+                return !lesser;
+            }
+            else
+                return comparer.compare(leftDisplayName, rightDisplayName) > 0;
+        }
+        return comparer.compare(leftDisplayName, rightDisplayName) > 0;
     }
 
     return QSortFilterProxyModel::lessThan(left, right);
@@ -173,6 +277,15 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
     auto childIndex = model->index(sourceRow, 0, sourceParent);
     if (childIndex.isValid()) {
         auto item = static_cast<FileItem*>(childIndex.internalPointer());
+
+        /* task#63345 通过.hidden文件来设置隐藏文件和目录 */
+        FileInfo* fileInfo = FileInfo::fromUri(item->uri()).get();
+        bool isHidden = fileInfo->property(G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN).toBool();
+        //qDebug()<<"File view .hidden file hidden,uri:"<<item->uri()<<" isHidden:"<<isHidden;
+        if(isHidden && !fileInfo->displayName().startsWith(".")){/* .xxx文件遵循是否显示隐藏文件的逻辑 */
+           return false;
+        }//end
+
         if(!item->shouldShow())
             return false;
         if (!m_show_hidden) {
@@ -180,9 +293,10 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
             //QMessageBox::warning(nullptr, "filter", item->m_info->displayName());
             //qDebug()<<item->m_info->displayName();
             if (item->m_info->displayName() != nullptr) {
-                if (item->m_info->displayName().at(0) == '.')
+                if (item->m_info->displayName().at(0) == '.') {
                     //qDebug()<<sourceRow<<item->m_info->displayName()<<model->rowCount(sourceParent);
                     return false;
+                }
             }
         }
         //regExp
@@ -194,6 +308,16 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
         if (targetUri.startsWith("file:///media/") && targetUri.endsWith("/2691-6AB8"))
             return false;
 
+        //not show system orgin lost+found and sec_storage_data folder in DATA, fix bug#67084
+        /* not show system orgin lost+found and bbox_logs folder in file:///data, fix bug#104820、bug#105714 */
+        if(targetUri.endsWith("data/bbox_logs",Qt::CaseInsensitive))
+            return false;
+        if (targetUri.endsWith("data/lost+found",Qt::CaseInsensitive) || targetUri.endsWith("data/sec_storage_data",Qt::CaseInsensitive))
+        {
+            if (! item->m_info->canWrite() && ! item->m_info->canExecute())
+               return false;
+        }
+
         //FIXME use display name to hide 839 MB disk
         if (item->m_info->displayName().contains("839 MB"))
             return false;
@@ -206,7 +330,18 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
             return false;
         if (! checkFileSizeOrTypeFilter(item->m_info->size(), item->m_info->isDir()))
             return false;
-        if (! checkFileNameFilter(item->m_info->displayName()))
+
+        //fix bug162927, desktop file should consider file name
+        if (item->uri().endsWith(".desktop")){
+            QString originName = item->uri().split("/").last();
+            QString AppName = item->m_info->displayName();
+            //对性能有影响，暂时屏蔽，后续再考虑优化
+//           if (! item->info()->canExecute())
+//               AppName = FileUtils::getApplicationName(item->uri());
+           if (! checkFileNameFilter(AppName) && ! checkFileNameFilter(originName))
+               return false;
+        }
+        else if (! checkFileNameFilter(item->m_info->displayName()))
             return false;
 
         //check the file label filter conditions
@@ -281,6 +416,42 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
             if (! find)
                 return false;
         }
+
+        if (!m_mimeTypeFilters.isEmpty()) {
+            if (!m_mimeTypeFilters.contains(fileInfo->fileType())) {
+                return false;
+            }
+        }
+
+        if (!m_nameFilters.isEmpty()) {
+            if (!fileInfo->isDir()) {
+                bool contains = false;
+                for (auto nameFilter : m_nameFilters) {
+
+                    QRegularExpression rx(QRegularExpression::wildcardToRegularExpression(nameFilter), this->filterCaseSensitivity()? QRegularExpression::NoPatternOption: QRegularExpression::CaseInsensitiveOption);
+                    QRegularExpressionMatch match = rx.match(fileInfo->displayName());
+                    if (match.hasMatch()) {
+                        contains = true;
+                        break;
+                    }
+                }
+                if (!contains) {
+                    return false;
+                }
+            }
+        }
+
+        QDir::Filters dirFilters = QDir::Filters(m_dirFilters);
+        if (m_dirFilters != -1) {
+            bool showFiles = dirFilters & QDir::Files;
+            bool showDirs = dirFilters & QDir::Dirs || dirFilters & QDir::AllDirs;
+            if (!showFiles && !fileInfo->isDir()) {
+                return false;
+            }
+            if (!showDirs && fileInfo->isDir()) {
+                return false;
+            }
+        }
     }
     return true;
 }
@@ -292,13 +463,64 @@ bool FileItemProxyFilterSortModel::checkFileNameFilter(const QString &displayNam
 
     for(auto key:m_file_name_list)
     {
-        if (displayName.contains(key))
+        //Filter criteria are not case sensitive. fix bug#92478
+        if (displayName.contains(key, Qt::CaseInsensitive))
             return true;
     }
 
     return false;
 }
 
+void FileItemProxyFilterSortModel::checkSortSettings()
+{
+    m_use_global_sort = m_settings->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool();
+    if (m_use_global_sort) {
+        m_show_hidden = m_settings->isExist(SHOW_HIDDEN_PREFERENCE)? m_settings->getValue(SHOW_HIDDEN_PREFERENCE).toBool(): false;
+        m_use_default_name_sort_order = m_settings->isExist(SORT_CHINESE_FIRST)? m_settings->getValue(SORT_CHINESE_FIRST).toBool(): false;
+        m_folder_first = m_settings->isExist(SORT_FOLDER_FIRST)? m_settings->getValue(SORT_FOLDER_FIRST).toBool(): true;
+    } else {
+        auto info = FileInfo::fromUri(getModelDirectoryUri(this));
+        auto fileMetaInfo = FileMetaInfo::fromUri(getModelDirectoryUri(this));
+        if (fileMetaInfo && !info->isEmptyInfo()) {
+            m_show_hidden = fileMetaInfo->getMetaInfoVariant(SHOW_HIDDEN_PREFERENCE).isValid()? fileMetaInfo->getMetaInfoVariant(SHOW_HIDDEN_PREFERENCE).toBool(): false;
+            m_use_default_name_sort_order = fileMetaInfo->getMetaInfoVariant(SORT_CHINESE_FIRST).isValid()? fileMetaInfo->getMetaInfoVariant(SORT_CHINESE_FIRST).toBool(): true;
+            m_folder_first = fileMetaInfo->getMetaInfoVariant(SORT_FOLDER_FIRST).isValid()? fileMetaInfo->getMetaInfoVariant(SORT_FOLDER_FIRST).toBool(): true;
+        } else {
+            qCritical()<<"could not get metainfo"<<getModelDirectoryUri(this);
+            m_show_hidden = false;
+            m_use_default_name_sort_order = true;
+            m_folder_first = true;
+        }
+    }
+}
+
+void FileItemProxyFilterSortModel::setSelectionModeHint(QAbstractItemView::SelectionMode mode)
+{
+    setProperty("selectionMode", int(mode));
+    Q_EMIT this->setSelectionModeChanged();
+}
+
+QVariant FileItemProxyFilterSortModel::getDirectorySettings(const QString &key)
+{
+    auto metaInfo = FileMetaInfo::fromUri(getModelDirectoryUri(this));
+    if (metaInfo) {
+        return metaInfo->getMetaInfoVariant(key);
+    } else {
+        qCritical()<<"can not get meta info"<<getModelDirectoryUri(this);
+    }
+    return QVariant();
+}
+
+void FileItemProxyFilterSortModel::setDirectorySettings(const QString &key, const QVariant &value)
+{
+    auto metaInfo = FileMetaInfo::fromUri(getModelDirectoryUri(this));
+    if (metaInfo) {
+        return metaInfo->setMetaInfoVariant(key, value);
+    } else {
+        qCritical()<<"can not set meta info"<<getModelDirectoryUri(this);
+    }
+}
+
 bool FileItemProxyFilterSortModel::checkFileTypeFilter(QString type) const
 {
     //qDebug()<<"m_show_file_type: "<<m_show_file_type<<" "<<type;
@@ -351,7 +573,7 @@ bool FileItemProxyFilterSortModel::checkFileTypeFilter(QString type) const
         }
         case AUDIO:
         {
-            if (type.contains(Audio_Type))
+            if (type.contains(Audio_Type) || type.contains("application/x-smaf"))
                 return true;
             break;
         }
@@ -359,7 +581,7 @@ bool FileItemProxyFilterSortModel::checkFileTypeFilter(QString type) const
         {
             //exclude classfied types, show the rest other types
             if (type != Folder_Type && ! type.contains(Image_Type) && ! type.contains(Video_Type)
-                    && ! type.contains(Text_Type) && !type.contains(Wps_Type) && ! type.contains(Audio_Type))
+                    && ! type.contains(Text_Type) && !type.contains(Wps_Type) && ! type.contains(Audio_Type) && !type.contains("application/x-smaf"))
                 return true;
             break;
         }
@@ -514,16 +736,33 @@ void FileItemProxyFilterSortModel::update()
     invalidateFilter();
 }
 
+void FileItemProxyFilterSortModel::setUseGlobalSort(bool use)
+{
+    m_use_global_sort = use;
+    checkSortSettings();
+    update();
+}
+
 void FileItemProxyFilterSortModel::setShowHidden(bool showHidden)
 {
-    GlobalSettings::getInstance()->setGSettingValue(SHOW_HIDDEN_PREFERENCE, showHidden);
+    if (GlobalSettings::getInstance()->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool()) {
+        GlobalSettings::getInstance()->setGSettingValue(SHOW_HIDDEN_PREFERENCE, showHidden);
+    } else {
+        setModelMetaInfo(this, SHOW_HIDDEN_PREFERENCE, showHidden);
+    }
+
     m_show_hidden = showHidden;
     invalidateFilter();
 }
 
 void FileItemProxyFilterSortModel::setUseDefaultNameSortOrder(bool use)
 {
-    GlobalSettings::getInstance()->setValue(SORT_CHINESE_FIRST, use);
+    if (GlobalSettings::getInstance()->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool()) {
+        GlobalSettings::getInstance()->setValue(SORT_CHINESE_FIRST, use);
+    } else {
+        setModelMetaInfo(this, SORT_CHINESE_FIRST, use);
+    }
+
     m_use_default_name_sort_order = use;
     beginResetModel();
     sort(sortColumn()>0? sortColumn(): 0, sortOrder()==Qt::DescendingOrder? Qt::DescendingOrder: Qt::AscendingOrder);
@@ -532,7 +771,12 @@ void FileItemProxyFilterSortModel::setUseDefaultNameSortOrder(bool use)
 
 void FileItemProxyFilterSortModel::setFolderFirst(bool folderFirst)
 {
-    GlobalSettings::getInstance()->setValue(SORT_FOLDER_FIRST, folderFirst);
+    if (GlobalSettings::getInstance()->getValue(USE_GLOBAL_DEFAULT_SORTING).toBool()) {
+        GlobalSettings::getInstance()->setValue(SORT_FOLDER_FIRST, folderFirst);
+    } else {
+        setModelMetaInfo(this, SORT_FOLDER_FIRST, folderFirst);
+    }
+
     m_folder_first = folderFirst;
     beginResetModel();
     sort(sortColumn()>0? sortColumn(): 0, sortOrder()==Qt::DescendingOrder? Qt::DescendingOrder: Qt::AscendingOrder);
@@ -600,6 +844,10 @@ void FileItemProxyFilterSortModel::clearConditions()
     m_file_type_list.clear();
     m_file_size_list.clear();
     m_modify_time_list.clear();
+
+    m_mimeTypeFilters.clear();
+    m_nameFilters.clear();
+    m_dirFilters = -1;
 }
 
 void FileItemProxyFilterSortModel::setFilterConditions(int fileType, int modifyTime, int fileSize)
@@ -610,6 +858,15 @@ void FileItemProxyFilterSortModel::setFilterConditions(int fileType, int modifyT
     invalidateFilter();
 }
 
+void FileItemProxyFilterSortModel::setFilterConditions(const QStringList &mimeTypeFilters, const QStringList &nameFilters,  QDir::Filters dirFilters, Qt::CaseSensitivity caseSensitivity)
+{
+    m_mimeTypeFilters = mimeTypeFilters;
+    m_nameFilters = nameFilters;
+    m_dirFilters = dirFilters;
+    setFilterCaseSensitivity(caseSensitivity);
+    invalidateFilter();
+}
+
 void FileItemProxyFilterSortModel::setFilterLabelConditions(QString name, QColor color)
 {
     m_label_name = name;
@@ -675,6 +932,39 @@ QModelIndexList FileItemProxyFilterSortModel::getAllFileIndexes()
     return l;
 }
 
+QAbstractItemView::SelectionMode FileItemProxyFilterSortModel::getSelectionModeHint()
+{
+    if (property("selectionMode").isValid()) {
+        return QAbstractItemView::SelectionMode(property("selectionMode").toInt());
+    }
+    return QAbstractItemView::NoSelection;
+}
+
+void FileItemProxyFilterSortModel::sort(int column, Qt::SortOrder order)
+{
+    m_sortType = column;
+    m_sortOrder = order;
+    if(!m_sortTimer->isActive()){
+        m_sortTimer->start(50);
+    }
+}
+
+int FileItemProxyFilterSortModel::expectedSortType()
+{
+    return m_sortType;
+}
+
+Qt::SortOrder FileItemProxyFilterSortModel::expectedSortOrder()
+{
+    return m_sortOrder;
+}
+
+void FileItemProxyFilterSortModel::manualUpdateExpectedSortInfo(int sortType, Qt::SortOrder order)
+{
+    m_sortType = sortType;
+    m_sortOrder = order;
+}
+
 QStringList FileItemProxyFilterSortModel::getAllFileUris()
 {
     QStringList l;
