@@ -33,6 +33,7 @@
 #include "gobject-template.h"
 #include "linux-pwd-helper.h"
 #include "side-bar-separator-item.h"
+#include "global-fstabdata.h"
 #include <udisks/udisks.h>
 #include <sys/stat.h>
 
@@ -41,6 +42,8 @@
 #include <QMessageBox>
 #include <QPushButton>
 #include <QUrl>
+#include <QApplication>
+#include <QFile>
 
 using namespace Peony;
 
@@ -95,35 +98,54 @@ QModelIndex SideBarFileSystemItem::lastColumnIndex()
 
 bool SideBarFileSystemItem::filterShowRow()
 {
-    if (m_uri == "file:///data" && FileUtils::isFileExsit("file:///data/usershare")) {
-        return false;
-    }
-    if (m_uri.startsWith("file:///home/")){
-        return false;
-    }
-    if (m_uri != "file:///") {
+    return SideBarAbstractItem::filterShowRow();
 
-        QString gvfsDisplayName = m_mountPoint;
-        QString gvfsUnixDevice = m_device;
+//    if (m_uri == "file:///data" && FileUtils::isFileExsit("file:///data/usershare")) {
+//        return false;
+//    }
+//    if (m_uri.startsWith("file:///home/")){
+//        return false;
+//    }
+//    if (m_uri != "file:///") {
+
+//        QString gvfsDisplayName = m_mountPoint;
+//        QString gvfsUnixDevice = m_device;
 
 
-        if (!gvfsUnixDevice.isNull() && (gvfsDisplayName.contains("DVD")))
-            return true;
+//        if (!gvfsUnixDevice.isNull() && (gvfsDisplayName.contains("DVD")))
+//            return true;
 
-        if(!gvfsUnixDevice.isNull() && !gvfsDisplayName.contains(":"))
-            return false;//Filter some non-mountable drive items
+//        if(!gvfsUnixDevice.isNull() && !gvfsDisplayName.contains(":"))
+//            return false;//Filter some non-mountable drive items
 
-        if (isMounted())
-            return true;
-        if (isRemoveable() && isUnmountable()) {
-            return true;
-        }
-        if (!isRemoveable() && !isEjectable() && !isStopable())
-            return true;
-        return false;
+//        if (isMounted())
+//            return true;
+//        if (isRemoveable() && isUnmountable()) {
+//            return true;
+//        }
+//        if (!isRemoveable() && !isEjectable() && !isStopable())
+//            return true;
+//        return false;
+//    }
+
+    //    return true;
+}
+
+QString SideBarFileSystemItem::getDeviceUUID(const char *device)
+{
+    struct stat statbuf;
+    if (stat (device, &statbuf) != 0)
+    {
+        return nullptr;
     }
 
-    return true;
+    g_autoptr(UDisksClient) client = udisks_client_new_sync (NULL,NULL);
+    g_autoptr(UDisksBlock) block = udisks_client_get_block_for_dev(client, statbuf.st_rdev);
+    if (!block)
+        return nullptr;
+
+    const gchar *uuid = udisks_block_get_id_uuid(block);
+    return uuid;
 }
 
 void SideBarFileSystemItem::initDirInfo(const QString &uri)
@@ -134,7 +156,7 @@ void SideBarFileSystemItem::initDirInfo(const QString &uri)
 
    m_children    = nullptr;
    m_watcher     = nullptr;
-   m_iconName    = "gtk-directory";
+   m_iconName    = "folder";
    m_device      = m_mountPoint = "";
 
    m_uri         = uri;
@@ -142,6 +164,11 @@ void SideBarFileSystemItem::initDirInfo(const QString &uri)
    m_displayName = info.get()->displayName();
    m_mounted = m_ejectable = m_stopable = m_removeable = m_mountable = false;
    m_unmountable = false;
+
+   if (uri == "computer:///ukui-data-volume") {
+       m_displayName = tr("Data");
+       m_iconName = "drive-harddisk";
+   }
 }
 
 void SideBarFileSystemItem::initComputerInfo()
@@ -173,6 +200,10 @@ void SideBarFileSystemItem::initVolumeInfo(const Experimental_Peony::Volume &vol
     m_uri = m_mountPoint = volumeItem.mountPoint();
     m_mounted   = !m_uri.isEmpty();
     m_displayName = volumeItem.name() + "(" + m_device + ")";
+    m_isVolume = true;
+    m_hidden = volumeItem.getHidden();
+
+    bool isData = false;
 
     /* 手机和空光盘的m_uri需要额外设置 */
     if(m_uri.isEmpty()){
@@ -181,22 +212,53 @@ void SideBarFileSystemItem::initVolumeInfo(const Experimental_Peony::Volume &vol
             m_mounted = true;
         }
         else if(m_device.contains("/dev/sr") &&
-                (m_displayName.contains("DVD") ||m_displayName.contains("CD")))//更好的方法区分是否是空光盘?
+                (FileUtils::isEmptyDisc(m_device) /* 空光盘linkto bug#127947 */
+                 || Experimental_Peony::VolumeManager::getInstance()->isEmptyDrive(volumeItem)))/* 空光驱,linkto bug#133362 */
         {
             m_mounted=true;
             m_unmountable = m_mountable=false;
             m_uri = "burn://";
+        } else {
+            /* 未挂载的volume尝试匹配computer:///的uri */
+            auto itemUris = FileUtils::getChildrenUris("computer:///");
+            for (auto itemUri : itemUris) {
+                auto unixDevice = FileUtils::getUnixDevice(itemUri);
+                if (unixDevice == m_device) {
+                    m_uri = itemUri;
+                    GlobalFstabData *globalFstabData = GlobalFstabData::getInstance();
+                    if(!globalFstabData->getUuidState()){
+                        if(globalFstabData->isMountPoints(m_device.toUtf8(), "/data")){
+                            isData = true;
+                        }
+                    }else{
+                        if(globalFstabData->isMountPoints(getDeviceUUID(m_device.toUtf8()), "/data")){
+                            isData = true;
+                        }
+                    }
+                    break;
+                }
+            }
         }
 
     }else{
         m_uri = "file://" + m_uri;
     }
     /* 文件系统项特殊处理 */
-    if("file:///"==m_uri){
+    if("file:///" == m_uri){
         m_unmountable = m_mountable = m_ejectable = m_stopable = false;
-        m_mounted=true;
+        m_mounted = true;
         m_displayName = QObject::tr("File System");
-        m_iconName="drive-harddisk-system-symbolic";
+        m_iconName = "drive-harddisk-system-symbolic";
+    }else if("file:///data" == m_uri || isData){
+        m_unmountable = m_mountable = m_ejectable = m_stopable = false;
+        m_mounted = true;
+        m_displayName = QObject::tr("Data");
+        m_iconName = "drive-harddisk";
+    }
+
+    // kydrive特殊处理
+    if (m_device.startsWith("kydrive:")) {
+        m_unmountable = false;
     }
 }
 
@@ -204,6 +266,7 @@ void SideBarFileSystemItem::clearChildren()
 {
     if(m_watcher)
         m_watcher->stopMonitor();
+    m_watcher = nullptr;
     SideBarAbstractItem::clearChildren();
 }
 
@@ -219,6 +282,7 @@ void SideBarFileSystemItem::slot_volumeDeviceAdd(const Experimental_Peony::Volum
         }
     }
 
+    qDebug()<<__func__<<__LINE__<<addItem.device()<<addItem.getHidden();
     SideBarFileSystemItem *item = new SideBarFileSystemItem(nullptr,
                                                           addItem,
                                                           this,
@@ -238,6 +302,7 @@ void SideBarFileSystemItem::slot_volumeDeviceRemove(const QString &removeDevice)
             m_model->beginRemoveRows(firstColumnIndex(), index, index);
             m_children->removeOne(child);
             m_model->endRemoveRows();
+            qDebug()<<__func__<<__LINE__<<child->m_device;
             child->deleteLater();
             break;
         }
@@ -246,11 +311,18 @@ void SideBarFileSystemItem::slot_volumeDeviceRemove(const QString &removeDevice)
 }
 
 void SideBarFileSystemItem::slot_volumeDeviceMount(const Experimental_Peony::Volume &volume)
-{
+{   
     QString device = volume.device();
     QString mountPoint = volume.mountPoint();
     if(mountPoint.isEmpty())
         return;
+
+    //过滤smb子项挂载后会更新computer:///ukui-data-volume，导致数据不准确
+    QUrl serverUrl = QUrl(volume.mountPoint());
+    if("smb"==serverUrl.scheme().toLower() && !serverUrl.path().isEmpty()){
+        return;
+    }
+
     //更新model,元素信息更新
     for(auto item:*m_children){
         if(item->m_device == device){
@@ -258,15 +330,22 @@ void SideBarFileSystemItem::slot_volumeDeviceMount(const Experimental_Peony::Vol
             item->m_mountPoint = mountPoint;     /* 设置挂载点，属性页会用到 */
             item->m_mountable =volume.canMount();
             item->m_unmountable = true;
-            item->m_uri = "file://" + mountPoint;/* 更新uri,为了枚举操作 */
-            /* 手机和空光盘的m_uri需要额外设置 */
+            if (device.startsWith("kydrive:")) {
+                item->m_unmountable = false;
+            }
+            item->m_iconName = volume.icon();
+            /* 更新uri,为了枚举操作 */
             if(device.startsWith("/dev/bus/usb"))/* 手机设备(mtp、gphoto2)的uri */
                 item->m_uri = "computer:///" + volume.name() + ".volume";
-            else if(item->m_device.contains("/dev/sr") &&
-                    (item->m_displayName.contains("DVD") ||item->m_displayName.contains("CD")))/* 空光盘 */
+            else if(item->m_device.contains("/dev/sr") && FileUtils::isEmptyDisc(item->m_device))/* 空光盘 */
             {
                 item->m_uri="burn:///";
-            }
+            }else if(mountPoint.startsWith("cdda://sr")){/* 音乐光盘的targeturi无需加"file://"，例如：target-uri: cdda://sr0/ */
+                item->m_uri = mountPoint;
+            }else{
+                item->m_uri = "file://" + mountPoint;
+            }//end
+
             m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
             break;
         }
@@ -283,11 +362,22 @@ void SideBarFileSystemItem::slot_volumeDeviceUnmount(const QString &unmountDevic
     //更新model,元素信息更新
     for(auto& item:*m_children){
         if(item->m_mountPoint == unmountDevice){/* 依靠挂载点属性匹配 */
-            item->m_uri = "";                   /* 分区卸载后不可以做枚举操作 */
+            item->m_uri = nullptr;                   /* 分区卸载后不可以做枚举操作 */
+            auto itemUris = FileUtils::getChildrenUris("computer:///");   /*  重新寻找匹配卸载点的computer uri，避免item被过滤  */
+            for (auto itemUri : itemUris) {
+                auto unixDevice = FileUtils::getUnixDevice(itemUri);
+                if (unixDevice == item->m_device) {
+                    item->m_uri = itemUri;
+                    break;
+                }
+            }
             item->m_mountPoint = "";            /*挂载点置空，属性页会用到? */
             item->m_mounted = false;            /* 分区已卸载 */
             item->m_unmountable = false;
             item->m_mountable = true;
+            if("burn:///" == unmountDevice && item->m_device.startsWith("/dev/sr")){/* 空光盘弹出后光驱要显示挂载状态，与其他光盘弹出后状态保持一致,hotfix bug#156012 */
+                item->m_mounted = true;
+            }
             m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
             break;
         }
@@ -296,17 +386,51 @@ void SideBarFileSystemItem::slot_volumeDeviceUnmount(const QString &unmountDevic
 
 void SideBarFileSystemItem::slot_volumeDeviceUpdate(const Experimental_Peony::Volume &updateDevice, QString property)
 {
-    qDebug()<<__func__<<__LINE__;
+    qDebug()<<__func__<<__LINE__<<updateDevice.device();
     QString device;
     if(property != "name")
         return;
 
+    auto gvolume = updateDevice.getGVolume();
     device = updateDevice.device();
     for(auto& item:*m_children){
-        if(item->m_device == device){
+        if("file:///" == item->uri() || "computer:///ukui-data-volume" == item->uri())/* hotfix bug#125095 打开文件管理器后，插入U盘，侧边栏中文件系统消失 */
+            continue;
+
+        auto fs_item = qobject_cast<SideBarFileSystemItem *>(item);
+        auto item_gvolume = fs_item->getVolume().getGVolume();
+        if(!item_gvolume || !gvolume)
+            continue;
+
+        if(item_gvolume == gvolume){
             item->m_displayName = updateDevice.name() + "(" + device + ")";
+            item->m_hidden = updateDevice.getHidden();
+            item->m_iconName = updateDevice.icon();
+            qDebug()<<__func__<<__LINE__<<item->m_device<<item->m_displayName<<item->m_hidden;
+            // 更新mount信息, 加密分区改变时需要
+            g_autoptr (GMount) gmount = g_volume_get_mount(gvolume);
+            if (gmount) {
+                item->m_mounted = true;            /* 更新挂载状态 */
+                QString mountPoint = updateDevice.mountPoint();
+                item->m_mountPoint = mountPoint;     /* 设置挂载点，属性页会用到 */
+                item->m_mountable = updateDevice.canMount();
+                item->m_unmountable = true;
+                item->m_iconName = updateDevice.icon();
+
+                /* 更新uri,为了枚举操作 */
+                if(device.startsWith("/dev/bus/usb"))/* 手机设备(mtp、gphoto2)的uri */
+                    item->m_uri = "computer:///" + updateDevice.name() + ".volume";
+                else if(item->m_device.contains("/dev/sr") && FileUtils::isEmptyDisc(item->m_device))/* 空光盘 */
+                {
+                    item->m_uri="burn:///";
+                }else if(mountPoint.startsWith("cdda://sr")){/* 音乐光盘的targeturi无需加"file://"，例如：target-uri: cdda://sr0/ */
+                    item->m_uri = mountPoint;
+                }else{
+                    item->m_uri = "file://" + mountPoint;
+                }//end
+            }
             //model更新
-             m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
+            m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
             break;
         }
     }
@@ -315,29 +439,35 @@ void SideBarFileSystemItem::slot_volumeDeviceUpdate(const Experimental_Peony::Vo
 
 void SideBarFileSystemItem::slot_fileCreate(const QString &uri)
 {
-    //qDebug()<<"created:"<<uri;
+    qDebug()<<"created:"<<uri;
     for (auto item : *m_children) {
-        if (item->uri() == uri) {
+        if (item->m_uri == uri) {
             return;
         }
     }
+    /* 更新fileinfo */
+    auto info = FileInfo::fromUri(uri);
+    FileInfoJob job(uri, this);
+    job.querySync();
 
-    SideBarFileSystemItem *item = new SideBarFileSystemItem(uri,
-                                                            nullptr,
-                                                            this,
-                                                            m_model);
-
+    if (!(info->isDir())){/* 只显示文件夹，文件不显示 */
+        return;
+    }
+    /* 新增项 */
+    SideBarFileSystemItem *item = new SideBarFileSystemItem(info->uri(), nullptr, this, m_model);
     m_model->beginInsertRows(this->firstColumnIndex(), m_children->count(), m_children->count());
     m_children->append(item);
     m_model->endInsertRows();
+    m_model->indexUpdated(this->firstColumnIndex());/* 如果添加了非空项，则需要删除空项 */
     m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
+
 }
 
 void SideBarFileSystemItem::slot_fileDelete(const QString &uri)
 {
-    //qDebug()<<"deleted:"<<uri;
+    qDebug()<<"deleted:"<<uri;
     for (auto child : *m_children) {
-        if (child->uri() == uri) {
+        if (child->m_uri == uri) {
             int index = m_children->indexOf(child);
             m_model->beginRemoveRows(firstColumnIndex(), index, index);
             m_children->removeOne(child);
@@ -346,14 +476,14 @@ void SideBarFileSystemItem::slot_fileDelete(const QString &uri)
             break;
         }
     }
-    m_model->indexUpdated(this->firstColumnIndex());
+    m_model->indexUpdated(this->firstColumnIndex());/* 如果删除了所有项，则需要添加空项 */
 }
 
 void SideBarFileSystemItem::slot_fileRename(const QString &oldUri, const QString &newUri)
 {
     qDebug()<<"rename,old uri:"<<oldUri<<" new uri:"<<newUri;
     for (auto item : *m_children){
-        if (item->uri() == oldUri){
+        if (item->m_uri == oldUri){
             item->m_uri = newUri;
             auto info = FileInfo::fromUri(item->m_uri);
             if (info->displayName().isEmpty()) {
@@ -375,8 +505,12 @@ void SideBarFileSystemItem::slot_enumeratorPrepared(const std::shared_ptr<GError
 
 void SideBarFileSystemItem::slot_enumeratorFinish(bool successed)
 {
-    if(!successed)
+    if(!successed) {
+        auto separator = new SideBarSeparatorItem(SideBarSeparatorItem::EmptyFile, this, m_model);
+        this->m_children->prepend(separator);
+        m_model->insertRows(0, 1, this->firstColumnIndex());
         return;
+    }
 
     auto infos = m_enumerator->getChildren();
     bool isEmpty = true;
@@ -452,18 +586,33 @@ void SideBarFileSystemItem::findChildren()
             m_model->dataChanged(item->firstColumnIndex(), item->lastColumnIndex());
         }
 
+        if (FileUtils::isFileExsit("file:///data/usershare")) {
+            m_model->beginInsertRows(this->firstColumnIndex(), m_children->count(), m_children->count());
+            SideBarFileSystemItem* item = new SideBarFileSystemItem("computer:///ukui-data-volume", nullptr, this, m_model);
+            m_children->append(item);
+            m_model->endInsertRows();
+        }
+
     }else{
         //对挂载点进行已存在文件的枚举操作
         QString enumdir = m_uri;
-        if(m_uri.startsWith("computer:///")){//GFileEnumerator不识别computer:///，只识别file:///
+        if (m_uri == "computer:///ukui-data-volume") {
+            enumdir = "file:///data";
+        } else if(m_uri.startsWith("computer:///")){//GFileEnumerator不识别computer:///，只识别file:///
             auto info = FileInfo::fromUri(m_uri);
             FileInfoJob job(info);
             job.querySync();
             enumdir = info.get()->targetUri();
         }
 
-        if(!m_enumerator)
+        if (!m_enumerator) {
             m_enumerator= new FileEnumerator();
+        } else {
+            m_enumerator->cancel();
+            m_enumerator->deleteLater();
+            m_enumerator = new FileEnumerator();
+        }
+
         m_enumerator->setEnumerateDirectory(enumdir);
         m_enumerator->setEnumerateWithInfoJob();
 
@@ -474,20 +623,21 @@ void SideBarFileSystemItem::findChildren()
     /* 设备动态增减处理 */
     if("computer:///" == m_uri){
         auto volumeManager = Experimental_Peony::VolumeManager::getInstance();
-        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeAdd,this,&SideBarFileSystemItem::slot_volumeDeviceAdd);
-        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeRemove,this,&SideBarFileSystemItem::slot_volumeDeviceRemove);
-        connect(volumeManager,&Experimental_Peony::VolumeManager::mountAdd,this,&SideBarFileSystemItem::slot_volumeDeviceMount);
-        connect(volumeManager,&Experimental_Peony::VolumeManager::mountRemove,this,&SideBarFileSystemItem::slot_volumeDeviceUnmount);
-        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeUpdate,this,&SideBarFileSystemItem::slot_volumeDeviceUpdate);
+        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeAdd,this,&SideBarFileSystemItem::slot_volumeDeviceAdd, Qt::DirectConnection);
+        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeRemove,this,&SideBarFileSystemItem::slot_volumeDeviceRemove, Qt::DirectConnection);
+        connect(volumeManager,&Experimental_Peony::VolumeManager::mountAdd,this,&SideBarFileSystemItem::slot_volumeDeviceMount, Qt::DirectConnection);
+        connect(volumeManager,&Experimental_Peony::VolumeManager::mountRemove,this,&SideBarFileSystemItem::slot_volumeDeviceUnmount, Qt::DirectConnection);
+        connect(volumeManager,&Experimental_Peony::VolumeManager::volumeUpdate,this,&SideBarFileSystemItem::slot_volumeDeviceUpdate, Qt::DirectConnection);
 
     }else{
         /* 对挂载目录监听 */
-        if(!m_watcher)
+        if(!m_watcher){
             m_watcher = std::make_shared<FileWatcher>(m_uri, nullptr, true);
+            connect(m_watcher.get(),&FileWatcher::fileCreated,this,&SideBarFileSystemItem::slot_fileCreate);
+            connect(m_watcher.get(),&FileWatcher::fileDeleted,this,&SideBarFileSystemItem::slot_fileDelete);
+            connect(m_watcher.get(),&FileWatcher::fileRenamed,this,&SideBarFileSystemItem::slot_fileRename);
+        }
         m_watcher->setMonitorChildrenChange();
-        connect(m_watcher.get(),&FileWatcher::fileCreated,this,&SideBarFileSystemItem::slot_fileCreate);
-        connect(m_watcher.get(),&FileWatcher::fileDeleted,this,&SideBarFileSystemItem::slot_fileDelete);
-        connect(m_watcher.get(),&FileWatcher::fileRenamed,this,&SideBarFileSystemItem::slot_fileRename);
         m_watcher->startMonitor();
     }
 
@@ -525,6 +675,9 @@ bool SideBarFileSystemItem::isMounted()
 
 void SideBarFileSystemItem::unmount()
 {
+    if (m_device.startsWith("kydrive:")) {
+        return;
+    }
     SyncThread *syncThread = new SyncThread(m_uri);
     QThread* currentThread = new QThread();
     syncThread->moveToThread(currentThread);
@@ -578,7 +731,7 @@ static UDisksObject *get_object_from_block_device (UDisksClient *client,const gc
     object = UDISKS_OBJECT (g_dbus_interface_dup_object (G_DBUS_INTERFACE (block)));
     g_object_unref (block);
 
-    crypto_backing_device = udisks_block_get_crypto_backing_device ((udisks_object_peek_block (object)));
+    crypto_backing_device = udisks_block_get_crypto_backing_device ((udisks_object_get_block (object)));
     crypto_backing_object = udisks_client_get_object (client, crypto_backing_device);
     if (crypto_backing_object != NULL)
     {
@@ -590,7 +743,7 @@ static UDisksObject *get_object_from_block_device (UDisksClient *client,const gc
 
 void SideBarFileSystemItem::ejectOrUnmount()
 {
-    if (isRemoveable())
+    if (isRemoveable()||isStopable())
         eject(G_MOUNT_UNMOUNT_NONE);
 
     else if (isUnmountable())
@@ -605,16 +758,23 @@ void SideBarFileSystemItem::mount()
 
 //update udisk file info
 void SideBarFileSystemItem::updateFileInfo(SideBarFileSystemItem *pThis){
-    //FIXME: replace BLOCKING api in ui thread.
-    auto fileInfo = FileInfo::fromUri(pThis->m_uri);
-    FileInfoJob fileJob(fileInfo);
-    fileJob.querySync();
+//    //FIXME: replace BLOCKING api in ui thread.
+//    auto fileInfo = FileInfo::fromUri(pThis->m_uri);
+//    FileInfoJob fileJob(fileInfo);
+//    fileJob.querySync();
 
-    QString tmpName = FileUtils::getFileDisplayName(pThis->m_uri);
+//    QString tmpName = FileUtils::getFileDisplayName(pThis->m_uri);
 
-    //old's drive name -> now's volume name. fix #17968
-    FileUtils::queryVolumeInfo(pThis->m_uri,pThis->m_volume_name,pThis->m_unix_device,tmpName);
-    //icon name.
-    pThis->m_iconName = FileUtils::getFileIconName(pThis->m_uri,false);
+//    //old's drive name -> now's volume name. fix #17968
+//    FileUtils::queryVolumeInfo(pThis->m_uri,pThis->m_volume_name,pThis->m_unix_device,tmpName);
+//    //icon name.
+//    pThis->m_iconName = FileUtils::getFileIconName(pThis->m_uri,false);
+
+//    // fix #81852, refer to #57660, #70014, task #25343
+//    if (pThis->m_iconName == "drive-harddisk-usb") {
+//        double size = FileUtils::getDeviceSize(pThis->m_unix_device.toUtf8().constData());
+//        if (size < 128) {
+//            pThis->m_iconName = "drive-removable-media-usb";
+//        }
+//    }
 }
-
