@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef VOLUMEMANAGER_H
-#define VOLUMEMANAGER_H
+#ifndef VOLUME_MANAGER_H
+#define VOLUME_MANAGER_H
 
 #include "peony-core_global.h"
 
@@ -264,6 +264,10 @@ Q_SIGNALS:
     void volumeRemoved(const std::shared_ptr<Volume> &volume);
     void mountAdded(const std::shared_ptr<Mount> &mount);
     void mountRemoved(const std::shared_ptr<Mount> &mount);
+    void volumeChanged(const std::shared_ptr<Volume> &volume);
+
+    // internal signal
+    void fileUnmounted(const QString &uri);
 
 protected:
     static void drive_connected_callback(GVolumeMonitor *monitor,
@@ -290,13 +294,15 @@ protected:
                                        GMount *mount,
                                        VolumeManager *p_this);
 
+    static void volume_changed_callback(GVolumeMonitor *monitor, GVolume *volume, VolumeManager *p_this);
+
 public Q_SLOTS:
     static void unmount(const QString &uri);
 
 protected:
     static void unmount_cb(GFile *file,
                            GAsyncResult *result,
-                           GError **error);
+                           GError **error, QString *targetUri);
 
 private:
     explicit VolumeManager(QObject *parent = nullptr);
@@ -309,6 +315,7 @@ private:
     gulong m_volume_removed_handle = 0;
     gulong m_mount_added_handle = 0;
     gulong m_mount_removed_handle = 0;
+    gulong m_volume_changed_handle = 0;
 };
 
 }
