@@ -32,6 +32,7 @@
 #include "icon-view-delegate.h"
 #include "clipboard-utils.h"
 #include "desktop-item-model.h"
+#include "emblem-provider.h"
 
 #include <QPushButton>
 #include <QWidget>
@@ -88,14 +89,12 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     }
 
     bool bCutFile = false;
-    if (Peony::FileUtils::isSamePath(ClipboardUtils::getClipedFilesParentUri(), view->getDirectoryUri())){
-        if (ClipboardUtils::isClipboardFilesBeCut()) {
-            auto clipedUris = ClipboardUtils::getClipboardFilesUris();
-            if (clipedUris.contains(FileUtils::urlEncode(index.data(DesktopItemModel::UriRole).toString()))) {
-                painter->setOpacity(0.5);
-                bCutFile = true;
-                qDebug()<<"cut item in desktop"<<index.data();
-            }
+    if (ClipboardUtils::isDesktopFilesBeCut() && ClipboardUtils::isClipboardFilesBeCut()){
+        auto clipedUris = ClipboardUtils::getClipboardFilesUris();
+        if (clipedUris.contains(FileUtils::urlEncode(index.data(DesktopItemModel::UriRole).toString()))) {
+            painter->setOpacity(0.5);
+            bCutFile = true;
+            qDebug()<<"cut item in desktop"<<index.data();
         }
     }
 
@@ -103,7 +102,7 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     if (!view->indexWidget(index)) {
         //painter->setClipRect(opt.rect);
         painter->save();
-        painter->setRenderHint(QPainter::Antialiasing);
+        painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
         if (opt.state.testFlag(QStyle::State_MouseOver) && !opt.state.testFlag(QStyle::State_Selected)) {
             QColor color = m_styled_button->palette().highlight().color();
             color.setAlpha(255*0.3);//half transparent
@@ -148,9 +147,14 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
     auto text = opt.text;
     opt.text = nullptr;
 
+    painter->save();
+    painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, opt.widget);
+    painter->restore();
 
     opt.text = text;
+    opt.font = qApp->font();
+    opt.fontMetrics = qApp->fontMetrics();
 
     painter->save();
     //painter->translate(visualRect.topLeft());
@@ -221,6 +225,8 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
 
     painter->restore();
 
+    QList<int> emblemPoses = {4, 3, 2, 1}; //bottom right, bottom left, top right, top left
+
     //paint link icon and locker icon
     FileInfo* file = FileInfo::fromUri(index.data(Qt::UserRole).toString()).get();
     if ((index.data(Qt::UserRole).toString() != "computer:///") && (index.data(Qt::UserRole).toString() != "trash:///")) {
@@ -256,17 +262,27 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
 
         if (! file->canRead())
         {
+            emblemPoses.removeOne(1);
             QIcon symbolicLinkIcon = QIcon::fromTheme("emblem-unreadable");
+            painter->save();
+            painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
             symbolicLinkIcon.paint(painter, linkRect, Qt::AlignCenter);
+            painter->restore();
         }
-        else if(! file->canWrite() && ! file->canExecute())
+        else if(! file->canWrite()/* && ! file->canExecute()*/)
         {
+            //只读图标对应可读不可写情况，与可执行权限无关，link to bug#99998
+            emblemPoses.removeOne(1);
             QIcon symbolicLinkIcon = QIcon::fromTheme("emblem-readonly");
+            painter->save();
+            painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
             symbolicLinkIcon.paint(painter, linkRect, Qt::AlignCenter);
+            painter->restore();
         }
     }
 
     if (index.data(Qt::UserRole + 1).toBool()) {
+        emblemPoses.removeOne(3);
         QSize symbolicIconSize = QSize(16, 16);
         int offset = 8;
         switch (view->zoomLevel()) {
@@ -292,12 +308,103 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
             break;
         }
         }
-        auto topRight = opt.rect.topRight();
-        topRight.setX(topRight.x() - offset - symbolicIconSize.width());
-        topRight.setY(topRight.y() + offset);
-        auto linkRect = QRect(topRight, symbolicIconSize);
-        QIcon symbolicLinkIcon = QIcon::fromTheme("emblem-symbolic-link");
+//        auto topRight = opt.rect.topRight();
+//        topRight.setX(topRight.x() - offset - symbolicIconSize.width());
+//        topRight.setY(topRight.y() + offset);
+//        auto linkRect = QRect(topRight, symbolicIconSize);
+        //Adjust link emblem to topLeft.link story#8354
+        auto topLeft = opt.rect.topLeft();
+        topLeft.setX(opt.rect.topLeft().x() + 10);
+        topLeft.setY(opt.rect.topLeft().y() + offset + iconRect.height() - symbolicIconSize.height());
+        auto linkRect = QRect(topLeft, symbolicIconSize);
+        QIcon symbolicLinkIcon = QIcon::fromTheme("emblem-link-symbolic");
+        painter->save();
+        painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
         symbolicLinkIcon.paint(painter, linkRect, Qt::AlignCenter);
+        painter->restore();
+    }
+
+    // paint extension emblems, FIXME: adjust layout, and implemet on indexwidget, other view.
+    auto extensionsEmblems = EmblemProviderManager::getInstance()->getAllEmblemsForUri(file->uri());
+    for (auto extensionsEmblem : extensionsEmblems) {
+        if (emblemPoses.isEmpty()) {
+            break;
+        }
+
+        QIcon icon = QIcon::fromTheme(extensionsEmblem);
+
+        QSize emblemsIconSize = QSize(16, 16);
+        int offset = 8;
+        switch (view->zoomLevel()) {
+        case DesktopIconView::Small: {
+            emblemsIconSize = QSize(8, 8);
+            offset = 10;
+            break;
+        }
+        case DesktopIconView::Normal: {
+            break;
+        }
+        case DesktopIconView::Large: {
+            offset = 4;
+            emblemsIconSize = QSize(24, 24);
+            break;
+        }
+        case DesktopIconView::Huge: {
+            offset = 2;
+            emblemsIconSize = QSize(32, 32);
+            break;
+        }
+        default: {
+            break;
+        }
+        }
+
+        if (!icon.isNull()) {
+            int pos = emblemPoses.takeFirst();
+            painter->save();
+            painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
+            switch (pos) {
+            case 1: {
+                icon.paint(painter,
+                           opt.rect.topLeft().x() + 10,
+                           opt.rect.topLeft().y() + 10,
+                           emblemsIconSize.width(),
+                           emblemsIconSize.height(),
+                           Qt::AlignCenter);
+                break;
+            }
+            case 2: {
+                icon.paint(painter,
+                           opt.rect.topRight().x() - offset - emblemsIconSize.width(),
+                           opt.rect.topRight().y() + 10,
+                           emblemsIconSize.width(),
+                           emblemsIconSize.height(),
+                           Qt::AlignCenter);
+                break;
+            }
+            case 3: {
+                icon.paint(painter,
+                           opt.rect.topLeft().x() + 10,
+                           opt.rect.topLeft().y() + offset + iconRect.height() - emblemsIconSize.height(),
+                           emblemsIconSize.width(),
+                           emblemsIconSize.height(),
+                           Qt::AlignCenter);
+                break;
+            }
+            case 4: {
+                icon.paint(painter,
+                           opt.rect.topRight().x() - offset - emblemsIconSize.width(),
+                           opt.rect.topRight().y() + offset + iconRect.height() - emblemsIconSize.height(),
+                           emblemsIconSize.width(),
+                           emblemsIconSize.height(),
+                           Qt::AlignCenter);
+                break;
+            }
+            default:
+                break;
+            }
+            painter->restore();
+        }
     }
 
     /*
@@ -313,20 +420,19 @@ void DesktopIconViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
 
 QSize DesktopIconViewDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    auto view = qobject_cast<Peony::DesktopIconView*>(parent());
-    auto zoomLevel = view->zoomLevel();
-    switch (zoomLevel) {
-    case DesktopIconView::Small:
-        return QSize(60, 70);
-    case DesktopIconView::Normal:
-        return QSize(90, 100);
-    case DesktopIconView::Large:
-        return QSize(105, 128);
-    case DesktopIconView::Huge:
-        return QSize(120, 150);
-    default:
-        return QSize(90, 100);
-    }
+    QStyleOptionViewItem opt = option;
+    initStyleOption(&opt, index);
+
+    auto view = qobject_cast<DesktopIconView*>(this->parent());
+    auto iconSize = view->iconSize();
+    QFont font = view->font();
+    font.setFamily(view->font().defaultFamily());
+    // asume max text size.
+    font.setPointSize(15);
+    auto fm = QFontMetrics(font);
+    int width = iconSize.width() + 41;
+    int height = iconSize.height() + fm.ascent()*2 + 20;
+    return QSize(width, height);
 }
 
 QWidget *DesktopIconViewDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -364,11 +470,7 @@ QWidget *DesktopIconViewDelegate::createEditor(QWidget *parent, const QStyleOpti
     });
 
     getView()->setEditFlag(true);
-    connect(edit, &IconViewEditor::returnPressed, getView(), [=]() {
-        this->setModelData(edit, nullptr, index);
-        edit->deleteLater();
-        getView()->setEditFlag(false);
-    });
+    connect(edit, &IconViewEditor::returnPressed, this, &DesktopIconViewDelegate::slot_finishEdit);
     connect(edit, &IconViewEditor::destroyed, getView(), [=](){
         getView()->setEditFlag(false);
     });
@@ -458,6 +560,18 @@ void DesktopIconViewDelegate::setModelData(QWidget *editor, QAbstractItemModel *
     }
 }
 
+void DesktopIconViewDelegate::slot_finishEdit()
+{
+    auto edit = qobject_cast<QWidget *>(sender());
+    commitData(edit);
+    closeEditor(edit, QAbstractItemDelegate::SubmitModelCache);
+    if(edit){
+        delete edit;
+        edit = nullptr;
+    }
+    getView()->setEditFlag(false);
+}
+
 DesktopIconView *DesktopIconViewDelegate::getView() const
 {
     auto view = qobject_cast<Peony::DesktopIconView*>(parent());
