@@ -39,6 +39,9 @@
 
 #include "peony-desktop-application.h"
 #include "desktop-icon-view.h"
+#include "global-settings.h"
+#include "sound-effect.h"
+#include "desktop-icon-view-delegate.h"
 
 #include <QStandardPaths>
 #include <QIcon>
@@ -136,8 +139,16 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
             job->querySync();
 
             // locate new item =====
+            //task#74174 扩展模式下支持拖拽图标放置到扩展屏, 创建文件获取当前view
+            auto view = ((PeonyDesktopApplication*)qApp)->getIconView(QCursor::pos());
+            //校验图标是否已经满了，如果满了寻找没有满的view
+            if (view && view->isFull()) {
+                Peony::DesktopIconView *notFullView = ((PeonyDesktopApplication*)qApp)->getNotFullView();
+                if (notFullView) {
+                    view = notFullView;
+                }
+            }
 
-            auto view = PeonyDesktopApplication::getIconView();
             auto itemRectHash = view->getCurrentItemRects();
             auto grid = view->gridSize();
             auto viewRect = view->viewport()->rect();
@@ -150,18 +161,28 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 notEmptyRegion += rect;
             }
 
+            int isUpdateIconGeometry = false;
             if (!view->isRenaming()) {
                 view->setFileMetaInfoPos(uri, QPoint(-1, -1));
             } else {
                 m_items_need_relayout.removeOne(uri);
                 view->setRenaming(false);
+                isUpdateIconGeometry = true;
             }
 
             auto metaInfoPos = view->getFileMetaInfoPos(uri);
+            QSize iconSize;
+            if (itemRectHash.isEmpty()) {
+                auto delegate = qobject_cast<DesktopIconViewDelegate *>(view->itemDelegate());
+                iconSize = delegate->sizeHint(QStyleOptionViewItem(), QModelIndex());
+            } else {
+                iconSize = itemRectHash.values().first().size();
+            }
+
             if (metaInfoPos.x() >= 0) {
                 // check if overlapped, it might happend whild drag out and in desktop view.
-                auto indexRect = QRect(metaInfoPos, itemRectHash.values().first().size());
-                if (notEmptyRegion.contains(indexRect.center())) {
+                auto indexRect = QRect(metaInfoPos, iconSize);
+                if (notEmptyRegion.intersects(indexRect)) {
 
                     // move index to closest empty grid.
                     auto next = indexRect;
@@ -179,7 +200,7 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                             //put item to next column first row
                             next.moveTo(next.x() + grid.width(), top);
                         }
-                        if (notEmptyRegion.contains(next.center()))
+                        if (notEmptyRegion.intersects(next))
                             continue;
 
                         isEmptyPos = true;
@@ -189,6 +210,8 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                         // handle position locate in DesktopIconView::itemInserted().
                         view->setFileMetaInfoPos(info->uri(), next.topLeft());
                     }
+                } else if (isUpdateIconGeometry){
+                    FileInfo::fromUri(uri).get()->setProperty("iconGeometry", QRect(view->mapToGlobal(metaInfoPos), iconSize));
                 }
 
                 this->beginInsertRows(QModelIndex(), m_files.count(), m_files.count());
@@ -203,12 +226,13 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 //this->endResetModel();
                 Q_EMIT this->requestUpdateItemPositions();
                 Q_EMIT this->requestLayoutNewItem(info->uri());
-                Q_EMIT this->fileCreated(uri);
+                //task#74174 在当前view中创建文件
+                view->fileCreated(uri);
                 return;
             }
 
             // aligin exsited rect
-            int marginTop = notEmptyRegion.boundingRect().top();
+            int marginTop = notEmptyRegion.isEmpty()? view->getViewRect().top() : notEmptyRegion.boundingRect().top();
             while (marginTop - grid.height() >= 0) {
                 marginTop -= grid.height();
             }
@@ -218,8 +242,8 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 marginLeft -= grid.width();
             }
 
-            auto indexRect = QRect(QPoint(marginLeft, marginTop), itemRectHash.isEmpty()? QSize(): itemRectHash.values().first().size());
-            if (notEmptyRegion.contains(indexRect.center())) {
+            auto indexRect = QRect(QPoint(marginLeft, marginTop), iconSize);
+            if (notEmptyRegion.intersects(indexRect)) {
 
                 // move index to closest empty grid.
                 auto next = indexRect;
@@ -237,7 +261,7 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                         //put item to next column first row
                         next.moveTo(next.x() + grid.width(), top);
                     }
-                    if (notEmptyRegion.contains(next.center()))
+                    if (notEmptyRegion.intersects(next))
                         continue;
 
                     isEmptyPos = true;
@@ -263,21 +287,35 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
             //this->endResetModel();
             Q_EMIT this->requestUpdateItemPositions();
             Q_EMIT this->requestLayoutNewItem(info->uri());
-            Q_EMIT this->fileCreated(uri);
+            //task#74174 在当前view中创建文件
+            view->fileCreated(uri);
+        }
+        else{
+            //file content changed, need update fileinfo, fix bug#76908
+            auto job = new FileInfoJob(info);
+            job->setAutoDelete();
+            job->querySync();
         }
     });
 
     m_desktop_watcher->connect(m_desktop_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
         m_items_need_relayout.removeOne(uri);
-        auto view = PeonyDesktopApplication::getIconView();
-        view->removeItemRect(uri);
-
+        auto info = FileInfo::fromUri(uri);
+        Peony::DesktopIconView *view = nullptr;
+        if (info.get()->isEmptyInfo()) {
+            view = ((PeonyDesktopApplication*)qApp)->removeUri(uri);
+        } else {
+            view = getIconView(uri);
+        }
         auto itemRectHash = view->getCurrentItemRects();
 
         for (auto info : m_files) {
             if (info->uri() == uri) {
                 //this->beginResetModel();
+                // continue fix #18155、#52228、#52231、#49442
+                // 注意有时不会走到view的aboutToRemoveRows中，所以需要在此调用relayoutAddedItem
                 this->beginRemoveRows(QModelIndex(), m_files.indexOf(info), m_files.indexOf(info));
+                view->relayoutExsitingItems(m_items_need_relayout);
                 m_files.removeOne(info);
                 this->endRemoveRows();
                 //this->endResetModel();
@@ -288,8 +326,6 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
     });
 
     m_desktop_watcher->connect(m_desktop_watcher.get(), &FileWatcher::fileChanged, [=](const QString &uri) {
-        auto view = PeonyDesktopApplication::getIconView();
-        auto itemRectHash = view->getCurrentItemRects();
 
         for (auto info : m_files) {
             if (info->uri() == uri) {
@@ -309,65 +345,90 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
         }
     });
 
+    //comment these code to fix bug#149540, story-view-19425
     //when system app uninstalled, delete link in desktop if exist
-    QString system_app_path = "file:///usr/share/applications/";
-    m_system_app_watcher = std::make_shared<FileWatcher>(system_app_path, this);
-    m_system_app_watcher->setMonitorChildrenChange(true);
-    auto mInfo = FileInfo::fromUri(system_app_path);
-    qDebug() <<"system_app_path:" <<mInfo->isDir();
-    this->connect(m_system_app_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
-        qDebug() << "m_system_app_watcher:" <<uri;
-        if (uri.endsWith(".desktop"))
-        {
-            QString fileName = uri;
-            fileName = fileName.replace(system_app_path, "");
-            qDebug() << "m_system_app_watcher:" <<fileName <<uri;
-            for (auto info : m_files) {
-                if (info->uri().endsWith(fileName)) {
-                    //this->beginResetModel();
-                    this->beginRemoveRows(QModelIndex(), m_files.indexOf(info), m_files.indexOf(info));
-                    m_files.removeOne(info);
-                    this->endRemoveRows();
-                    //this->endResetModel();
-                    Q_EMIT this->requestClearIndexWidget();
-                    Q_EMIT this->requestUpdateItemPositions();
-                    QStringList list;
-                    list.append(info->uri());
-                    FileOperationUtils::remove(list);
-                }
-            }
-        }
-    });
+//    QString system_app_path = "file:///usr/share/applications/";
+//    m_system_app_watcher = std::make_shared<FileWatcher>(system_app_path, this);
+//    m_system_app_watcher->setMonitorChildrenChange(true);
+//    auto mInfo = FileInfo::fromUri(system_app_path);
+//    qDebug() <<"system_app_path:" <<mInfo->isDir();
+//    this->connect(m_system_app_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
+//        qDebug() << "m_system_app_watcher:" <<uri;
+//        if (uri.endsWith(".desktop"))
+//        {
+//            QString fileName = uri;
+//            fileName = fileName.replace(system_app_path, "");
+//            qDebug() << "m_system_app_watcher:" <<fileName <<uri;
+//            for (auto info : m_files) {
+//                if (info->uri().endsWith(fileName)) {
+//                    //fix bug#136661, desktop file may be auto deleted wrong
+//                    //desktop file be deleted and then created
+//                    QString absPath = uri;
+//                    absPath = absPath.replace("file://", "");
+//                    QTimer::singleShot(100, this, [=](){
+//                    if (! QFile::exists(absPath)){
+//                        //this->beginResetModel();
+//                        this->beginRemoveRows(QModelIndex(), m_files.indexOf(info), m_files.indexOf(info));
+//                        m_files.removeOne(info);
+//                        this->endRemoveRows();
+//                        //this->endResetModel();
+//                        Q_EMIT this->requestClearIndexWidget();
+//                        Q_EMIT this->requestUpdateItemPositions();
+//                        //fix bug#148380, 148375 remove file not exist, deleted by app
+//                        if (QFile::exists(info->uri().replace("file://", ""))){
+//                            QStringList list;
+//                            list.append(info->uri());
+//                            //auto remove, link to task#10131
+//                            FileOperationUtils::remove(list);
+//                        }
+//                      }
+//                    });
+//                }
+//            }
+//        }
+//    });
 
-    //when andriod app uninstalled, delete link in desktop if exist
-    QString homePath = "file://" + QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
-    auto andriod_app_path = homePath + "/.local/share/applications/";
-    auto app_info = FileInfo::fromUri(andriod_app_path);
-    qDebug() <<"andriod_app_path:" <<app_info->isDir();
-    m_andriod_app_watcher = std::make_shared<FileWatcher>(andriod_app_path, this);
-    m_andriod_app_watcher->setMonitorChildrenChange(true);
-    this->connect(m_andriod_app_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
-        if (uri.endsWith(".desktop"))
-        {
-            QString fileName = uri;
-            fileName = fileName.replace(andriod_app_path, "");
-            qDebug() << "andriod_app_path:" <<fileName <<uri;
-            for (auto info : m_files) {
-                if (info->uri().endsWith(fileName)) {
-                    //this->beginResetModel();
-                    this->beginRemoveRows(QModelIndex(), m_files.indexOf(info), m_files.indexOf(info));
-                    m_files.removeOne(info);
-                    this->endRemoveRows();
-                    //this->endResetModel();
-                    Q_EMIT this->requestClearIndexWidget();
-                    Q_EMIT this->requestUpdateItemPositions();
-                    QStringList list;
-                    list.append(info->uri());
-                    FileOperationUtils::trash(list, false);
-                }
-            }
-        }
-    });
+//    //when andriod app uninstalled, delete link in desktop if exist
+//    QString homePath = "file://" + QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+//    auto andriod_app_path = homePath + "/.local/share/applications/";
+//    auto app_info = FileInfo::fromUri(andriod_app_path);
+//    qDebug() <<"andriod_app_path:" <<app_info->isDir();
+//    m_andriod_app_watcher = std::make_shared<FileWatcher>(andriod_app_path, this);
+//    m_andriod_app_watcher->setMonitorChildrenChange(true);
+//    this->connect(m_andriod_app_watcher.get(), &FileWatcher::fileDeleted, [=](const QString &uri) {
+//        if (uri.endsWith(".desktop"))
+//        {
+//            QString fileName = uri;
+//            fileName = fileName.replace(andriod_app_path, "");
+//            qDebug() << "andriod_app_path:" <<fileName <<uri;
+//            for (auto info : m_files) {
+//                if (info->uri().endsWith(fileName)) {
+//                    //fix bug#136661,android desktop file be auto deleted wrong
+//                    //desktop file be deleted and then created
+//                    QString absPath = uri;
+//                    absPath = absPath.replace("file://", "");
+//                    QTimer::singleShot(100, this, [=](){
+//                    if (! QFile::exists(absPath)){
+//                        //this->beginResetModel();
+//                        this->beginRemoveRows(QModelIndex(), m_files.indexOf(info), m_files.indexOf(info));
+//                        m_files.removeOne(info);
+//                        this->endRemoveRows();
+//                        //this->endResetModel();
+//                        Q_EMIT this->requestClearIndexWidget();
+//                        Q_EMIT this->requestUpdateItemPositions();
+//                        //fix bug#148380, 148375 remove file not exist, deleted by app
+//                        if (QFile::exists(info->uri().replace("file://", ""))){
+//                            QStringList list;
+//                            list.append(info->uri());
+//                            //auto remove, link to task#10131
+//                            FileOperationUtils::remove(list);
+//                         }
+//                       }
+//                    });
+//                }
+//            }
+//        }
+//    });
 
     //handle standard dir changing.
     m_dir_manager =new UserdirManager(this);
@@ -388,7 +449,7 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                 return;
             }
             m_renaming_file_pos.first = renamingUri;
-            m_renaming_file_pos.second = PeonyDesktopApplication::getIconView()->getFileMetaInfoPos(renamingUri);
+            m_renaming_file_pos.second = getIconView(renamingUri)->getFileMetaInfoPos(renamingUri);
         } else {
             m_renaming_file_pos.first = nullptr;
             m_renaming_file_pos.second = QPoint();
@@ -405,11 +466,25 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
                     m_renaming_file_pos.second = QPoint();
                     return;
                 }
-                m_renaming_file_pos.first = renamingUri;
-                m_items_need_relayout.removeOne(renamingUri);
-                m_items_need_relayout.removeOne(renamingUri + ".desktop");
-                PeonyDesktopApplication::getIconView()->updateItemPosByUri(renamingUri, m_renaming_file_pos.second);
-                PeonyDesktopApplication::getIconView()->setFileMetaInfoPos(renamingUri, m_renaming_file_pos.second);
+                auto view = getIconView(renamingUri);
+                QPoint target_pos = view->getCurrentItemRects().value(renamingUri).topLeft();
+                //desktop文件重命名时，如果存在相同文件则不会重命名成功。由于该文件uri不会变，所以pos不变，无需更新pos
+                if (target_pos.isNull() || (m_renaming_file_pos.second == target_pos)) {
+                    //desktop文件重命名成功
+                    m_renaming_file_pos.first = renamingUri;
+                    m_items_need_relayout.removeOne(renamingUri);
+                    m_items_need_relayout.removeOne(renamingUri + ".desktop");
+                    view->updateItemPosByUri(renamingUri, m_renaming_file_pos.second);
+                    view->setFileMetaInfoPos(renamingUri, m_renaming_file_pos.second);
+                } else {
+                    //desktop文件(uri)重命名失败
+                    QString &src_uri = info->m_src_uris.first();
+                    QTimer::singleShot(100, view, [=]() {
+                        view->setSelections(QStringList() << src_uri);
+                        view->scrollToSelection(src_uri);
+                        view->setFocus();
+                    });
+                }
             } else {
                 // restore/relayout?
             }
@@ -424,6 +499,16 @@ DesktopItemModel::DesktopItemModel(QObject *parent)
             m_renaming_operation_info = nullptr;
         }
     });
+
+    auto settings = GlobalSettings::getInstance();
+    m_showFileExtension = settings->isExist(SHOW_FILE_EXTENSION)? settings->getValue(SHOW_FILE_EXTENSION).toBool(): true;
+    connect(GlobalSettings::getInstance(), &GlobalSettings::valueChanged, this, [=] (const QString& key) {
+        if (SHOW_FILE_EXTENSION == key) {
+            m_showFileExtension= GlobalSettings::getInstance()->getValue(key).toBool();
+            beginResetModel();
+            endResetModel();
+        }
+    });
 }
 
 DesktopItemModel::~DesktopItemModel()
@@ -461,44 +546,10 @@ void DesktopItemModel::refreshInternal()
         ThumbnailManager::getInstance()->releaseThumbnail(info->uri());
     }
     m_files.clear();
-
-    auto desktopUri = "file://" + QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
-
-    //FIXME: replace BLOCKING api in ui thread.
-    if (!FileUtils::isFileExsit(desktopUri)) {
-        // try get correct desktop path delay.
-        //FIXME: replace BLOCKING api in ui thread.
-
-        if (findProgram("xdg-user-dirs-update")) {
-            do {
-                QProcess p;
-                p.setProgram("xdg-user-dirs-update");
-                p.start();
-                p.waitForFinished();
-                desktopUri = "file://" + QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
-            } while (!FileUtils::isFileExsit(desktopUri));
-        }
-
-        QTimer::singleShot(1000, this, [=](){
-            if (!FileUtils::isFileExsit(desktopUri)) {
-                endResetModel();
-                Q_EMIT refreshed();
-                refresh();
-            } else {
-                m_enumerator = new FileEnumerator(this);
-                m_enumerator->setAutoDelete();
-                m_enumerator->setEnumerateWithInfoJob();
-                m_enumerator->setEnumerateDirectory(desktopUri);
-                m_enumerator->connect(m_enumerator, &FileEnumerator::enumerateFinished, this, &DesktopItemModel::onEnumerateFinished);
-                m_enumerator->enumerateAsync();
-                endResetModel();
-            }
-        });
-        return;
-    }
-
     m_enumerator = new FileEnumerator(this);
+    connect(this, &DesktopItemModel::prepareRefresh, m_enumerator, &FileEnumerator::cancel, Qt::DirectConnection);
     m_enumerator->setAutoDelete();
+    QString desktopUri = "file://" + QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
     m_enumerator->setEnumerateDirectory(desktopUri);
     m_enumerator->connect(m_enumerator, &FileEnumerator::enumerateFinished, this, &DesktopItemModel::onEnumerateFinished);
     m_enumerator->enumerateAsync();
@@ -523,15 +574,34 @@ QVariant DesktopItemModel::data(const QModelIndex &index, int role) const
     //qDebug()<<"data"<<m_files.at(index.row())->uri();
     auto info = m_files.at(index.row());
     switch (role) {
-    case Qt::DisplayRole:
-        //fix bug#53504, desktop files not show same name issue
+    case Qt::DisplayRole:{
+        QString displayName = info->displayName();
         if (info->isDesktopFile())
         {
-            auto displayName = FileUtils::handleDesktopFileName(info->uri(), info->displayName());
-            return displayName;
+            displayName = FileUtils::handleDesktopFileName(info->uri(), info->displayName());
+            return QVariant(displayName);
         }
-        return info->displayName();
-    case Qt::ToolTipRole:
+        /* story#8359 【文件管理器】手动开启关闭文件拓展名 */
+        if(!m_showFileExtension){
+            if (info->isDir()) {
+                return QVariant(displayName);
+            }
+            return QVariant(FileUtils::getBaseNameOfFile(displayName));
+
+        }else
+            return QVariant(displayName);
+    }
+    case Qt::ToolTipRole: {
+        // fix #80257
+        switch (index.row()) {
+        case 0:
+            return tr("Computer");
+        case 1:
+            return tr("Trash");
+        default:
+            break;
+        }
+
         //fix bug#53504, desktop files not show same name issue
         if (info->isDesktopFile())
         {
@@ -539,12 +609,13 @@ QVariant DesktopItemModel::data(const QModelIndex &index, int role) const
             return displayName;
         }
         return info->displayName();
+    }
     case Qt::DecorationRole: {
         auto thumbnail = ThumbnailManager::getInstance()->tryGetThumbnail(info->uri());
         if (!thumbnail.isNull()) {
             return thumbnail;
         }
-        return QIcon::fromTheme(info->iconName(), QIcon::fromTheme("text-x-generic"));
+        return QIcon::fromTheme(info->iconName(), QIcon::fromTheme("unknown"));
     }
     case UriRole:
         return info->uri();
@@ -554,8 +625,21 @@ QVariant DesktopItemModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
-void DesktopItemModel::onEnumerateFinished()
+void DesktopItemModel::onEnumerateFinished(bool successed)
 {
+    if (!successed) {
+        qWarning()<<"failed to enumerate desktop";
+        beginResetModel();
+        m_files.clear();
+        endResetModel();
+        return;
+    }
+
+    // check if there is info querying, if true, wait querying finished.
+    while (!m_querying_files.isEmpty()) {
+        qApp->processEvents();
+    }
+
     //beginResetModel();
     beginRemoveRows(QModelIndex(), 0, m_files.count() - 1);
     m_files.clear();
@@ -579,15 +663,29 @@ void DesktopItemModel::onEnumerateFinished()
     //this->endResetModel();
     for (auto info : infos) {
         auto asyncJob = new FileInfoJob(info);
-        connect(asyncJob, &FileInfoJob::queryAsyncFinished, this, [=](){
+        connect(this, &DesktopItemModel::prepareRefresh, asyncJob, [=]{
+            asyncJob->cancel();
+            asyncJob->setProperty("isCancelled", true);
+        }, Qt::DirectConnection);
+        connect(asyncJob, &FileInfoJob::queryAsyncFinished, this, [=](bool successed){
             m_querying_files.removeOne(info);
+            if (!successed) {
+                m_files.removeOne(info);
+            }
+
+            if (asyncJob->property("isCancelled").toBool()) {
+                // quit loop to avoid invalid data inserted;
+                return;
+            }
+
             if (m_querying_files.isEmpty()) {
-                beginInsertRows(QModelIndex(), 0, m_files.count() - 1);
-                endInsertRows();
+                if (!m_files.isEmpty()) {
+                    beginInsertRows(QModelIndex(), 0, m_files.count() - 1);
+                    endInsertRows();
 
                 for (auto info : m_files) {
                     auto uri = info->uri();
-                    auto view = PeonyDesktopApplication::getIconView();
+                    auto view = getIconView(uri);
                     auto pos = view->getFileMetaInfoPos(info->uri());
                     if (pos.x() >= 0) {
                         view->updateItemPosByUri(info->uri(), pos);
@@ -595,10 +693,11 @@ void DesktopItemModel::onEnumerateFinished()
                         view->ensureItemPosByUri(uri);
                     }
 
-                    if (info->isDesktopFile()) {
-                        ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_thumbnail_watcher);
-                    } else {
-                        ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+                        if (info->isDesktopFile()) {
+                            ThumbnailManager::getInstance()->updateDesktopFileThumbnail(info->uri(), m_thumbnail_watcher);
+                        } else {
+                            ThumbnailManager::getInstance()->createThumbnail(info->uri(), m_thumbnail_watcher);
+                        }
                     }
                 }
 
@@ -612,8 +711,8 @@ void DesktopItemModel::onEnumerateFinished()
                     m_desktop_watcher->setMonitorChildrenChange(true);
                 }
                 m_desktop_watcher->startMonitor();
-                m_system_app_watcher->startMonitor();
-                m_andriod_app_watcher->startMonitor();
+//                m_system_app_watcher->startMonitor();
+//                m_andriod_app_watcher->startMonitor();
 
                 Q_EMIT refreshed();
 
@@ -629,11 +728,6 @@ void DesktopItemModel::clearFloatItems()
     m_items_need_relayout.clear();
 }
 
-void DesktopItemModel::relayoutAddedItems()
-{
-    PeonyDesktopApplication::getIconView()->relayoutExsitingItems(m_items_need_relayout);
-}
-
 bool DesktopItemModel::acceptDropAction() const
 {
     return m_accept_drop_action;
@@ -760,10 +854,19 @@ bool DesktopItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     //NOTE:
     //do not allow drop on it self.
     auto urls = data->urls();
+    if (urls.isEmpty())
+        return false;
+
+    bool hasPeonyEncodedUris = false;
+    if (data->hasFormat("peony-qt/encoded-uris")) {
+        if (!data->data("peony-qt/encoded-uris").isEmpty()) {
+            hasPeonyEncodedUris = true;
+        }
+    }
 
     QStringList srcUris;
-    if (data->hasFormat("peony-qt/encoded-uris")) {
-        srcUris = data->text().split(" ");
+    if (hasPeonyEncodedUris) {
+        srcUris = QString(data->data("peony-qt/encoded-uris")).split(" ");
         for (QString uri : srcUris) {
             if (uri.startsWith("recent://"))
                 srcUris.removeOne(uri);
@@ -791,6 +894,11 @@ bool DesktopItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         return false;
     }
 
+    //can not move StandardPath to any dir
+    if (action == Qt::MoveAction && FileUtils::containsStandardPath(srcUris)) {
+        return false;
+    }
+
     bool b_trash_item = false;
     for(auto path : srcUris)
     {
@@ -801,8 +909,9 @@ bool DesktopItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         }
     }
     //drag from trash to another place, return false
-    if (b_trash_item && destDirUri != "trash:///")
-        return false;
+    //comment to fix can not drag to copy trash file,link to bug#117741
+//    if (b_trash_item && destDirUri != "trash:///")
+//        return false;
 
     auto fileOpMgr = FileOperationManager::getInstance();
     bool addHistory = true;
@@ -819,12 +928,14 @@ bool DesktopItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         // 如果是保护箱删除时，不会反馈删除弹窗，保护箱文件不影响
         if(!(srcUris.first().startsWith("filesafe:///") &&
             (QString(srcUris.first()).remove("filesafe:///").indexOf("/") == -1))) {
-            if(canNotTrash){
-                FileOperationUtils::trash(srcUris, false);
-            }else {
-                FileTrashOperation *trashOp = new FileTrashOperation(srcUris);
-                fileOpMgr->startOperation(trashOp, addHistory);
-            }
+            //fix bug#91525, can trash file in U disk issue
+            FileOperationUtils::trash(srcUris, true);
+//            if(canNotTrash){
+//                FileOperationUtils::trash(srcUris, false);
+//            }else {
+//                FileTrashOperation *trashOp = new FileTrashOperation(srcUris);
+//                fileOpMgr->startOperation(trashOp, addHistory);
+//            }
         }
     } else {
         qDebug() << "DesktopItemModel dropMimeData:" <<action;
@@ -836,7 +947,16 @@ bool DesktopItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         if (srcUris.first().startsWith("filesafe:///"))
             action = Qt::CopyAction;
 
-        FileOperationUtils::moveWithAction(srcUris, destDirUri, true, action);
+        //fix drag trash file to other path is copy issue,link to bug#117741
+        if (srcUris.first().startsWith("trash:///") && action == Qt::MoveAction){
+            //not copy move, do target move to delete file in trash
+            action = Qt::TargetMoveAction;
+        }
+
+        auto op = FileOperationUtils::moveWithAction(srcUris, destDirUri, true, action);
+        op->connect(op, &FileOperation::operationFinished, this, [=](){
+            Peony::SoundEffect::getInstance()->copyOrMoveSucceedMusic();
+        });
     }
 
     //NOTE:
@@ -858,11 +978,36 @@ Qt::DropActions DesktopItemModel::supportedDragActions() const
 
 void DesktopItemModel::refresh()
 {
+    Q_EMIT prepareRefresh();
+
+    beginResetModel();
+    m_files.clear();
+    m_items_need_relayout.clear();
+//    auto app = static_cast<PeonyDesktopApplication *>(qApp);
+//    app->clearViewCache();
+    endResetModel();
+
     m_desktop_info = FileInfo::fromPath(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
     auto infoJob = new FileInfoJob(m_desktop_info);
     infoJob->setAutoDelete();
-    connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=](){
-        refreshInternal();
+    connect(infoJob, &FileInfoJob::queryAsyncFinished, this, [=](bool successed){
+        if (successed) {
+            refreshInternal();
+        } else {
+            qWarning()<<"desktop model refreshs: can not query desktop info"<<m_desktop_info->uri();
+        }
     });
+    connect(this, &DesktopItemModel::prepareRefresh, infoJob, &FileInfoJob::cancel, Qt::DirectConnection);
     infoJob->queryAsync();
 }
+
+Peony::DesktopIconView *DesktopItemModel::getIconView(const QString &uri)
+{
+    //获取当前屏幕的view
+    auto metaInfo = FileMetaInfo::fromUri(uri);
+    if (metaInfo) {
+        int id = metaInfo->getMetaInfoInt("peony-qt-desktop-id");
+        return ((PeonyDesktopApplication*)qApp)->getIconView(id);
+    }
+    return ((PeonyDesktopApplication*)qApp)->getIconView(0);
+}
