@@ -35,6 +35,7 @@
 #include <QDebug>
 #include "vfs-plugin-iface.h"
 #include "vfs-plugin-manager.h"
+#include "emblem-plugin-iface.h"
 
 using namespace Peony;
 
@@ -98,6 +99,12 @@ void DesktopMenuPluginManager::loadAsync()
                 continue;
             }
 
+            auto emblemsPlugin = dynamic_cast<EmblemPluginInterface *>(plugin);
+            if (emblemsPlugin){
+                EmblemProviderManager::getInstance()->registerProvider(emblemsPlugin->create());
+                continue;
+            }
+
             MenuPluginInterface *piface = dynamic_cast<MenuPluginInterface*>(plugin);
             if (!piface)
                 continue;
