@@ -24,6 +24,7 @@
 #define DESKTOPMENU_H
 
 #include <QMenu>
+#include "desktop-icon-view.h"
 
 namespace Peony {
 
@@ -38,6 +39,13 @@ public:
         return m_uris_to_edit;
     }
 
+    void showProperties(const QString &uri);
+    void showProperties(const QStringList &uris);
+
+Q_SIGNALS:
+    void setDefaultZoomLevel(Peony::DesktopIconView::ZoomLevel level);
+    void setSortType(int sortType);
+
 protected:
     void fillActions();
     const QList<QAction *> constructOpenOpActions();
@@ -49,8 +57,6 @@ protected:
 
     void openWindow(const QString &uri);
     void openWindow(const QStringList &uris);
-    void showProperties(const QString &uri);
-    void showProperties(const QStringList &uris);
     void gotoAboutComputer();
 
 private:
