@@ -30,12 +30,15 @@
 
 #include "desktop-icon-view.h"
 
+#include "global-settings.h"
 #include "plasma-shell-manager.h"
 #include "desktop-menu.h"
-
+#include "global-settings.h"
+#include "file-enumerator.h"
 #include "desktopbackground.h"
 #include "desktop-background-manager.h"
 #include "desktopbackgroundwindow.h"
+#include "desktop-item-model.h"
 
 #include <QCommandLineParser>
 #include <QCommandLineOption>
@@ -63,7 +66,10 @@
 #include <QScreen>
 #include <QTimeLine>
 
+#include <QSessionManager>
 #include <KWindowSystem>
+#include <QX11Info>
+#include <X11/Xlib.h>
 
 #define KYLIN_USER_GUIDE_PATH "/"
 #define KYLIN_USER_GUIDE_SERVICE QString("com.kylinUserGuide.hotel_%1").arg(getuid())
@@ -75,7 +81,9 @@ static bool has_desktop = false;
 static bool has_daemon = false;
 static bool has_background = false;
 static QRect max_size = QRect(0, 0, 0, 0);
-static Peony::DesktopIconView *desktop_icon_view = nullptr;
+static Peony::DesktopItemModel *desktop_model = nullptr;
+static int desktop_window_id = 0;
+
 /*!
  * \brief virtualDesktopWindow
  * \deprecated
@@ -88,6 +96,14 @@ qint64 PeonyDesktopApplication::peony_desktop_start_time = 0;
 void guessContentTypeCallback(GObject* object,GAsyncResult *res,gpointer data);
 static void volume_mount_cb (GObject* source, GAsyncResult* res, gpointer udata);
 
+static void mount_added_cb (GVolumeMonitor *volume_monitor,
+                            GMount         *mount,
+                            gpointer        user_data);
+
+static void mount_changed_cb (GVolumeMonitor *volume_monitor,
+                              GMount         *mount,
+                              gpointer        user_data);
+
 void trySetDefaultFolderUrlHandler() {
     //NOTE:
     //There is a bug in qt concurrent. If we use QtConcurrent::run()
@@ -168,6 +184,39 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
     setApplicationName(tr("peony-qt-desktop"));
     setWindowIcon(QIcon::fromTheme("system-file-manager"));
 
+    //added for session call interactive
+    QGuiApplication::setFallbackSessionManagementEnabled(true);
+    QGuiApplication::setQuitOnLastWindowClosed(false);
+    // fix #145378, logout background displayment issue.
+    QObject::connect(this, &QGuiApplication::saveStateRequest, this, [=](QSessionManager &manager){
+        if (KWindowSystem::isPlatformX11()) {
+            if (manager.allowsErrorInteraction()) {
+                qInfo()<<"session about to logout, clear the root window background";
+//                XSetWindowBackground(QX11Info::display(), QX11Info::appRootWindow(), 0);
+//                XSync(QX11Info::display(), false);
+                manager.release();
+            } else {
+                qInfo()<<"session not support interaction or not x11 platform";
+//                XSetWindowBackground(QX11Info::display(), QX11Info::appRootWindow(), 0);
+//                XSync(QX11Info::display(), false);
+            }
+        }
+    });
+
+    // global settings
+    if (QGSettings::isSchemaInstalled (FONT_SETTINGS)) {
+        //font monitor
+        QGSettings *fontSetting = new QGSettings (FONT_SETTINGS, QByteArray(), this);
+        connect (fontSetting, &QGSettings::changed, this, [=] (const QString &key) {
+            if (key == "systemFont" || key == "systemFontSize") {
+                QFont font = this->font();
+                for(auto widget : qApp->allWidgets()) {
+                    widget->setFont(font);
+                }
+            }
+        });
+    }
+
     if (!this->isRunning()) {
         qDebug()<<"isPrimary screen";
         connect(this, &QtSingleApplication::messageReceived, [=](QString msg) {
@@ -201,36 +250,19 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
         connect(trayIcon, &QSystemTrayIcon::messageClicked, trayIcon, &QSystemTrayIcon::hide);
         */
 
-        // auto mount local driver
-        qDebug()<<"auto mount local volumes";
-        GVolumeMonitor* vm = g_volume_monitor_get ();
-        if (vm) {
-            GList* drives = g_volume_monitor_get_connected_drives(vm);
-            if (drives) {
-                for (GList* i = drives; nullptr != i; i = i->next) {
-                    GDrive * d = static_cast<GDrive*>(i->data);
-                    if (G_IS_DRIVE(d)) {
-                        GList* volumes = g_drive_get_volumes(d);
-                        if (volumes) {
-                            for (GList* j = volumes; nullptr != j; j = j->next) {
-                                GVolume* v = static_cast<GVolume*>(j->data);
-                                if (G_IS_VOLUME(v)) {
-                                    g_autofree char* uuid = g_volume_get_uuid(v);
-                                    if (0 != g_strcmp0("2691-6AB8", uuid)) {
-                                        g_volume_mount(v, G_MOUNT_MOUNT_NONE, nullptr, nullptr, volume_mount_cb, nullptr);
-                                    }
-                                    g_object_unref(v);
-                                }
-                            }
-                            g_list_free(volumes);
-                        }
-                        g_object_unref(d);
-                    }
-                }
-                g_list_free(drives);
-            }
-        }
-        g_object_unref(vm);
+        g_signal_connect (g_volume_monitor_get(), "mount-added", G_CALLBACK(mount_added_cb), nullptr);
+        g_signal_connect (g_volume_monitor_get(), "mount-changed", G_CALLBACK(mount_added_cb), nullptr);
+
+        // enumerat network:///
+        QThread* t = QThread::create ([=] () {
+            FileEnumerator e;
+            e.setEnumerateDirectory ("network:///");
+            e.enumerateSync();
+            e.getChildrenUris ();
+        });
+        connect (t, &QThread::finished, t, &QObject::deleteLater);
+        t->start ();
+
     }
 
     connect(this, &SingleApplication::layoutDirectionChanged, this, &PeonyDesktopApplication::layoutDirectionChangedProcess);
@@ -260,11 +292,61 @@ PeonyDesktopApplication::PeonyDesktopApplication(int &argc, char *argv[], const
     qDebug()<<"peony desktop application constructor end";
 }
 
-Peony::DesktopIconView *PeonyDesktopApplication::getIconView()
+Peony::DesktopItemModel *PeonyDesktopApplication::getModel()
 {
-    if (!desktop_icon_view)
-        desktop_icon_view = new Peony::DesktopIconView(/*virtualDesktopWindow*/);
-    return desktop_icon_view;
+    if (!desktop_model)
+        desktop_model =  new DesktopItemModel();
+    return desktop_model;
+}
+
+Peony::DesktopIconView *PeonyDesktopApplication::getIconView(QPoint pos)
+{
+    //获取当前屏幕的view,如果是镜像直接返回主屏
+    Peony::DesktopIconView *desktopIconView = getIconView(qApp->primaryScreen());
+    QRegion screenRegion(qApp->primaryScreen()->geometry());
+    if (screenRegion.contains(pos)) {
+        return desktopIconView;
+    };
+
+    for (auto window : m_bg_windows) {
+        QRegion screenRegion(window->screen()->geometry());
+        if (screenRegion.contains(pos)) {
+            desktopIconView = window->getIconView();
+            break;
+        };
+    }
+    return desktopIconView;
+}
+
+Peony::DesktopIconView *PeonyDesktopApplication::getIconView(int id)
+{
+    for (auto window : m_bg_windows) {
+        if (id == window->id()) {
+            return window->getIconView();
+        }
+    }
+    return m_bg_windows[0]->getIconView();
+}
+
+Peony::DesktopIconView *PeonyDesktopApplication::getIconView(QScreen *screen)
+{
+    for (auto window : m_bg_windows) {
+        if (screen == window->screen()) {
+            return window->getIconView();
+        }
+    }
+    return m_bg_windows[0]->getIconView();
+}
+
+Peony::DesktopIconView *PeonyDesktopApplication::removeUri(const QString& uri)
+{
+    for (auto window : m_bg_windows) {
+        auto view = window->getIconView();
+        if (view->removeItemRect(uri) == 1) {
+            return view;
+        }
+    }
+    return m_bg_windows[0]->getIconView();
 }
 
 bool PeonyDesktopApplication::userGuideDaemonRunning()
@@ -310,25 +392,74 @@ void PeonyDesktopApplication::gotoSetBackground()
 {
     QProcess p;
     p.setProgram("ukui-control-center");
-    //old version use -a, new version use -b as para
-    p.setArguments(QStringList()<<"-b");
+    //old version use -b, new version use -m Wallpaper as para
+    p.setArguments(QStringList()<<"-m" <<"Wallpaper");
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
     p.startDetached();
 #else
-    p.startDetached("ukui-control-center", QStringList()<<"-b");
+    p.startDetached("ukui-control-center", QStringList()<<"-m" <<"Wallpaper");
 #endif
     p.waitForFinished(-1);
 }
 
+void PeonyDesktopApplication::gotoSetResolution()
+{
+    QProcess p;
+    p.setProgram("ukui-control-center");
+    p.setArguments(QStringList()<<"-m" <<"display");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+    p.startDetached();
+#else
+    p.startDetached("ukui-control-center", QStringList()<<"-m" <<"display");
+#endif
+    p.waitForFinished(-1);
+
+}
+
 void PeonyDesktopApplication::relocateIconView()
 {
+    qInfo()<<"start relocate icon view";
+    //task#74174 更新多屏显示,根据id过滤元素
+    int id = -1;
+    DesktopBackgroundWindow *primaryWindow = nullptr;
     for (auto window : m_bg_windows) {
         if (window->screen() == qApp->primaryScreen()) {
-            window->setCentralWidget(PeonyDesktopApplication::getIconView());
-            KWindowSystem::raiseWindow(window->winId());
+            id = window->id();
+            primaryWindow = window;
             break;
         }
     }
+    qDebug()<<"primary screen id:"<<id;
+    if (0 < id) {
+        for (auto window : m_bg_windows) {
+            if (0 == window->id()) {
+                primaryWindow->getIconView()->refreshResolutionChange();
+                window->getIconView()->refreshResolutionChange();
+                window->setId(id);
+                primaryWindow->setId(0);
+                window->getIconView()->clearItemRect();
+                primaryWindow->getIconView()->clearItemRect();
+                Q_EMIT window->getIconView()->updateView();
+                Q_EMIT primaryWindow->getIconView()->updateView();
+                window->getIconView()->resolutionChange();
+                primaryWindow->getIconView()->resolutionChange();
+                KWindowSystem::raiseWindow(primaryWindow->winId());
+                return;
+            }
+        }
+    }
+
+    for (auto window : m_bg_windows) {
+        qDebug() << "screen name :" << window->screen()->name() << " id:" << window->id() ;
+        Q_EMIT window->getIconView()->updateView();
+        window->setCentralWidget(window->getIconView());
+        if (window->screen() != qApp->primaryScreen()) {
+            KWindowSystem::raiseWindow(window->winId());
+        }
+    }
+    if(primaryWindow) {
+        KWindowSystem::raiseWindow(primaryWindow->winId());
+    }
 }
 
 void PeonyDesktopApplication::parseCmd(QString msg, bool isPrimary)
@@ -347,6 +478,9 @@ void PeonyDesktopApplication::parseCmd(QString msg, bool isPrimary)
     QCommandLineOption backgroundOption(QStringList()<<"b"<<"background", tr("Setup backgrounds"));
 //    parser.addOption(backgroundOption);
 
+    QCommandLineOption clearIconsOption(QStringList()<<"c"<<"clear-icons", tr("Clear standard icons"));
+    parser.addOption(clearIconsOption);
+
     if (isPrimary) {
         if (m_first_parse) {
             auto helpOption = parser.addHelpOption();
@@ -408,6 +542,12 @@ void PeonyDesktopApplication::parseCmd(QString msg, bool isPrimary)
         }
 
         if (parser.isSet(desktopOption)) {
+            if(!has_background) {
+                QDBusServiceWatcher *watcher = new QDBusServiceWatcher(this);
+                watcher->setConnection(QDBusConnection::sessionBus());
+                watcher->addWatchedService("org.ukui.KWin");
+                connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &PeonyDesktopApplication::raiseWid);
+            }
             setupBgAndDesktop();
         }
 
@@ -415,6 +555,12 @@ void PeonyDesktopApplication::parseCmd(QString msg, bool isPrimary)
             setupBgAndDesktop();
         }
 
+        if (parser.isSet(clearIconsOption)) {
+            if (has_desktop) {
+                clearIcons(args);
+            }
+        }
+
         connect(this, &QApplication::paletteChanged, this, [=](const QPalette &pal) {
             for (auto w : allWidgets()) {
                 w->setPalette(pal);
@@ -435,6 +581,41 @@ void PeonyDesktopApplication::parseCmd(QString msg, bool isPrimary)
     }
 }
 
+void PeonyDesktopApplication::clearIcons(const QStringList &args)
+{
+    //定制需求
+    int index = -1;
+    if (args.contains("-c")) {
+        index = args.indexOf("-c");
+
+    } else if (args.contains("--clear-icons")) {
+        index = args.indexOf("--clear-icons");
+    }
+
+    index++;
+    if ((index <= 0) || (index >= args.count())) {
+        return;
+    }
+
+    const QString &operationStr = args.value(index);
+    bool isSuccess = false;
+    int operationNum = operationStr.toInt(&isSuccess);
+    for (auto window : m_bg_windows) {
+        if (!window->getIconView()) {
+            return;
+        }
+    }
+    if (isSuccess) {
+        switch (operationNum) {
+            case 1:
+                GlobalSettings::getInstance()->setValue(DISPLAY_STANDARD_ICONS, false);
+                break;
+            default:
+                GlobalSettings::getInstance()->setValue(DISPLAY_STANDARD_ICONS, true);
+        }
+    }
+}
+
 void PeonyDesktopApplication::addWindow(QScreen *screen, bool checkPrimay)
 {
 
@@ -485,28 +666,70 @@ void PeonyDesktopApplication::updateVirtualDesktopGeometryByWindows()
 
 void PeonyDesktopApplication::addBgWindow(QScreen *screen)
 {
-    auto window = new DesktopBackgroundWindow(screen);
-    m_bg_windows.append(window);
+    int desktopWindowId = getDesktopWindowId();
+    auto window = new DesktopBackgroundWindow(screen, desktopWindowId );
 
+    if (screen == qApp->primaryScreen()) {
+        window->getIconView()->refresh();
+    }
+
+    m_bg_windows.append(window);
+    desktop_window_id = m_bg_windows.count();
     // recheck primary screen info. new screen might become
     // primary screen.
-
+    qDebug()<<"[PeonyDesktopApplication::addBgWindow] screen name:"<<window->screen()->name()<<"  IP:"<<window->screen();
     window->show();
     connect(screen, &QScreen::destroyed, this, [=](){
-        if (getIconView()->parent() == window) {
-            getIconView()->setParent(nullptr);
+        if (m_mode == 2) {
+            if (m_bg_windows.count() > 2) {
+                //task#74174 销毁时保存扩展屏元素的坐标点
+                getIconView(screen)->saveExtendItemInfo();
+                getIconView(qApp->primaryScreen())->updateView();
+            } else if (m_bg_windows.count() == 2) {
+                singleScreenMode();
+                m_mode = 0;
+            }
         }
+        qDebug()<<"QScreen::destroyed screen name:"<<screen->name();
+        Q_EMIT window->destroyed();
         m_bg_windows.removeOne(window);
         window->deleteLater();
     });
-
-    // raise primary window to make sure icon view is visible.
-    for (auto window : m_bg_windows) {
-        if (window->screen() == QApplication::primaryScreen()) {
-            KWindowSystem::raiseWindow(window->winId());
-            break;
+    //task#74174 更新图标大小
+    connect(window, &DesktopBackgroundWindow::setDefaultZoomLevel, this, [=](DesktopIconView::ZoomLevel level){
+        for (auto bgWindow : m_bg_windows) {
+            if (bgWindow->getIconView()->zoomLevel() != level) {
+                bgWindow->getIconView()->setDefaultZoomLevel(level);
+                bgWindow->getIconView()->clearExtendItemPos(true);
+            }
         }
+    });
+    //task#74174 更新排序方式
+    connect(window, &DesktopBackgroundWindow::setSortType, this, [=](int sortType){
+        for (auto bgWindow : m_bg_windows) {
+            bgWindow->getIconView()->setSortType(sortType);
+        }
+    });
+    //task#74174 更新扩展屏与镜像切换
+    connect(window, &DesktopBackgroundWindow::updateWindow, this, [=](const QRect &geometry){
+        int mode = checkScreenMode(geometry);
+        if (m_mode != mode) {
+            if (1 == mode) {
+                singleScreenMode();
+             } else if (2 == mode) {
+                multiscreenMode();
+            }
+        }
+        m_mode = mode;
+        window->setWindowGeometry(geometry);
+    });
+    //task#74174 恢复扩展屏
+    m_mode = checkScreenMode(screen->geometry());
+    if (2 == m_mode) {
+        multiscreenMode();
     }
+
+    relocateIconView();
 }
 
 void PeonyDesktopApplication::setupDesktop()
@@ -515,7 +738,7 @@ void PeonyDesktopApplication::setupDesktop()
     for (auto screen : qApp->screens()) {
         addBgWindow(screen);
     }
-    relocateIconView();
+
     connect(qApp, &QApplication::screenAdded, this, &PeonyDesktopApplication::addBgWindow);
     connect(this, &PeonyDesktopApplication::primaryScreenChanged, this, &PeonyDesktopApplication::relocateIconView);
 }
@@ -528,6 +751,54 @@ void PeonyDesktopApplication::setupBgAndDesktop()
     has_background = true;
 }
 
+int PeonyDesktopApplication::getDesktopWindowId()
+{
+    int desktopWindowId = 0;
+    for (; desktopWindowId <= desktop_window_id; desktopWindowId++) {
+        bool find = false;
+        for (auto bgWindow : m_bg_windows) {
+            if (bgWindow->id() == desktopWindowId) {
+                find = true;
+                break;
+            }
+        }
+        if (!find) {
+            break;
+        }
+    }
+    return desktopWindowId;
+}
+
+void PeonyDesktopApplication::singleScreenMode()
+{
+    auto primayView = getIconView(0);
+    qDebug() << "primay view item" << primayView->model()->rowCount() << "total item:" << getModel()->rowCount();
+    if ( 2 == m_mode  && primayView->model()->rowCount() == getModel()->rowCount()) {
+        primayView->clearExtendItemPos();
+        return;
+    }
+    for (auto bgWindow : m_bg_windows) {
+        auto view = bgWindow->getIconView();
+        view->clearItemRect();
+        view->saveExtendItemInfo();
+    }
+
+    primayView->updateView();
+}
+
+void PeonyDesktopApplication::multiscreenMode()
+{
+    for (auto bgWindow : m_bg_windows) {
+        auto view = bgWindow->getIconView();
+        view->clearItemRect();
+        view->resetExtendItemInfo();
+    }
+    for (auto bgWindow : m_bg_windows) {
+        auto view = bgWindow->getIconView();
+        view->updateView();
+    }
+}
+
 void guessContentTypeCallback(GObject* object, GAsyncResult *res,gpointer data)
 {
     char **guessType;
@@ -561,6 +832,8 @@ void guessContentTypeCallback(GObject* object, GAsyncResult *res,gpointer data)
         if(guessType && g_strv_length(guessType) > 0){
             int n;
             for(n = 0; guessType[n]; ++n){
+                if(g_content_type_is_a(guessType[n],"x-content/image-dcf"))
+                    openFolder = false;
                 if(g_content_type_is_a(guessType[n],"x-content/win32-software"))
                     openFolder = false;
                 if(unixDevice && !strcmp(guessType[n],"x-content/bootable-media") && !strstr(unixDevice,"/dev/sr"))
@@ -633,6 +906,45 @@ void PeonyDesktopApplication::volumeRemovedProcess(const std::shared_ptr<Peony::
    //     g_drive_stop(gdrive,G_MOUNT_UNMOUNT_NONE,NULL,NULL,NULL,NULL);
 };
 
+int PeonyDesktopApplication::checkScreenMode(const QRect &geometry)
+{
+    int mode = 1;
+    if (m_bg_windows.count() == 1) {
+        mode = 0;
+        return mode;
+    }
+
+    for (auto window : m_bg_windows) {
+        if (window->screen()->geometry() != geometry) {
+            mode = 2;
+            break;
+        }
+    }
+    return mode;
+}
+
+Peony::DesktopIconView *PeonyDesktopApplication::getNotFullView()
+{
+    for (auto window : m_bg_windows) {
+        Peony::DesktopIconView *view = window->getIconView();
+        if (view && !view->isFull()) {
+            return view;
+        }
+    }
+    return nullptr;
+}
+
+void PeonyDesktopApplication::raiseWid()
+{
+    QTimer::singleShot(2000, this, [=]() {
+        for (auto window : m_bg_windows) {
+            if (window->screen() == this->primaryScreen() && window->screen()) {
+                KWindowSystem::raiseWindow(window->winId());
+                return;
+            }
+        }
+    });
+}
 
 static void volume_mount_cb (GObject* source, GAsyncResult* res, gpointer udata)
 {
@@ -640,3 +952,23 @@ static void volume_mount_cb (GObject* source, GAsyncResult* res, gpointer udata)
 
     Q_UNUSED(udata);
 }
+
+void mount_added_cb (GVolumeMonitor *volume_monitor,
+                     GMount         *mount,
+                     gpointer        user_data)
+{
+    Q_UNUSED (volume_monitor)
+    Q_UNUSED (user_data)
+    g_autoptr (GFile) file = g_mount_get_root(mount);
+    g_file_query_info_async(file, "*", G_FILE_QUERY_INFO_NONE, 0, 0, 0, 0);
+}
+
+void mount_changed_cb (GVolumeMonitor *volume_monitor,
+                       GMount         *mount,
+                       gpointer        user_data)
+{
+    Q_UNUSED (volume_monitor)
+    Q_UNUSED (user_data)
+    g_autoptr (GFile) file = g_mount_get_root(mount);
+    g_file_query_info_async(file, "*", G_FILE_QUERY_INFO_NONE, 0, 0, 0, 0);
+}
