@@ -35,6 +35,7 @@ class DesktopBackgroundWindow;
 
 namespace Peony {
 class DesktopIconView;
+class DesktopItemModel;
 }
 
 using namespace Peony;
@@ -47,12 +48,24 @@ class PeonyDesktopApplication : public QtSingleApplication
 public:
     explicit PeonyDesktopApplication(int &argc, char *argv[], const QString &applicationName = "peony-qt-desktop");
 
-    static Peony::DesktopIconView *getIconView();
     static bool userGuideDaemonRunning();
     static void showGuide(const QString &appName = "");
     static void gotoSetBackground();
+    static void gotoSetResolution();
 
     static qint64 peony_desktop_start_time;
+    static Peony::DesktopItemModel* getModel();
+    Peony::DesktopIconView *getIconView(QPoint pos);
+    Peony::DesktopIconView *getIconView(int id);
+    Peony::DesktopIconView *getIconView(QScreen *screen);
+    Peony::DesktopIconView * removeUri(const QString& uri);
+    int checkScreenMode(const QRect &geometry);
+    Peony::DesktopIconView *getNotFullView();
+    void singleScreenMode();
+    void multiscreenMode();
+
+    // only used in model refresh.
+//    void clearViewCache();
 
 Q_SIGNALS:
     void requestSetUKUIOutputEnable(bool enable);
@@ -75,16 +88,20 @@ public Q_SLOTS:
 
     void addBgWindow(QScreen *screen);
     void relocateIconView();
+    void raiseWid();
 
 private:
     void setupDesktop();
     void setupBgAndDesktop();
+    void clearIcons(const QStringList &args);
+    int getDesktopWindowId();
 
     bool m_first_parse = true;
 
     QList<DesktopBackgroundWindow *> m_bg_windows;
 
     QTimeLine *m_primaryScreenSettingsTimeLine = nullptr;
+    int m_mode = 0;
 };
 
 #endif // PEONYDESKTOPAPPLICATION_H
