@@ -30,29 +30,40 @@
 #include <QColorDialog>
 #include <QMouseEvent>
 
+#include <QPainter>
+#include <QPainterPath>
+#include <QPixmap>
+#include <QMap>
+
+#include <QStyleOptionViewItem>
+
 #include <QApplication>
 #include <QDebug>
 
 static LabelBoxStyle *global_instance = nullptr;
 
+static QMap<QString, QIcon> color_icons;
+
 FileLabelBox::FileLabelBox(QWidget *parent) : QListView(parent)
 {
-    //setItemDelegate(new LabelBoxDelegate(this));
+    setItemDelegate(new LabelBoxDelegate(this));
     setStyle(LabelBoxStyle::getStyle());
     viewport()->setStyle(LabelBoxStyle::getStyle());
+    viewport()->setAutoFillBackground(true);
+    viewport()->setBackgroundRole(QPalette::AlternateBase);
     setModel(FileLabelModel::getGlobalModel());
 
     setContextMenuPolicy(Qt::CustomContextMenu);
 
     connect(this, &QWidget::customContextMenuRequested, this, [=](const QPoint &pos) {
         auto index = indexAt(pos);
-        bool labelRemovable = false;
-        QMenu menu;
+        //bool labelRemovable = false;
+        QMenu menu(this);
         if (index.isValid()) {
             auto item = FileLabelModel::getGlobalModel()->itemFormIndex(index);
             int id = item->id();
-            if (id > TOTAL_DEFAULT_COLOR)
-                labelRemovable = true;
+//            if (id > TOTAL_DEFAULT_COLOR)
+//                labelRemovable = true;
 
             menu.addAction(tr("Rename"), [=]() {
                 //FIXME: edit
@@ -61,19 +72,25 @@ FileLabelBox::FileLabelBox(QWidget *parent) : QListView(parent)
 
             menu.addAction(tr("Edit Color"), [=]() {
                 QColorDialog d;
+                d.setStyleSheet("QSpinBox{"
+                                "min-width: 2em;"
+                                "}");
                 if (d.exec()) {
                     auto color = d.selectedColor();
-                    item->setColor(color);
+                    FileLabelModel::getGlobalModel()->setLabelColor(item->id(), color);
                 }
             });
 
             auto a = menu.addAction(tr("Delete"), [=]() {
                 FileLabelModel::getGlobalModel()->removeLabel(id);
             });
-            a->setEnabled(labelRemovable);
+            //a->setEnabled(labelRemovable);
         } else {
             menu.addAction(tr("Create New Label"), [=]() {
                 QColorDialog dialog;
+                dialog.setStyleSheet("QSpinBox{"
+                                "min-width: 2em;"
+                                "}");
                 if (dialog.exec()) {
                     auto color = dialog.selectedColor();
                     auto name = color.name();
@@ -81,7 +98,7 @@ FileLabelBox::FileLabelBox(QWidget *parent) : QListView(parent)
                 }
             });
         }
-        menu.exec(QCursor::pos());
+        menu.exec(mapToGlobal(pos));
     });
 }
 
@@ -123,5 +140,45 @@ LabelBoxStyle *LabelBoxStyle::getStyle()
 
 void LabelBoxStyle::drawPrimitive(QStyle::PrimitiveElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
 {
+    if (element == QStyle::PE_Frame)
+        return;
+
     return QApplication::style()->drawPrimitive(element, option, painter, widget);
 }
+
+void LabelBoxStyle::drawControl(QStyle::ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
+{
+    if (element == CE_ItemViewItem) {
+        if (auto tmp = qstyleoption_cast<const QStyleOptionViewItem*>(option)) {
+            QStyleOptionViewItem opt = *tmp;
+            auto color = qvariant_cast<QColor>(opt.index.data(Qt::DecorationRole));
+            auto icon = color_icons.value(color.name());
+            if (icon.isNull()) {
+                QPixmap pic(QSize(12, 12));
+                pic.fill(Qt::transparent);
+                QPainter p(&pic);
+                p.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
+                p.setPen(QPen(Qt::gray, 0.5, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
+                p.setBrush(color);
+                p.drawEllipse(QRect(0, 0, 12, 12));
+                p.end();
+                icon.addPixmap(pic);
+                color_icons.insert(color.name(), icon);
+            }
+            opt.icon = icon;
+            return QApplication::style()->drawControl(element, &opt, painter, widget);
+        }
+
+    }
+    return QApplication::style()->drawControl(element, option, painter, widget);
+}
+
+QSize LabelBoxStyle::sizeFromContents(QStyle::ContentsType type, const QStyleOption *option, const QSize &size, const QWidget *widget) const
+{
+    if (type == CT_ItemViewItem) {
+        QSize size = QApplication::style()->sizeFromContents(type, option, size, widget);
+        size += QSize(0, 8);
+        return size;
+    }
+    return QApplication::style()->sizeFromContents(type, option, size, widget);
+}
