@@ -40,6 +40,8 @@
 
 #include "file-utils.h"
 
+#include "x11-window-manager.h"
+
 #include <QHeaderView>
 #include <QPushButton>
 
@@ -61,11 +63,15 @@
 #include <QMessageBox>
 
 #include <QPainterPath>
+#include <QLabel>
 
 #include <QDebug>
 #include <QToolTip>
 
+#include <QApplication>
+
 #define NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS 4
+#define MINIMUM_COLUMN_SIZE 2
 
 using namespace Peony;
 
@@ -73,6 +79,8 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 {
     static NavigationSideBarStyle *global_style = new NavigationSideBarStyle;
 
+    header()->setMinimumSectionSize(30);
+
     setSortingEnabled(true);
 
     setIconSize(QSize(16, 16));
@@ -98,12 +106,13 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
                   "border: 0px solid transparent"
                   "}");
 
-    setStyle(global_style);
+    //setStyle(global_style);
 
     setAttribute(Qt::WA_TranslucentBackground);
     viewport()->setAttribute(Qt::WA_TranslucentBackground);
-    header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-    header()->setStretchLastSection(false);
+    header()->setSectionResizeMode(QHeaderView::Fixed);
+    header()->setStretchLastSection(true);
+    header()->setMinimumSectionSize(MINIMUM_COLUMN_SIZE);
     header()->hide();
 
     setContextMenuPolicy(Qt::CustomContextMenu);
@@ -119,6 +128,7 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
     this->setModel(m_proxy_model);
 
     setMouseTracking(true);//追踪鼠标
+    setAutoScrollMargin(0);
 
     VolumeManager *volumeManager = VolumeManager::getInstance();
     connect(volumeManager,&Peony::VolumeManager::volumeAdded,this,[=](const std::shared_ptr<Peony::Volume> &volume){
@@ -145,6 +155,12 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         /*!
           \bug can not expanded? enumerator can not get prepared signal, why?
           */
+        bool isShowNetwork = Peony::GlobalSettings::getInstance()->isExist(SHOW_NETWORK) ?
+                    Peony::GlobalSettings::getInstance()->getValue(SHOW_NETWORK).toBool() : true;
+        if (item->type() == SideBarAbstractItem::NetWorkItem && !isShowNetwork) {
+            this->setRowHidden(index.row(), index.parent(), true);
+            return;
+        }
         item->findChildrenAsync();
     });
 
@@ -154,6 +170,9 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
     });
 
     connect(Experimental_Peony::VolumeManager::getInstance(), &Experimental_Peony::VolumeManager::signal_mountFinished,this,[=](){
+        //fix open mutiple peony window, mount in side bar crash issue, link to bug#116201,116589
+        if(!m_currSelectedItem)
+            return;
         JumpDirectory(m_currSelectedItem->uri());
         qDebug()<<"挂载后跳转路径："<<m_currSelectedItem->uri();
     });
@@ -162,6 +181,13 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         switch (index.column()) {
         case 0: {
             m_currSelectedItem = m_proxy_model->itemFromIndex(index);
+            //fix open mutiple peony window, mount in side bar crash issue, link to bug#116201,116589
+            if (! m_currSelectedItem)
+                break;
+            //continue to fix crash issue, related to bug#116201,116589
+            m_currSelectedItem->connect(m_currSelectedItem, &SideBarAbstractItem::destroyed, this, [=]{
+                m_currSelectedItem = nullptr;
+            });
             if(m_currSelectedItem->isMountable()&&!m_currSelectedItem->isMounted())
                 m_currSelectedItem->mount();
             else{
@@ -173,6 +199,10 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         case 1: {
             auto item = m_proxy_model->itemFromIndex(index);
             if (item->isMounted() || item->isEjectable()||item->isStopable()) {
+                if(item->getDevice().contains("/dev/sr") && FileUtils::isBusyDevice(item->getDevice())){/* 光盘在刻录数据、镜像等操作时,若处于busy状态时，不可弹出。link to bug#143293 */
+                    QMessageBox::information(this, tr("Tips"), tr("The device is in busy state, please perform this operation later."));
+                    break;
+                }
                 auto leftIndex = m_proxy_model->index(index.row(), 0, index.parent());
                 this->collapse(leftIndex);
                 item->ejectOrUnmount();
@@ -194,7 +224,7 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
         auto item = m_proxy_model->itemFromIndex(index);
         if (item) {
             if (item->type() != Peony::SideBarAbstractItem::SeparatorItem) {
-                Peony::SideBarMenu menu(item, nullptr);
+                Peony::SideBarMenu menu(item, nullptr, this);
                 QList<QAction *> actionList;
                 MainWindow *window = dynamic_cast<MainWindow *>(this->topLevelWidget());
 
@@ -231,61 +261,100 @@ NavigationSideBar::NavigationSideBar(QWidget *parent) : QTreeView(parent)
 
                     enumerator->prepare();
                 });
+                if (!qApp->property("tabletMode").toBool()) {
+                    actionList << menu.addAction(QIcon::fromTheme("tab-new-symbolic"), tr("Open In New Tab"), [=](){
+                        auto enumerator = new Peony::FileEnumerator;
+                        enumerator->setEnumerateDirectory(item->uri());
+                        enumerator->setAutoDelete();
 
-                actionList << menu.addAction(QIcon::fromTheme("tab-new-symbolic"), tr("Open In New Tab"), [=](){
-                    auto enumerator = new Peony::FileEnumerator;
-                    enumerator->setEnumerateDirectory(item->uri());
-                    enumerator->setAutoDelete();
+                        enumerator->connect(enumerator, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
+                            auto targetUri = Peony::FileUtils::getTargetUri(item->uri());
+                            if (!targetUri.isEmpty()) {
+                                auto enumerator2 = new Peony::FileEnumerator;
+                                enumerator2->setEnumerateDirectory(targetUri);
+                                enumerator2->connect(enumerator2, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
+                                    if (!critical) {
+                                        window->addNewTabs(QStringList()<<targetUri);
+                                        dynamic_cast<QWidget *>(window)->show();
+                                    } else {
+                                        auto info = FileInfo::fromUri(targetUri);
+                                        QMessageBox::critical(0, 0, tr("Can not open %1, %2").arg(info.get()->displayName()).arg(err.get()->message()));
+                                    }
+                                    enumerator2->deleteLater();
+                                });
+                                enumerator2->prepare();
+                            } else if (!err.get() && !critical) {
+                                window->addNewTabs(QStringList()<<item->uri());
+                                dynamic_cast<QWidget *>(window)->show();
+                            }
+                        });
 
-                    enumerator->connect(enumerator, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
-                        auto targetUri = Peony::FileUtils::getTargetUri(item->uri());
-                        if (!targetUri.isEmpty()) {
-                            auto enumerator2 = new Peony::FileEnumerator;
-                            enumerator2->setEnumerateDirectory(targetUri);
-                            enumerator2->connect(enumerator2, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
-                                if (!critical) {
-                                    window->addNewTabs(QStringList()<<targetUri);
-                                    dynamic_cast<QWidget *>(window)->show();
-                                } else {
-                                    auto info = FileInfo::fromUri(targetUri);
-                                    QMessageBox::critical(0, 0, tr("Can not open %1, %2").arg(info.get()->displayName()).arg(err.get()->message()));
-                                }
-                                enumerator2->deleteLater();
-                            });
-                            enumerator2->prepare();
-                        } else if (!err.get() && !critical) {
-                            window->addNewTabs(QStringList()<<item->uri());
-                            dynamic_cast<QWidget *>(window)->show();
-                        }
+                        enumerator->connect(enumerator, &Peony::FileEnumerator::prepared, [=](){
+                            enumerator->deleteLater();
+                        });
+
+                        enumerator->prepare();
                     });
-
-                    enumerator->connect(enumerator, &Peony::FileEnumerator::prepared, [=](){
-                        enumerator->deleteLater();
-                    });
-
-                    enumerator->prepare();
-                });
+                }
 
                 if (item->type() == SideBarAbstractItem::FileSystemItem) {
                     if ((0 != QString::compare(item->uri(), "computer:///")) &&
                         (0 != QString::compare(item->uri(), "filesafe:///"))) {
                         for (const auto &actionItem : actionList) {
-                            if(item->isMountable()||item->isUnmountable())/* 分区才去需要判断是否已挂载 */
+                            if(item->isVolume()){/* 分区才去需要判断是否已挂载 */
                                 actionItem->setEnabled(item->isMounted());
+                                if(item->getDevice().contains("/dev/sr")){/* 光盘在刻录数据、镜像等操作时,即若处于busy状态时，该菜单置灰不可用。 */
+                                    actionItem->setDisabled(FileUtils::isBusyDevice(item->getDevice()));
+                                }
+                            }
                         }
                     }
                 }
 
-                menu.exec(QCursor::pos());
+                menu.exec(mapToGlobal(pos));
             }
         }
     });
 
     connect(m_model, &QAbstractItemModel::dataChanged, this, [=](){
         this->viewport()->update();
+        m_proxy_model->invalidate();
     });
 
-    expandToDepth(1);/* 快速访问、计算机、网络 各模块往下展开一层 */
+    connect(Peony::GlobalSettings::getInstance(), &GlobalSettings::valueChanged, this, [=](const QString& key){
+        if (SHOW_NETWORK == key) {
+            for (int i = 0; i < m_proxy_model->rowCount(); ++i) {
+                auto index = m_proxy_model->index(i, 0);
+                auto item = m_proxy_model->itemFromIndex(index);
+                bool isShowNetwork = Peony::GlobalSettings::getInstance()->isExist(SHOW_NETWORK) ?
+                            Peony::GlobalSettings::getInstance()->getValue(SHOW_NETWORK).toBool() : true;
+                if (item->type() == SideBarAbstractItem::NetWorkItem) {
+                    this->setRowHidden(index.row(), index.parent(), !isShowNetwork);
+                    if (!isShowNetwork) {
+                        item->findChildrenAsync();
+                    }
+                    return;
+                }
+            }
+            this->viewport()->update();
+        }
+    });
+
+    connect(m_model, &SideBarModel::signal_collapsedChildren, this, [=](const QModelIndex &index){
+        QModelIndex modelIndex = m_proxy_model->mapFromSource(index);
+        collapse(modelIndex);
+    });
+
+    //expandToDepth(1);/* 快速访问、计算机、网络 各模块往下展开一层 */
+    for(int row =0; row < model()->rowCount();row++)
+    {
+        auto index = model()->index(row,0);
+        auto srcIndex = m_proxy_model->mapToSource(index);
+        auto item = m_model->itemFromIndex(srcIndex);
+        if(item->uri()=="filesafe:///")/* 文件保护箱默认不展开 */
+            continue;
+        expand(index);
+    }
 }
 
 bool NavigationSideBar::eventFilter(QObject *obj, QEvent *e)
@@ -295,8 +364,12 @@ bool NavigationSideBar::eventFilter(QObject *obj, QEvent *e)
 
 void NavigationSideBar::updateGeometries()
 {
-    setViewportMargins(4, 0, 4, 0);
+    setViewportMargins(8, 0, 4, 0);
     QTreeView::updateGeometries();
+    if(m_notAllowHorizontalMove){
+        horizontalScrollBar()->setValue(0);/* hotfix bug#93557 */
+    }
+    m_notAllowHorizontalMove = false;
 }
 
 void NavigationSideBar::scrollTo(const QModelIndex &index, QAbstractItemView::ScrollHint hint)
@@ -318,8 +391,8 @@ void NavigationSideBar::resizeEvent(QResizeEvent *e)
 {
     QTreeView::resizeEvent(e);
     if (header()->count() > 0) {
-        this->setColumnWidth(1, 20);
-        header()->resizeSection(0, this->viewport()->width() - this->columnWidth(1));
+        setColumnWidth(0, this->viewport()->width() - MINIMUM_COLUMN_SIZE - viewportMargins().left() - viewportMargins().right() - verticalScrollBar()->width());
+        setColumnWidth(1, MINIMUM_COLUMN_SIZE);
     }
 }
 
@@ -330,18 +403,18 @@ void NavigationSideBar::dropEvent(QDropEvent *e)
         return;
 
     QString destUri = m_proxy_model->itemFromIndex(indexAt(e->pos()))->uri();
+    auto data = e->mimeData();
+    auto bookmark = Peony::BookMarkManager::getInstance();
+    if (bookmark->isLoaded()) {
+        for (auto url : data->urls()) {
+            if(url.toString().startsWith("filesafe:///")){
+                QMessageBox::warning(this, tr("warn"), tr("This operation is not supported."));
+                continue;
+            }
+            if (dropIndicatorPosition() == QAbstractItemView::AboveItem || dropIndicatorPosition() == QAbstractItemView::BelowItem || "favorite:///" == destUri) {
+                // add to bookmark
+                e->setAccepted(true);
 
-    if (dropIndicatorPosition() == QAbstractItemView::AboveItem || dropIndicatorPosition() == QAbstractItemView::BelowItem || "favorite:///" == destUri) {
-        // add to bookmark
-        e->setAccepted(true);
-
-        auto data = e->mimeData();
-        auto bookmark = Peony::BookMarkManager::getInstance();
-        if (bookmark->isLoaded()) {
-            for (auto url : data->urls()) {
-                if(url.toString().startsWith("filesafe:///")){
-                    continue;
-                }
                 //FIXME: replace BLOCKING api in ui thread.
                 auto info = Peony::FileInfo::fromUri(url.toDisplayString());
                 if (info->displayName().isNull()) {
@@ -371,13 +444,19 @@ QSize NavigationSideBar::sizeHint() const
 
 void NavigationSideBar::JumpDirectory(const QString &uri)
 {
+    if(uri=="" && m_currSelectedItem && m_currSelectedItem->getDevice().startsWith("/dev/sd"))
+    {/* 异常U盘 */
+        QMessageBox::information(nullptr, tr("Tips"), tr("This is an abnormal Udisk, please fix it or format it"));
+        return;
+    }
+
     auto info = FileInfo::fromUri(uri);
     if (info.get()->isEmptyInfo()) {
         FileInfoJob j(info);
         j.querySync();
     }
     auto targetUri = FileUtils::getTargetUri(uri);
-    if (targetUri == "" && uri== "burn://" /*&& item->displayName().contains("DVD")*/)
+    if (targetUri == "" && uri== "burn://")
     {
         qDebug() << "empty drive"<<uri;
         QMessageBox::information(nullptr, tr("Tips"), tr("This is an empty drive, please insert a Disc."));
@@ -389,6 +468,11 @@ void NavigationSideBar::JumpDirectory(const QString &uri)
         return;
     }
 
+    // try fixing #133429.
+    if (m_currSelectedItem->getDevice().startsWith("/dev/sr") && uri.startsWith("computer://")) {
+        return;
+    }
+
     //some side bar item doesn't have a uri.
     //do not emit signal with a null uri to window.
     if (!uri.isNull())
@@ -397,6 +481,11 @@ void NavigationSideBar::JumpDirectory(const QString &uri)
 
 void NavigationSideBar::keyPressEvent(QKeyEvent *event)
 {
+    if(event->key() == Qt::Key_Left||event->key()==Qt::Key_Right)
+    {
+        m_notAllowHorizontalMove = true;
+    }
+
     QTreeView::keyPressEvent(event);
 
     if (event->key() == Qt::Key_Return) {
@@ -406,6 +495,11 @@ void NavigationSideBar::keyPressEvent(QKeyEvent *event)
             Q_EMIT this->updateWindowLocationRequest(uri, true);
         }
     }
+
+    if(event->key() == Qt::Key_Left||event->key()==Qt::Key_Right)
+    {/* 按下左右键不可使侧边栏内容左右平移显示 */
+        horizontalScrollBar()->setValue(0);/* hotfix bug#93557 */
+    }
 }
 
 void NavigationSideBar::focusInEvent(QFocusEvent *event)
@@ -426,19 +520,40 @@ void NavigationSideBar::focusInEvent(QFocusEvent *event)
             });
         }
     }
+    GlobalSettings::getInstance()->setValue("LAST_FOCUS_PEONY_WINID", dynamic_cast<MainWindow *>(this->topLevelWidget())->winId());
+}
+
+void NavigationSideBar::wheelEvent(QWheelEvent *event)
+{
+    QTreeView::wheelEvent(event);
+    if (event->orientation()==Qt::Horizontal) {
+        /* 触摸板左右滑动不可使侧边栏内容左右平移显示 */
+        horizontalScrollBar()->setValue(0);/* hotfix bug#93557 */
+    }
 }
 
 int NavigationSideBar::sizeHintForColumn(int column) const
 {
     if (column == 1)
-        return 22;
+        return MINIMUM_COLUMN_SIZE;
 
     if (column == 0)
-        return viewport()->width() - 22;
+        return viewport()->width() - MINIMUM_COLUMN_SIZE - viewportMargins().left() - viewportMargins().right() - verticalScrollBar()->width();
 
     return QTreeView::sizeHintForColumn(column);
 }
 
+void NavigationSideBar::dragEnterEvent(QDragEnterEvent *event)
+{
+    if (event->mimeData()->hasUrls()) {
+        if ((event->dropAction() == Qt::MoveAction) && FileUtils::containsStandardPath(event->mimeData()->urls())) {
+            event->ignore();
+            return;
+        }
+    }
+    QAbstractItemView::dragEnterEvent(event);
+}
+
 NavigationSideBarItemDelegate::NavigationSideBarItemDelegate(QObject *parent)
 {
 
@@ -447,39 +562,58 @@ NavigationSideBarItemDelegate::NavigationSideBarItemDelegate(QObject *parent)
 QSize NavigationSideBarItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     auto size = QStyledItemDelegate::sizeHint(option, index);
-    size.setHeight(36);
+    //task#106007 【文件管理器】文件管理器应用做平板UI适配，修改侧边栏项的高度--48px
+    if(qApp->property("tabletMode").toBool()) {
+        size.setHeight(48);
+    } else {
+        size.setHeight(36);
+    }
+
     return size;
 }
 
 void NavigationSideBarItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     painter->save();
-    if (index.column() == 1) {
-        QPainterPath rightRoundedRegion;
-        rightRoundedRegion.setFillRule(Qt::WindingFill);
-        auto rect = option.rect;
-        auto view = qobject_cast<const QAbstractItemView *>(option.widget);
-        if (view) {
-            rect.setRight(view->viewport()->rect().right());
-        }
-        rightRoundedRegion.addRoundedRect(rect, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS);
-        rightRoundedRegion.addRect(rect.adjusted(0, 0, -NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, 0));
-        painter->setClipPath(rightRoundedRegion);
-    }
+//    if (index.column() == 1) {
+//        QPainterPath rightRoundedRegion;
+//        rightRoundedRegion.setFillRule(Qt::WindingFill);
+//        auto rect = option.rect;
+//        auto view = qobject_cast<const QAbstractItemView *>(option.widget);
+//        if (view) {
+//            rect.setRight(view->viewport()->rect().right());
+//        }
+//        rightRoundedRegion.addRoundedRect(rect, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS);
+//        rightRoundedRegion.addRect(rect.adjusted(0, 0, -NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, 0));
+//        //painter->setClipPath(rightRoundedRegion);
+//    }
 
-    painter->setRenderHint(QPainter::Antialiasing);
+    painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     QStyledItemDelegate::paint(painter, option, index);
     painter->restore();
 }
 
-NavigationSideBarContainer::NavigationSideBarContainer(QWidget *parent)
+NavigationSideBarContainer::NavigationSideBarContainer(QWidget *parent) : Peony::SideBar(parent)
 {
+    setMinimumWidth(144);  /* 设计要求侧边栏最小宽度为144px */
     setAttribute(Qt::WA_TranslucentBackground);
 
     m_layout = new QVBoxLayout;
     m_layout->setContentsMargins(0, 4, 0, 0);
     m_layout->setSpacing(0);
-}
+
+    auto sideBar = new NavigationSideBar(this);
+
+    QWidget *widget = new QWidget;
+    m_layout->addWidget(new TitleLabel(this));
+    m_layout->addWidget(sideBar);
+    widget->setLayout(m_layout);
+
+    setWidget(widget);
+
+    connect(sideBar, &NavigationSideBar::updateWindowLocationRequest, this, &NavigationSideBarContainer::updateWindowLocationRequest);
+
+ }
 
 void NavigationSideBarContainer::addSideBar(NavigationSideBar *sidebar)
 {
@@ -494,9 +628,10 @@ void NavigationSideBarContainer::addSideBar(NavigationSideBar *sidebar)
     l->setContentsMargins(4, 4, 2, 4);
 
     m_label_button = new QPushButton(QIcon(":/icons/sign"), tr("All tags..."), this);
-    m_label_button->setProperty("useIconHighlightEffect", true);
+    m_label_button->setProperty("useIconHighlightEffect", 0x2);
     m_label_button->setProperty("iconHighlightEffectMode", 1);
     m_label_button->setProperty("fillIconSymbolicColor", true);
+    m_label_button->setProperty("isWindowButton", 0x1);
     m_label_button->setCheckable(true);
 
     m_label_button->setFocusPolicy(Qt::FocusPolicy(m_label_button->focusPolicy() & ~Qt::TabFocus));
@@ -533,17 +668,41 @@ void NavigationSideBarStyle::drawPrimitive(QStyle::PrimitiveElement element, con
 {
     painter->save();
     switch (element) {
-    case QStyle::PE_IndicatorBranch: {
-        if (option->rect.x() == 0) {
-            QPainterPath leftRoundedRegion;
-            leftRoundedRegion.setFillRule(Qt::WindingFill);
-            leftRoundedRegion.addRoundedRect(option->rect, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS);
-            leftRoundedRegion.addRect(option->rect.adjusted(NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, 0, 0, 0));
-            painter->setClipPath(leftRoundedRegion);
-        }
-        break;
+    case QStyle::PE_IndicatorItemViewItemDrop: {
+        /* hotfixbug#99344：拖拽文件到侧边栏，出现黑框 */
+        painter->setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform, true);/* 反锯齿 */
+        /* 按设计要求，边框颜色为调色板highlight值，圆角为6px */
+        QColor color = option->palette.color(QPalette::Highlight);
+        painter->setPen(color);
+        painter->drawRoundedRect(option->rect, 6, 6);
+        painter->restore();
+        return;
     }
+//    case QStyle::PE_IndicatorBranch: {
+//        if (option->rect.x() == 0) {
+//            QPainterPath leftRoundedRegion;
+//            leftRoundedRegion.setFillRule(Qt::WindingFill);
+//            leftRoundedRegion.addRoundedRect(option->rect, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS);
+//            leftRoundedRegion.addRect(option->rect.adjusted(NAVIGATION_SIDEBAR_ITEM_BORDER_RADIUS, 0, 0, 0));
+//            painter->setClipPath(leftRoundedRegion);
+//        }
+//        const QStyleOptionViewItem *tmp = qstyleoption_cast<const QStyleOptionViewItem *>(option);
+//        QStyleOptionViewItem opt = *tmp;
+//        if (!opt.state.testFlag(QStyle::State_Selected)) {
+//            if (opt.state & QStyle::State_Sunken) {
+//                opt.palette.setColor(QPalette::Highlight, opt.palette.button().color());
+//            }
+//            if (opt.state & QStyle::State_MouseOver) {
+//                opt.palette.setColor(QPalette::Highlight, opt.palette.mid().color());
+//            }
+//        }
+//        qApp->style()->drawPrimitive(element, &opt, painter, widget);
+//        painter->restore();
+//        return;
+//    }
+
     case QStyle::PE_PanelItemViewRow: {
+        painter->restore();
         return;
         break;
     }
@@ -554,6 +713,49 @@ void NavigationSideBarStyle::drawPrimitive(QStyle::PrimitiveElement element, con
         break;
     }
 
-    QProxyStyle::drawPrimitive(element, option, painter, widget);
+    qApp->style()->drawPrimitive(element, option, painter, widget);
     painter->restore();
 }
+
+void NavigationSideBarStyle::drawControl(QStyle::ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
+{
+    if (element == QStyle::CE_ItemViewItem) {
+        const QStyleOptionViewItem *tmp = qstyleoption_cast<const QStyleOptionViewItem *>(option);
+        QStyleOptionViewItem opt = *tmp;
+        if (!opt.state.testFlag(QStyle::State_Selected)) {
+            if (opt.state & QStyle::State_Sunken) {
+                opt.palette.setColor(QPalette::Highlight, opt.palette.button().color());
+            }
+            if (opt.state & QStyle::State_MouseOver) {
+                opt.palette.setColor(QPalette::Highlight, opt.palette.mid().color());
+            }
+        }
+        return qApp->style()->drawControl(element, &opt, painter, widget);
+    }
+}
+
+TitleLabel::TitleLabel(QWidget *parent):QWidget(parent)
+{
+    X11WindowManager::getInstance()->registerWidget(this);
+    m_pix_label = new QLabel(this);
+    //task#106007 【文件管理器】文件管理器应用做平板UI适配，修改应用图标可以跟随主题框架
+    m_pix_label->setPixmap(QIcon::fromTheme("system-file-manager").pixmap(32,32));
+
+    if (QGSettings::isSchemaInstalled("org.ukui.style")) {
+        m_gSettings = new QGSettings("org.ukui.style", QByteArray(), this);
+        connect(m_gSettings, &QGSettings::changed, this, [=](const QString &key) {
+            if("iconThemeName" == key){
+                m_pix_label->setPixmap(QIcon::fromTheme("system-file-manager").pixmap(32,32));
+            }
+        });
+    }
+
+    m_text_label = new QLabel(tr("Peony"),this);
+    QHBoxLayout *l = new QHBoxLayout(this);
+    l->setMargin(8); /* 按设计要求间距为8px */
+    l->addWidget(m_pix_label);
+    l->addSpacing(8);
+    l->addWidget(m_text_label);
+    l->addStretch();
+    this->setFixedHeight(sizeHint().height());
+}
