@@ -31,9 +31,12 @@ class SortTypeMenu : public QMenu
 public:
     explicit SortTypeMenu(QWidget *parent = nullptr);
 
+    void setOriginPathVisible(bool visible);
+
 Q_SIGNALS:
     void switchSortTypeRequest(int type);
     void switchSortOrderRequest(Qt::SortOrder order);
+    void globalSortingPolicyChanged();
 
 public Q_SLOTS:
     void setSortType(int type);
@@ -43,6 +46,7 @@ private:
     int m_sort_type = 0;
     Qt::SortOrder m_sort_order = Qt::AscendingOrder;
 
+    QAction *m_origin_path = nullptr;
     QActionGroup *m_sort_types;
     QActionGroup *m_sort_orders;
 };
