@@ -52,7 +52,8 @@ public Q_SLOTS:
     void updateZoomLevelState(int zoomLevel);
 
     void onZoomRequest(bool zoomIn);
-
+    //显示隐藏文件，更新项目个数
+    void updateItemsNum();
 protected:
     void paintEvent(QPaintEvent *e) override;
     void mousePressEvent(QMouseEvent *e) override;
