@@ -77,6 +77,9 @@
 #include "directory-view-menu.h"
 #include "icon-view.h"
 
+#include "side-bar-factory-manager.h"
+#include "intel/tablet-side-bar-factory.h"
+
 #include "plugin-manager.h"
 
 #include "list-view.h"
@@ -118,6 +121,9 @@ static bool m_resident = false;
 
 PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicationName) : SingleApplication (argc, argv, applicationName, true)
 {
+    bool isWayland = QString(qgetenv("XDG_SESSION_DESKTOP")).contains("ukui-wayland");
+    setProperty("isWayland", isWayland);
+
     setApplicationVersion(QString("v%1").arg(VERSION));
     //setApplicationDisplayName(tr("Peony-Qt"));
 
@@ -136,7 +142,23 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
     QTranslator *t3 = new QTranslator(this);
     t3->load("/usr/share/qt5/translations/qt_"+QLocale::system().name());
     QApplication::installTranslator(t3);
-    setStyle(Peony::ComplementaryStyle::getStyle());
+    QTranslator *t4 = new QTranslator(this);
+    t4->load("/usr/share/qt5/translations/qtbase_"+QLocale::system().name());
+    QApplication::installTranslator(t4);
+    //setStyle(Peony::ComplementaryStyle::getStyle());
+    QTranslator *sdkTrans = new QTranslator(this);
+    if (sdkTrans->load(":/translations/gui_" + QLocale::system().name() + ".qm")) {
+        QApplication::installTranslator(sdkTrans);
+    }
+
+#ifdef KY_UDF_BURN
+    QTranslator *tUdfBrun = new QTranslator(this);
+    auto udfBurnTranslationFilePath = QString("/usr/share/kyudfburn/translations/kyudfburn_%1.qm").arg(QLocale::system().name());
+    bool ok = tUdfBrun->load(udfBurnTranslationFilePath);
+    if (!ok) {
+        qWarning()<<"can not load kyudfburn translation files, path is"<<udfBurnTranslationFilePath;
+    }
+#endif
 
     setApplicationName(tr("peony-qt"));
 
@@ -171,6 +193,7 @@ PeonyApplication::PeonyApplication(int &argc, char *argv[], const char *applicat
 
     if (this->isPrimary()) {
         connect(this, &SingleApplication::receivedMessage, this, &PeonyApplication::parseCmd);
+        Peony::SideBarFactoryManager::getInstance()->registerFactory(new Peony::Intel::TabletSideBarFactory);
     }
 
     //parse cmd
