@@ -29,21 +29,31 @@
 #include <QMouseEvent>
 #include <QGSettings>
 
+#ifdef KY_SDK_QT_WIDGETS
+#include <kaboutdialog.h>
+#endif
+
 namespace Ui {
 class AboutDialog;
 }
 
+#ifdef KY_SDK_QT_WIDGETS
+class AboutDialog : public kdk::KAboutDialog
+#else
 class AboutDialog : public QDialog
+#endif
 {
     Q_OBJECT
 
 public:
     explicit AboutDialog(QWidget *parent = nullptr);
     ~AboutDialog();
+    void resetSize();
+
 private:
    void  initUI();
     QString getCurrentVersion();
-	void paintEvent(QPaintEvent *event) override;
+
 private Q_SLOTS:
     void on_closeBtn_clicked();
 
@@ -53,6 +63,7 @@ private:
     void setSupportText();
     //颜色转换
     QString convertRGB16HexStr(const QColor &color);
+    bool m_isFirstLoad = false;
 };
 
 #endif // ABOUTDIALOG_H
